package cn.iocoder.yudao.module.ecw.controller.admin.bankAccount;

import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;

import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

import cn.iocoder.yudao.framework.excel.util.ExcelUtils;

import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;

import cn.iocoder.yudao.module.ecw.controller.admin.bankAccount.vo.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.bankAccount.BankAccountDO;
import cn.iocoder.yudao.module.ecw.convert.bankAccount.BankAccountConvert;
import cn.iocoder.yudao.module.ecw.service.bankAccount.BankAccountService;

@Api(tags = "管理后台 - 银行账户")
@RestController
@RequestMapping("/ecw/bank-account")
@Validated
public class BankAccountController {

    @Resource
    private BankAccountService bankAccountService;

    @PostMapping("/create")
    @ApiOperation("创建银行账户")
    @PreAuthorize("@ss.hasPermission('ecw:bank-account:create')")
    public CommonResult<Long> createBankAccount(@Valid @RequestBody BankAccountCreateReqVO createReqVO) {
        return success(bankAccountService.createBankAccount(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新银行账户")
    @PreAuthorize("@ss.hasPermission('ecw:bank-account:update')")
    public CommonResult<Boolean> updateBankAccount(@Valid @RequestBody BankAccountUpdateReqVO updateReqVO) {
        bankAccountService.updateBankAccount(updateReqVO);
        return success(true);
    }

    @PutMapping("/updateStatus")
    @ApiOperation("更新银行账户")
    @PreAuthorize("@ss.hasPermission('ecw:bank-account:update')")
    public CommonResult<Boolean> updateBankAccountStatus(
            @Valid @RequestBody BankAccountUpdateStatusReqVO updateReqVO) {
        bankAccountService.updateBankAccountStatus(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除银行账户")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('ecw:bank-account:delete')")
    public CommonResult<Boolean> deleteBankAccount(@RequestParam("id") Long id) {
        bankAccountService.deleteBankAccount(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得银行账户")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
//    @PreAuthorize("@ss.hasPermission('ecw:bank-account:query')")
    public CommonResult<BankAccountRespVO> getBankAccount(@RequestParam("id") Long id) {
        BankAccountDO bankAccount = bankAccountService.getBankAccount(id);
        return success(BankAccountConvert.INSTANCE.convert(bankAccount));
    }

    @GetMapping("/list")
    @ApiOperation("获得银行账户列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
//    @PreAuthorize("@ss.hasPermission('ecw:bank-account:query')")
    public CommonResult<List<BankAccountRespVO>> getBankAccountList(@RequestParam("ids") Collection<Long> ids) {
        List<BankAccountDO> list = bankAccountService.getBankAccountList(ids);
        return success(BankAccountConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得银行账户分页")
//    @PreAuthorize("@ss.hasPermission('ecw:bank-account:query')")
    public CommonResult<PageResult<BankAccountRespVO>> getBankAccountPage(@Valid BankAccountPageReqVO pageVO) {
        PageResult<BankAccountDO> pageResult = bankAccountService.getBankAccountPage(pageVO);
        return success(BankAccountConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出银行账户 Excel")
    @PreAuthorize("@ss.hasPermission('ecw:bank-account:export')")
    @OperateLog(type = EXPORT)
    public void exportBankAccountExcel(@Valid BankAccountExportReqVO exportReqVO,
              HttpServletResponse response) throws IOException {
        List<BankAccountDO> list = bankAccountService.getBankAccountList(exportReqVO);
        // 导出 Excel
        List<BankAccountExcelVO> datas = BankAccountConvert.INSTANCE.convertList02(list);
        ExcelUtils.write(response, "银行账户.xls", "数据", BankAccountExcelVO.class, datas);
    }

}
