package cn.iocoder.yudao.module.ecw.controller.admin.busiPwd;

import cn.iocoder.yudao.module.ecw.enums.ErrorCodeConstants;
import org.springframework.util.DigestUtils;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;

import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.error;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

import cn.iocoder.yudao.framework.excel.util.ExcelUtils;

import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;

import cn.iocoder.yudao.module.ecw.controller.admin.busiPwd.vo.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.busiPwd.BusiPwdDO;
import cn.iocoder.yudao.module.ecw.convert.busiPwd.BusiPwdConvert;
import cn.iocoder.yudao.module.ecw.service.busiPwd.BusiPwdService;

@Api(tags = "管理后台 - 业务密码")
@RestController
@RequestMapping("/ecw/busi-pwd")
@Validated
public class BusiPwdController {

    @Resource
    private BusiPwdService busiPwdService;

    @PostMapping("/create")
    @ApiOperation("创建业务密码")
    @PreAuthorize("@ss.hasPermission('ecw:busi-pwd:create')")
    public CommonResult<Long> createBusiPwd(@Valid @RequestBody BusiPwdCreateReqVO createReqVO) {
        BusiPwdPageReqVO reqVO=new BusiPwdPageReqVO();
        reqVO.setBusiType(createReqVO.getBusiType());
        PageResult pageResult=busiPwdService.getBusiPwdPage(reqVO);
        if(pageResult.getTotal()>0){
            return error(ErrorCodeConstants.BUSI_PWD_TYPE_MUST_ONE);
        }
        return success(busiPwdService.createBusiPwd(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新业务密码")
    @PreAuthorize("@ss.hasPermission('ecw:busi-pwd:update')")
    public CommonResult<Boolean> updateBusiPwd(@Valid @RequestBody BusiPwdUpdateReqVO updateReqVO) {
        busiPwdService.updateBusiPwd(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除业务密码")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('ecw:busi-pwd:delete')")
    public CommonResult<Boolean> deleteBusiPwd(@RequestParam("id") Long id) {
        busiPwdService.deleteBusiPwd(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得业务密码")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('ecw:busi-pwd:query')")
    public CommonResult<BusiPwdRespVO> getBusiPwd(@RequestParam("id") Long id) {
        BusiPwdDO busiPwd = busiPwdService.getBusiPwd(id);
        return success(BusiPwdConvert.INSTANCE.convert(busiPwd));
    }

    @GetMapping("/list")
    @ApiOperation("获得业务密码列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    @PreAuthorize("@ss.hasPermission('ecw:busi-pwd:query')")
    public CommonResult<List<BusiPwdRespVO>> getBusiPwdList(@RequestParam("ids") Collection<Long> ids) {
        List<BusiPwdDO> list = busiPwdService.getBusiPwdList(ids);
        return success(BusiPwdConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得业务密码分页")
    @PreAuthorize("@ss.hasPermission('ecw:busi-pwd:query')")
    public CommonResult<PageResult<BusiPwdRespVO>> getBusiPwdPage(@Valid BusiPwdPageReqVO pageVO) {
        PageResult<BusiPwdDO> pageResult = busiPwdService.getBusiPwdPage(pageVO);
        return success(BusiPwdConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出业务密码 Excel")
    @PreAuthorize("@ss.hasPermission('ecw:busi-pwd:export')")
    @OperateLog(type = EXPORT)
    public void exportBusiPwdExcel(@Valid BusiPwdExportReqVO exportReqVO,
              HttpServletResponse response) throws IOException {
        List<BusiPwdDO> list = busiPwdService.getBusiPwdList(exportReqVO);
        // 导出 Excel
        List<BusiPwdExcelVO> datas = BusiPwdConvert.INSTANCE.convertList02(list);
        ExcelUtils.write(response, "业务密码.xls", "数据", BusiPwdExcelVO.class, datas);
    }




    @PostMapping("/validate-pwd")
    @ApiOperation("验证业务密码")
    public CommonResult<Boolean> validatePwd(@Valid @RequestBody BusiPwdConfirmReqVO busiPwdConfirmReqVO) {

        String busiType = busiPwdConfirmReqVO.getBusiType();
        String pwd = DigestUtils.md5DigestAsHex(busiPwdConfirmReqVO.getPwd().getBytes()) ;

        BusiPwdDO busiPwdDO = busiPwdService.selectOne("busi_type", busiType, "pwd", pwd);

        return success(busiPwdDO != null);
    }

}
