package cn.iocoder.yudao.module.ecw.controller.admin.cabinet;

import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;

import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

import cn.iocoder.yudao.framework.excel.util.ExcelUtils;

import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;

import cn.iocoder.yudao.module.ecw.controller.admin.cabinet.vo.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.cabinet.CabinetDO;
import cn.iocoder.yudao.module.ecw.convert.cabinet.CabinetConvert;
import cn.iocoder.yudao.module.ecw.service.cabinet.CabinetService;

@Api(tags = "管理后台 - 柜型配置")
@RestController
@RequestMapping("/ecw/cabinet")
@Validated
public class CabinetController {

    @Resource
    private CabinetService cabinetService;

    @PostMapping("/create")
    @ApiOperation("创建柜型配置")
    @PreAuthorize("@ss.hasPermission('ecw:cabinet:create')")
    public CommonResult<Long> createCabinet(@Valid @RequestBody CabinetCreateReqVO createReqVO) {
        return success(cabinetService.createCabinet(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新柜型配置")
    @PreAuthorize("@ss.hasPermission('ecw:cabinet:update')")
    public CommonResult<Boolean> updateCabinet(@Valid @RequestBody CabinetUpdateReqVO updateReqVO) {
        cabinetService.updateCabinet(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除柜型配置")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('ecw:cabinet:delete')")
    public CommonResult<Boolean> deleteCabinet(@RequestParam("id") Long id) {
        cabinetService.deleteCabinet(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得柜型配置")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
//    @PreAuthorize("@ss.hasPermission('ecw:cabinet:query')")
    public CommonResult<CabinetRespVO> getCabinet(@RequestParam("id") Long id) {
        CabinetDO cabinet = cabinetService.getCabinet(id);
        return success(CabinetConvert.INSTANCE.convert(cabinet));
    }

    @GetMapping("/list")
    @ApiOperation("获得柜型配置列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
//    @PreAuthorize("@ss.hasPermission('ecw:cabinet:query')")
    public CommonResult<List<CabinetRespVO>> getCabinetList(@RequestParam("ids") Collection<Long> ids) {
        List<CabinetDO> list = cabinetService.getCabinetList(ids);
        return success(CabinetConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得柜型配置分页")
//    @PreAuthorize("@ss.hasPermission('ecw:cabinet:query')")
    public CommonResult<PageResult<CabinetRespVO>> getCabinetPage(@Valid CabinetPageReqVO pageVO) {
        PageResult<CabinetDO> pageResult = cabinetService.getCabinetPage(pageVO);
        return success(CabinetConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出柜型配置 Excel")
//    @PreAuthorize("@ss.hasPermission('ecw:cabinet:export')")
    @OperateLog(type = EXPORT)
    public void exportCabinetExcel(@Valid CabinetExportReqVO exportReqVO,
              HttpServletResponse response) throws IOException {
        List<CabinetDO> list = cabinetService.getCabinetList(exportReqVO);
        // 导出 Excel
        List<CabinetExcelVO> datas = CabinetConvert.INSTANCE.convertList02(list);
        ExcelUtils.write(response, "柜型配置.xls", "数据", CabinetExcelVO.class, datas);
    }

}
