package cn.iocoder.yudao.module.ecw.controller.admin.clearanceFileNo;

import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;
import javax.validation.constraints.*;
import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;
import cn.iocoder.yudao.module.ecw.vo.clearanceFileNo.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.clearanceFileNo.ClearanceFileNoDO;
import cn.iocoder.yudao.module.ecw.convert.clearanceFileNo.ClearanceFileNoConvert;
import cn.iocoder.yudao.module.ecw.service.clearanceFileNo.ClearanceFileNoService;

@Validated
@RestController
@Api(tags = "管理后台 - 清关文件号码")
@RequestMapping("/ecw/clearance-file-no")
public class ClearanceFileNoController {

    @Resource
    private ClearanceFileNoService clearanceFileNoService;

    @PostMapping("/create")
    @ApiOperation("创建清关文件号码")
//    @PreAuthorize("@ss.hasPermission('ecw:clearance-file-no:create')")
    public CommonResult<Long> createClearanceFileNo(@Valid @RequestBody ClearanceFileNoCreateReqVO createReqVO) {
        return success(clearanceFileNoService.createClearanceFileNo(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新清关文件号码")
//    @PreAuthorize("@ss.hasPermission('ecw:clearance-file-no:update')")
    public CommonResult<Boolean> updateClearanceFileNo(@Valid @RequestBody ClearanceFileNoUpdateReqVO updateReqVO) {
        clearanceFileNoService.updateClearanceFileNo(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除清关文件号码")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
//    @PreAuthorize("@ss.hasPermission('ecw:clearance-file-no:delete')")
    public CommonResult<Boolean> deleteClearanceFileNo(@RequestParam("id") Long id) {
        clearanceFileNoService.deleteClearanceFileNo(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得清关文件号码")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
//    @PreAuthorize("@ss.hasPermission('ecw:clearance-file-no:query')")
    public CommonResult<ClearanceFileNoBackVO> getClearanceFileNo(@RequestParam("id") Long id) {
        ClearanceFileNoDO clearanceFileNo = clearanceFileNoService.getClearanceFileNo(id);
        return success(ClearanceFileNoConvert.INSTANCE.convert(clearanceFileNo));
    }

    @GetMapping("/list")
    @ApiOperation("获得清关文件号码列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
//    @PreAuthorize("@ss.hasPermission('ecw:clearance-file-no:query')")
    public CommonResult<List<ClearanceFileNoBackVO>> getClearanceFileNoList(@RequestParam("ids") Collection<Long> ids) {
        List<ClearanceFileNoDO> list = clearanceFileNoService.getClearanceFileNoList(ids);
        return success(ClearanceFileNoConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得清关文件号码分页")
//    @PreAuthorize("@ss.hasPermission('ecw:clearance-file-no:query')")
    public CommonResult<PageResult<ClearanceFileNoBackVO>> getClearanceFileNoPage(@Valid ClearanceFileNoQueryVO query, PageVO page) {
        PageResult<ClearanceFileNoDO> pageResult = clearanceFileNoService.getClearanceFileNoPage(query, page);
        return success(ClearanceFileNoConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出清关文件号码 Excel")
//    @PreAuthorize("@ss.hasPermission('ecw:clearance-file-no:export')")
    @OperateLog(type = EXPORT)
    public void exportClearanceFileNoExcel(@Valid ClearanceFileNoQueryVO query,
              HttpServletResponse response) throws IOException {
        List<ClearanceFileNoDO> list = clearanceFileNoService.getClearanceFileNoList(query);
        // 导出 Excel
        List<ClearanceFileNoBackVO> datas = ClearanceFileNoConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "清关文件号码.xls", "数据", ClearanceFileNoBackVO.class, datas);
    }
}
