package cn.iocoder.yudao.module.ecw.controller.admin.country;

import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;

import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;
import cn.iocoder.yudao.module.ecw.vo.country.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.country.CountryDO;
import cn.iocoder.yudao.module.ecw.convert.country.CountryConvert;
import cn.iocoder.yudao.module.ecw.service.country.CountryService;

@Validated
@RestController
@Api(tags = "管理后台 - 国家区号")
@RequestMapping("/ecw/country")
public class CountryController {

    @Resource
    private CountryService countryService;

    @PostMapping("/create")
    @ApiOperation("创建国家区号")
    @PreAuthorize("@ss.hasPermission('ecw:country:create')")
    public CommonResult<Long> createCountry(@Valid @RequestBody CountryCreateReqVO createReqVO) {
        return success(countryService.createCountry(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新国家区号")
    @PreAuthorize("@ss.hasPermission('ecw:country:update')")
    public CommonResult<Boolean> updateCountry(@Valid @RequestBody CountryUpdateReqVO updateReqVO) {
        countryService.updateCountry(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除国家区号")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('ecw:country:delete')")
    public CommonResult<Boolean> deleteCountry(@RequestParam("id") Long id) {
        countryService.deleteCountry(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得国家区号")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<CountryBackVO> getCountry(@RequestParam("id") Long id) {
        CountryDO country = countryService.getCountry(id);
        return success(CountryConvert.INSTANCE.convert(country));
    }

    @GetMapping("/list")
    @ApiOperation("获得国家区号列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    public CommonResult<List<CountryBackVO>> getCountryList(@RequestParam("ids") Collection<Long> ids) {
        List<CountryDO> list = countryService.getCountryList(ids);
        return success(CountryConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/list-all")
    @ApiOperation("获得所有国家区号列表")
    public CommonResult<List<CountryBackVO>> getCountryListAll() {
        List<CountryDO> list = countryService.getCountryList(new CountryQueryVO());
        return success(CountryConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得国家区号分页")
    public CommonResult<PageResult<CountryBackVO>> getCountryPage(@Valid CountryQueryVO query, PageVO page) {
        PageResult<CountryDO> pageResult = countryService.getCountryPage(query, page);
        return success(CountryConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出国家区号 Excel")
    @PreAuthorize("@ss.hasPermission('ecw:country:export')")
    @OperateLog(type = EXPORT)
    public void exportCountryExcel(@Valid CountryQueryVO query,
              HttpServletResponse response) throws IOException {
        List<CountryDO> list = countryService.getCountryList(query);
        // 导出 Excel
        List<CountryBackVO> datas = CountryConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "国家区号.xls", "数据", CountryBackVO.class, datas);
    }
}
