package cn.iocoder.yudao.module.ecw.controller.admin.currency;

import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;

import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

import cn.iocoder.yudao.framework.excel.util.ExcelUtils;

import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;

import cn.iocoder.yudao.module.ecw.controller.admin.currency.vo.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.currency.CurrencyDO;
import cn.iocoder.yudao.module.ecw.convert.currency.CurrencyConvert;
import cn.iocoder.yudao.module.ecw.service.currency.CurrencyService;

@Api(tags = "管理后台 - 货币单位")
@RestController
@RequestMapping("/ecw/currency")
@Validated
public class CurrencyController {

    @Resource
    private CurrencyService currencyService;

    @PostMapping("/create")
    @ApiOperation("创建货币单位")
    @PreAuthorize("@ss.hasPermission('ecw:currency:create')")
    public CommonResult<Integer> createCurrency(@Valid @RequestBody CurrencyCreateReqVO createReqVO) {
        return success(currencyService.createCurrency(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新货币单位")
    @PreAuthorize("@ss.hasPermission('ecw:currency:update')")
    public CommonResult<Boolean> updateCurrency(@Valid @RequestBody CurrencyUpdateReqVO updateReqVO) {
        currencyService.updateCurrency(updateReqVO);
        return success(true);
    }

    @PutMapping("/updateStatus")
    @ApiOperation("更新货币单位")
    @PreAuthorize("@ss.hasPermission('ecw:currency:update')")
    public CommonResult<Boolean> updateCurrencyStatus(@Valid @RequestBody CurrencyUpdateStatusReqVO updateReqVO) {
        currencyService.updateCurrencyStatus(updateReqVO);
        return success(true);
    }


    @DeleteMapping("/delete")
    @ApiOperation("删除货币单位")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Integer.class)
    @PreAuthorize("@ss.hasPermission('ecw:currency:delete')")
    public CommonResult<Boolean> deleteCurrency(@RequestParam("id") Integer id) {
        currencyService.deleteCurrency(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得货币单位")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Integer.class)
//    @PreAuthorize("@ss.hasPermission('ecw:currency:query')")
    public CommonResult<CurrencyRespVO> getCurrency(@RequestParam("id") Integer id) {
        CurrencyDO currency = currencyService.getCurrency(id);
        return success(CurrencyConvert.INSTANCE.convert(currency));
    }

    @GetMapping("/list")
    @ApiOperation("获得货币单位列表")
//    @PreAuthorize("@ss.hasPermission('ecw:currency:query')")
    public CommonResult<List<CurrencyRespVO>> getCurrencyList() {
        List<CurrencyDO> list = currencyService.getCurrencyList();
        return success(CurrencyConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得货币单位分页")
//    @PreAuthorize("@ss.hasPermission('ecw:currency:query')")
    public CommonResult<PageResult<CurrencyRespVO>> getCurrencyPage(@Valid CurrencyPageReqVO pageVO) {
        PageResult<CurrencyDO> pageResult = currencyService.getCurrencyPage(pageVO);
        return success(CurrencyConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出货币单位 Excel")
//    @PreAuthorize("@ss.hasPermission('ecw:currency:export')")
    @OperateLog(type = EXPORT)
    public void exportCurrencyExcel(@Valid CurrencyExportReqVO exportReqVO,
              HttpServletResponse response) throws IOException {
        List<CurrencyDO> list = currencyService.getCurrencyList(exportReqVO);
        // 导出 Excel
        List<CurrencyExcelVO> datas = CurrencyConvert.INSTANCE.convertList02(list);
        ExcelUtils.write(response, "货币单位.xls", "数据", CurrencyExcelVO.class, datas);
    }

}
