package cn.iocoder.yudao.module.ecw.controller.admin.currencyEcash;

import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;

import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

import cn.iocoder.yudao.framework.excel.util.ExcelUtils;

import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;

import cn.iocoder.yudao.module.ecw.controller.admin.currencyEcash.vo.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.currencyEcash.CurrencyEcashDO;
import cn.iocoder.yudao.module.ecw.convert.currencyEcash.CurrencyEcashConvert;
import cn.iocoder.yudao.module.ecw.service.currencyEcash.CurrencyEcashService;

@Api(tags = "管理后台 - E-Cash汇率单位")
@RestController
@RequestMapping("/ecw/currency-ecash")
@Validated
public class CurrencyEcashController {

    @Resource
    private CurrencyEcashService currencyEcashService;

    @PostMapping("/create")
    @ApiOperation("创建E-Cash汇率单位")
    @PreAuthorize("@ss.hasPermission('ecw:currency-ecash:create')")
    public CommonResult<Integer> createCurrencyEcash(@Valid @RequestBody CurrencyEcashCreateReqVO createReqVO) throws Exception {
        return success(currencyEcashService.createCurrencyEcash(createReqVO));
    }

    @PutMapping("/updateBatch")
    @ApiOperation("批量更新E-Cash汇率单位")
    @PreAuthorize("@ss.hasPermission('ecw:currency-ecash:update')")
    public CommonResult<Boolean> batchUpdateCurrencyEcash(@Valid @RequestBody List<CurrencyEcashUpdateReqVO> updateReqVO) {
        currencyEcashService.batchUpdateCurrencyEcash(updateReqVO);
        return success(true);
    }

    @PutMapping("/update")
    @ApiOperation("更新E-Cash汇率单位")
    @PreAuthorize("@ss.hasPermission('ecw:currency-ecash:update')")
    public CommonResult<Boolean> updateCurrencyEcash(@Valid @RequestBody CurrencyEcashUpdateReqVO updateReqVO) {
        currencyEcashService.updateCurrencyEcash(updateReqVO);
        return success(true);
    }

    @PutMapping("/updateAll")
    @ApiOperation("更新E-Cash汇率单位ALL")
    @PreAuthorize("@ss.hasPermission('ecw:currency-ecash:update')")
    public CommonResult<Boolean> updateCurrencyEcashAll(@RequestBody CurrencyEcashDO currencyEcashDO) {
        currencyEcashService.updateCurrencyEcashAll(currencyEcashDO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除E-Cash汇率单位")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Integer.class)
    @PreAuthorize("@ss.hasPermission('ecw:currency-ecash:delete')")
    public CommonResult<Boolean> deleteCurrencyEcash(@RequestParam("id") Integer id) {
        currencyEcashService.deleteCurrencyEcash(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得E-Cash汇率单位")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Integer.class)
//    @PreAuthorize("@ss.hasPermission('ecw:currency-ecash:query')")
    public CommonResult<CurrencyEcashRespVO> getCurrencyEcash(@RequestParam("id") Integer id) {
        CurrencyEcashDO currencyEcash = currencyEcashService.getCurrencyEcash(id);
        return success(CurrencyEcashConvert.INSTANCE.convert(currencyEcash));
    }

    @GetMapping("/list")
    @ApiOperation("获得E-Cash汇率单位列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
//    @PreAuthorize("@ss.hasPermission('ecw:currency-ecash:query')")
    public CommonResult<List<CurrencyEcashRespVO>> getCurrencyEcashList(@RequestParam("ids") Collection<Integer> ids) {
        List<CurrencyEcashDO> list = currencyEcashService.getCurrencyEcashList(ids);
        return success(CurrencyEcashConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得E-Cash汇率单位分页")
//    @PreAuthorize("@ss.hasPermission('ecw:currency-ecash:query')")
    public CommonResult<PageResult<CurrencyEcashRespVO>> getCurrencyEcashPage(@Valid CurrencyEcashPageReqVO pageVO) {
        PageResult<CurrencyEcashDO> pageResult = currencyEcashService.getCurrencyEcashPage(pageVO);
        return success(CurrencyEcashConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出E-Cash汇率单位 Excel")
//    @PreAuthorize("@ss.hasPermission('ecw:currency-ecash:export')")
    @OperateLog(type = EXPORT)
    public void exportCurrencyEcashExcel(@Valid CurrencyEcashExportReqVO exportReqVO,
              HttpServletResponse response) throws IOException {
        List<CurrencyEcashDO> list = currencyEcashService.getCurrencyEcashList(exportReqVO);
        // 导出 Excel
        List<CurrencyEcashExcelVO> datas = CurrencyEcashConvert.INSTANCE.convertList02(list);
        ExcelUtils.write(response, "E-Cash汇率单位.xls", "数据", CurrencyEcashExcelVO.class, datas);
    }

}
