package cn.iocoder.yudao.module.ecw.controller.admin.enterprise;

import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;

import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

import cn.iocoder.yudao.framework.excel.util.ExcelUtils;

import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;

import cn.iocoder.yudao.module.ecw.controller.admin.enterprise.vo.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.enterprise.EnterpriseDO;
import cn.iocoder.yudao.module.ecw.convert.enterprise.EnterpriseConvert;
import cn.iocoder.yudao.module.ecw.service.enterprise.EnterpriseService;

@Api(tags = "管理后台 - 企业设置")
@RestController
@RequestMapping("/ecw/enterprise")
@Validated
public class EnterpriseController {

    @Resource
    private EnterpriseService enterpriseService;

    @PostMapping("/create")
    @ApiOperation("创建企业设置")
    @PreAuthorize("@ss.hasPermission('ecw:enterprise:create')")
    public CommonResult<Long> createEnterprise(@Valid @RequestBody EnterpriseCreateReqVO createReqVO) {
        return success(enterpriseService.createEnterprise(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新企业设置")
    @PreAuthorize("@ss.hasPermission('ecw:enterprise:update')")
    public CommonResult<Boolean> updateEnterprise(@Valid @RequestBody EnterpriseUpdateReqVO updateReqVO) {
        enterpriseService.updateEnterprise(updateReqVO);
        return success(true);
    }

//    @DeleteMapping("/delete")
//    @ApiOperation("删除企业设置")
//    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
//    @PreAuthorize("@ss.hasPermission('ecw:enterprise:delete')")
//    public CommonResult<Boolean> deleteEnterprise(@RequestParam("id") Long id) {
//        enterpriseService.deleteEnterprise(id);
//        return success(true);
//    }

//    @GetMapping("/get")
//    @ApiOperation("获得企业设置")
//    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
//    @PreAuthorize("@ss.hasPermission('ecw:enterprise:query')")
//    public CommonResult<EnterpriseRespVO> getEnterprise(@RequestParam("id") Long id) {
//        EnterpriseDO enterprise = enterpriseService.getEnterprise(id);
//        return success(EnterpriseConvert.INSTANCE.convert(enterprise));
//    }
    @GetMapping("/get")
    @ApiOperation("获得企业设置")
    @PreAuthorize("@ss.hasPermission('ecw:enterprise:query')")
    public CommonResult<EnterpriseRespVO> getEnterprise() {
        EnterpriseDO enterprise = enterpriseService.getInfo();
        return success(EnterpriseConvert.INSTANCE.convert(enterprise));
    }

//    @GetMapping("/list")
//    @ApiOperation("获得企业设置列表")
//    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
//    @PreAuthorize("@ss.hasPermission('ecw:enterprise:query')")
//    public CommonResult<List<EnterpriseRespVO>> getEnterpriseList(@RequestParam("ids") Collection<Long> ids) {
//        List<EnterpriseDO> list = enterpriseService.getEnterpriseList(ids);
//        return success(EnterpriseConvert.INSTANCE.convertList(list));
//    }

    @GetMapping("/page")
    @ApiOperation("获得企业设置分页")
    @PreAuthorize("@ss.hasPermission('ecw:enterprise:query')")
    public CommonResult<PageResult<EnterpriseRespVO>> getEnterprisePage(@Valid EnterprisePageReqVO pageVO) {
        PageResult<EnterpriseDO> pageResult = enterpriseService.getEnterprisePage(pageVO);
        return success(EnterpriseConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出企业设置 Excel")
    @PreAuthorize("@ss.hasPermission('ecw:enterprise:export')")
    @OperateLog(type = EXPORT)
    public void exportEnterpriseExcel(@Valid EnterpriseExportReqVO exportReqVO,
              HttpServletResponse response) throws IOException {
        List<EnterpriseDO> list = enterpriseService.getEnterpriseList(exportReqVO);
        // 导出 Excel
        List<EnterpriseExcelVO> datas = EnterpriseConvert.INSTANCE.convertList02(list);
        ExcelUtils.write(response, "企业设置.xls", "数据", EnterpriseExcelVO.class, datas);
    }

}
