package cn.iocoder.yudao.module.ecw.controller.admin.exchangeRate;

import cn.hutool.core.util.StrUtil;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.module.ecw.convert.exchangeRate.ExchangeRateConvert;
import cn.iocoder.yudao.module.ecw.dal.dataobject.exchangeRate.ExchangeRateDO;
import cn.iocoder.yudao.module.ecw.service.exchangeRate.ExchangeRateService;
import cn.iocoder.yudao.module.ecw.vo.exchangeRate.ExchangeRateBackVO;
import cn.iocoder.yudao.module.ecw.vo.exchangeRate.ExchangeRateCreateReqVO;
import cn.iocoder.yudao.module.ecw.vo.exchangeRate.ExchangeRateQueryVO;
import cn.iocoder.yudao.module.ecw.vo.exchangeRate.ExchangeRateUpdateReqVO;
import cn.iocoder.yudao.module.system.api.user.AdminUserApi;
import cn.iocoder.yudao.module.system.api.user.dto.AdminUserRespDTO;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.Valid;
import java.util.Collection;
import java.util.List;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

@Validated
@RestController
@Api(tags = "管理后台 - 汇率管理")
@RequestMapping("/ecw/exchange-rate")
public class ExchangeRateController {

    @Resource
    private AdminUserApi adminUserApi;
    @Resource
    private ExchangeRateService exchangeRateService;

    @PostMapping("/create")
    @ApiOperation("创建汇率管理")
    public CommonResult<Long> createExchangeRate(@Valid @RequestBody ExchangeRateCreateReqVO createReqVO) {
        return success(exchangeRateService.createExchangeRate(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新汇率管理")
    public CommonResult<Boolean> updateExchangeRate(@Valid @RequestBody ExchangeRateUpdateReqVO updateReqVO) {
        exchangeRateService.updateExchangeRate(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除汇率管理")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<Boolean> deleteExchangeRate(@RequestParam("id") Long id) {
        exchangeRateService.deleteExchangeRate(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得汇率管理")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<ExchangeRateBackVO> getExchangeRate(@RequestParam("id") Long id) {
        ExchangeRateDO exchangeRate = exchangeRateService.getExchangeRate(id);
        ExchangeRateBackVO result = ExchangeRateConvert.INSTANCE.convert(exchangeRate);
        if (StrUtil.isNotBlank(exchangeRate.getCreator())) {
            AdminUserRespDTO adminUserRespDTO = adminUserApi.getUser(Long.parseLong(exchangeRate.getCreator()));
            if (null != adminUserRespDTO) {
                result.setCreatorName(adminUserRespDTO.getNickname());
            }
        }
        if (StrUtil.isNotBlank(exchangeRate.getUpdater())) {
            AdminUserRespDTO adminUserRespDTO = adminUserApi.getUser(Long.parseLong(exchangeRate.getUpdater()));
            if (null != adminUserRespDTO) {
                result.setUpdaterName(adminUserRespDTO.getNickname());
            }
        }
        return success(result);
    }

    @GetMapping("/list")
    @ApiOperation("获得汇率管理列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    public CommonResult<List<ExchangeRateBackVO>> getExchangeRateList(@RequestParam("ids") Collection<Long> ids) {
        List<ExchangeRateDO> list = exchangeRateService.getExchangeRateList(ids);
        return success(ExchangeRateConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得汇率管理分页")
    public CommonResult<PageResult<ExchangeRateBackVO>> getExchangeRatePage(@Valid ExchangeRateQueryVO query, PageVO page) {
        PageResult<ExchangeRateDO> pageResult = exchangeRateService.getExchangeRatePage(query, page);
        return success(ExchangeRateConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/getRateByCurrencyId")
    @ApiOperation("根据币种获取汇率根据货币ID")
    public CommonResult<ExchangeRateBackVO> getExchangeRatePage(@RequestParam("sourceCurrencyId") Long sourceCurrencyId, @RequestParam("targetCurrencyId") Long targetCurrencyId) {
        LambdaQueryWrapper<ExchangeRateDO> lambdaQueryWrapper = new LambdaQueryWrapper<>();
        lambdaQueryWrapper.eq(ExchangeRateDO::getSourceCurrencyId, sourceCurrencyId);
        lambdaQueryWrapper.eq(ExchangeRateDO::getTargetCurrencyId, targetCurrencyId);
        return success(ExchangeRateConvert.INSTANCE.convert(exchangeRateService.getOne(lambdaQueryWrapper)));
    }

    @GetMapping("/getRateByCurrencyCoe")
    @ApiOperation("根据币种获取汇率根据货币符号")
    public CommonResult<ExchangeRateBackVO> getExchangeRatePage(@RequestParam("sourceCurrencyCode") String sourceCurrencyCode, @RequestParam("targetCurrencyCode") String targetCurrencyCode) {
        LambdaQueryWrapper<ExchangeRateDO> lambdaQueryWrapper = new LambdaQueryWrapper<>();
        lambdaQueryWrapper.eq(ExchangeRateDO::getSourceCurrencyCode, sourceCurrencyCode);
        lambdaQueryWrapper.eq(ExchangeRateDO::getTargetCurrencyCode, targetCurrencyCode);
        return success(ExchangeRateConvert.INSTANCE.convert(exchangeRateService.getOne(lambdaQueryWrapper)));
    }
}
