package cn.iocoder.yudao.module.ecw.controller.admin.exchangeRateLog;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.module.ecw.convert.exchangeRateLog.ExchangeRateLogConvert;
import cn.iocoder.yudao.module.ecw.dal.dataobject.exchangeRateLog.ExchangeRateLogDO;
import cn.iocoder.yudao.module.ecw.service.exchangeRateLog.ExchangeRateLogService;
import cn.iocoder.yudao.module.ecw.vo.exchangeRateLog.ExchangeRateLogBackVO;
import cn.iocoder.yudao.module.ecw.vo.exchangeRateLog.ExchangeRateLogCreateReqVO;
import cn.iocoder.yudao.module.ecw.vo.exchangeRateLog.ExchangeRateLogQueryVO;
import cn.iocoder.yudao.module.ecw.vo.exchangeRateLog.ExchangeRateLogUpdateReqVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.Valid;
import java.util.Collection;
import java.util.List;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

@Validated
@RestController
@Api(tags = "管理后台 - 汇率变更记录")
@RequestMapping("/ecw/exchange-rate-log")
public class ExchangeRateLogController {

    @Resource
    private ExchangeRateLogService exchangeRateLogService;

    @PostMapping("/create")
    @ApiOperation("创建汇率变更记录")
    public CommonResult<Long> createExchangeRateLog(@Valid @RequestBody ExchangeRateLogCreateReqVO createReqVO) {
        return success(exchangeRateLogService.createExchangeRateLog(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新汇率变更记录")
    public CommonResult<Boolean> updateExchangeRateLog(@Valid @RequestBody ExchangeRateLogUpdateReqVO updateReqVO) {
        exchangeRateLogService.updateExchangeRateLog(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除汇率变更记录")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<Boolean> deleteExchangeRateLog(@RequestParam("id") Long id) {
        exchangeRateLogService.deleteExchangeRateLog(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得汇率变更记录")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<ExchangeRateLogBackVO> getExchangeRateLog(@RequestParam("id") Long id) {
        ExchangeRateLogDO exchangeRateLog = exchangeRateLogService.getExchangeRateLog(id);
        return success(ExchangeRateLogConvert.INSTANCE.convert(exchangeRateLog));
    }

    @GetMapping("/list")
    @ApiOperation("获得汇率变更记录列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    public CommonResult<List<ExchangeRateLogBackVO>> getExchangeRateLogList(@RequestParam("ids") Collection<Long> ids) {
        List<ExchangeRateLogDO> list = exchangeRateLogService.getExchangeRateLogList(ids);
        return success(ExchangeRateLogConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得汇率变更记录分页")
    public CommonResult<PageResult<ExchangeRateLogBackVO>> getExchangeRateLogPage(@Valid ExchangeRateLogQueryVO query, PageVO page) {
        PageResult<ExchangeRateLogDO> pageResult = exchangeRateLogService.getExchangeRateLogPage(query, page);
        return success(ExchangeRateLogConvert.INSTANCE.convertPage(pageResult));
    }
}
