package cn.iocoder.yudao.module.ecw.controller.admin.express;

import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;

import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

import cn.iocoder.yudao.framework.excel.util.ExcelUtils;

import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;

import cn.iocoder.yudao.module.ecw.controller.admin.express.vo.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.express.ExpressDO;
import cn.iocoder.yudao.module.ecw.convert.express.ExpressConvert;
import cn.iocoder.yudao.module.ecw.service.express.ExpressService;

@Api(tags = "管理后台 - 配送管理")
@RestController
@RequestMapping("/ecw/express")
@Validated
public class ExpressController {

    @Resource
    private ExpressService expressService;

    @PostMapping("/create")
    @ApiOperation("创建配送管理")
//    @PreAuthorize("@ss.hasPermission('ecw:express:create')")
    public CommonResult<Long> createExpress(@Valid @RequestBody ExpressCreateReqVO createReqVO) {
        return success(expressService.createExpress(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新配送管理")
//    @PreAuthorize("@ss.hasPermission('ecw:express:update')")
    public CommonResult<Boolean> updateExpress(@Valid @RequestBody ExpressUpdateReqVO updateReqVO) {
        expressService.updateExpress(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除配送管理")
    @ApiImplicitParam(name = "id", value = "编号", required = true, dataTypeClass = Long.class)
//    @PreAuthorize("@ss.hasPermission('ecw:express:delete')")
    public CommonResult<Boolean> deleteExpress(@RequestParam("id") Long id) {
        expressService.deleteExpress(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得配送管理")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
//    @PreAuthorize("@ss.hasPermission('ecw:express:query')")
    public CommonResult<ExpressRespVO> getExpress(@RequestParam("id") Long id) {
        ExpressDO express = expressService.getExpress(id);
        return success(ExpressConvert.INSTANCE.convert(express));
    }

    @GetMapping("/list")
    @ApiOperation("获得配送管理列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
//    @PreAuthorize("@ss.hasPermission('ecw:express:query')")
    public CommonResult<List<ExpressRespVO>> getExpressList(@RequestParam("ids") Collection<Long> ids) {
        List<ExpressDO> list = expressService.getExpressList(ids);
        return success(ExpressConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得配送管理分页")
//    @PreAuthorize("@ss.hasPermission('ecw:express:query')")
    public CommonResult<PageResult<ExpressRespVO>> getExpressPage(@Valid ExpressPageReqVO pageVO) {
        PageResult<ExpressDO> pageResult = expressService.getExpressPage(pageVO);
        return success(ExpressConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出配送管理 Excel")
//    @PreAuthorize("@ss.hasPermission('ecw:express:export')")
    @OperateLog(type = EXPORT)
    public void exportExpressExcel(@Valid ExpressExportReqVO exportReqVO,
              HttpServletResponse response) throws IOException {
        List<ExpressDO> list = expressService.getExpressList(exportReqVO);
        // 导出 Excel
        List<ExpressExcelVO> datas = ExpressConvert.INSTANCE.convertList02(list);
        ExcelUtils.write(response, "配送管理.xls", "数据", ExpressExcelVO.class, datas);
    }

}
