package cn.iocoder.yudao.module.ecw.controller.admin.internalMessage;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.security.core.annotations.PreAuthenticated;
import cn.iocoder.yudao.framework.web.core.util.WebFrameworkUtils;
import cn.iocoder.yudao.module.ecw.convert.internalMessage.WebInternalMessageConvert;
import cn.iocoder.yudao.module.ecw.dal.dataobject.internalMessage.WebInternalMessageDO;
import cn.iocoder.yudao.module.ecw.service.internalMessage.WebInternalMessageService;
import cn.iocoder.yudao.module.ecw.vo.internalMessage.InternalMessageBackVO;
import cn.iocoder.yudao.module.ecw.vo.internalMessage.InternalMessageCreateReqVO;
import cn.iocoder.yudao.module.ecw.vo.internalMessage.InternalMessageQueryVO;
import cn.iocoder.yudao.module.ecw.vo.internalMessage.InternalMessageUpdateReqVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.Valid;
import java.util.Collection;
import java.util.List;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

@Validated
@RestController
@Api(tags = "管理后台 - 客户端消息")
@RequestMapping("/ecw/client-internal-message")
public class ClientInternalMessageController {

    @Resource
    private WebInternalMessageService internalMessageService;

    @PostMapping("/create")
    @ApiOperation("管理后台 - 创建客户端消息")
    @PreAuthenticated
    public CommonResult<Long> createInternalMessage(@Valid @RequestBody InternalMessageCreateReqVO createReqVO) {
        return success(internalMessageService.createInternalMessage(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("管理后台 - 更新客户端消息--不会更新接收人信息，需要的话别加")
    @PreAuthenticated
    public CommonResult<Boolean> updateInternalMessage(@Valid @RequestBody InternalMessageUpdateReqVO updateReqVO) {
        internalMessageService.updateInternalMessage(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("管理后台 - 删除客户端消息")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthenticated
    public CommonResult<Boolean> deleteInternalMessage(@RequestParam("id") Long id) {
        internalMessageService.deleteInternalMessage(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("管理后台 - 获得客户端消息")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthenticated
    public CommonResult<InternalMessageBackVO> getInternalMessage(@RequestParam("id") Long id) {
        WebInternalMessageDO internalMessage = internalMessageService.getInternalMessage(id);
        return success(WebInternalMessageConvert.INSTANCE.convert(internalMessage));
    }

    @GetMapping("/list")
    @ApiOperation("管理后台 - 获得客户端消息列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    @PreAuthenticated
    public CommonResult<List<InternalMessageBackVO>> getInternalMessageList(@RequestParam("ids") Collection<Long> ids) {
        List<WebInternalMessageDO> list = internalMessageService.getInternalMessageList(ids);
        return success(WebInternalMessageConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("管理后台 - 获得客户端消息分页")
    @PreAuthenticated
    public CommonResult<PageResult<InternalMessageBackVO>> getInternalMessagePage(@Valid InternalMessageQueryVO query, PageVO page) {
        PageResult<WebInternalMessageDO> pageResult = internalMessageService.getInternalMessagePage(query, page);
        return success(WebInternalMessageConvert.INSTANCE.convertPage(pageResult));
    }


    @GetMapping("/getNotReadInternalMessageTotal")
    @PreAuthenticated
    public CommonResult<Long> getNotReadInternalMessageTotal() {
        Long userId = WebFrameworkUtils.getLoginUserId();
        return success(internalMessageService.getNotReadInternalMessageTotal(userId));
    }

    @GetMapping("/getMyInternalMessagePage")
    @ApiOperation("管理后台 - 得到我的客户端消息列表")
    @PreAuthenticated
    public CommonResult<PageResult<InternalMessageBackVO>> getMyInternalMessagePage(@Valid InternalMessageQueryVO query, PageVO page) {
        Long userId = WebFrameworkUtils.getLoginUserId();
        query.setUserId(userId);
        return success(internalMessageService.getMyInternalMessagePage(query, page));
    }

    @GetMapping("/redInternalMessage")
    @ApiOperation("管理后台 - 设置当用用户的某一条客户端消息为已读")
    @ApiImplicitParam(name = "messageId", value = "客户端消息ID", required = true, example = "2048", dataTypeClass = Long.class)
    public CommonResult<Boolean> redInternalMessage(@RequestParam("messageId") Long messageId) {
        Long userId = WebFrameworkUtils.getLoginUserId();
        return success(internalMessageService.redInternalMessage(userId, messageId));
    }
}
