package cn.iocoder.yudao.module.ecw.controller.admin.internalMessage;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.web.core.util.WebFrameworkUtils;
import cn.iocoder.yudao.module.ecw.convert.internalMessage.InternalMessageConvert;
import cn.iocoder.yudao.module.ecw.dal.dataobject.internalMessage.InternalMessageDO;
import cn.iocoder.yudao.module.ecw.service.internalMessage.InternalMessageService;
import cn.iocoder.yudao.module.ecw.vo.internalMessage.InternalMessageBackVO;
import cn.iocoder.yudao.module.ecw.vo.internalMessage.InternalMessageCreateReqVO;
import cn.iocoder.yudao.module.ecw.vo.internalMessage.InternalMessageQueryVO;
import cn.iocoder.yudao.module.ecw.vo.internalMessage.InternalMessageUpdateReqVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.security.crypto.password.PasswordEncoder;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.Valid;
import java.util.Collection;
import java.util.List;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

@Validated
@RestController
@Api(tags = "管理后台 - 后台用户站内信")
@RequestMapping("/ecw/internal-message")
public class InternalMessageController {

    @Resource
    private InternalMessageService internalMessageService;

    @Resource
    PasswordEncoder passwordEncoder;

    @PostMapping("/create")
    @ApiOperation("创建后台用户站内信")
    @PreAuthorize("@ss.hasPermission('ecw:internal-message:create')")
    public CommonResult<Long> createInternalMessage(@Valid @RequestBody InternalMessageCreateReqVO createReqVO) {
        return success(internalMessageService.createInternalMessage(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新后台用户站内信--不会更新接收人信息，需要的话别加")
    @PreAuthorize("@ss.hasPermission('ecw:internal-message:update')")
    public CommonResult<Boolean> updateInternalMessage(@Valid @RequestBody InternalMessageUpdateReqVO updateReqVO) {
        internalMessageService.updateInternalMessage(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除后台用户站内信")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('ecw:internal-message:delete')")
    public CommonResult<Boolean> deleteInternalMessage(@RequestParam("id") Long id) {
        internalMessageService.deleteInternalMessage(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得后台用户站内信")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
//    @PreAuthorize("@ss.hasPermission('ecw:internal-message:query')")
    public CommonResult<InternalMessageBackVO> getInternalMessage(@RequestParam("id") Long id) {
        InternalMessageDO internalMessage = internalMessageService.getInternalMessage(id);
        return success(InternalMessageConvert.INSTANCE.convert(internalMessage));
    }

    @GetMapping("/list")
    @ApiOperation("获得后台用户站内信列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    @PreAuthorize("@ss.hasPermission('ecw:internal-message:query')")
    public CommonResult<List<InternalMessageBackVO>> getInternalMessageList(@RequestParam("ids") Collection<Long> ids) {
        List<InternalMessageDO> list = internalMessageService.getInternalMessageList(ids);
        return success(InternalMessageConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得后台用户站内信分页")
//    @PreAuthorize("@ss.hasPermission('ecw:internal-message:query')")
    public CommonResult<PageResult<InternalMessageBackVO>> getInternalMessagePage(@Valid InternalMessageQueryVO query, PageVO page) {
        PageResult<InternalMessageDO> pageResult = internalMessageService.getInternalMessagePage(query, page);
        return success(InternalMessageConvert.INSTANCE.convertPage(pageResult));
    }


    @GetMapping("/getNotReadInternalMessageTotal")
    @ApiOperation("得到我的所有未读后台用户站内信总数")
    public CommonResult<Long> getNotReadInternalMessageTotal() {
        Long userId = WebFrameworkUtils.getLoginUserId();
        return success(internalMessageService.getNotReadInternalMessageTotal(userId));
    }

    @GetMapping("/getMyInternalMessagePage")
    @ApiOperation("得到我的后台用户站内信列表")
//    @PreAuthorize("@ss.hasPermission('ecw:my-internal-message:query')")
    public CommonResult<PageResult<InternalMessageBackVO>> getMyInternalMessagePage(@Valid InternalMessageQueryVO query, PageVO page) {
        Long userId = WebFrameworkUtils.getLoginUserId();
        query.setUserId(userId);
        System.out.println("------------------------------------:"+passwordEncoder.encode("123456"));
        return success(internalMessageService.getMyInternalMessagePage(query, page));
    }

    @GetMapping("/redInternalMessage")
    @ApiOperation("设置当用用户的某一条后台用户站内信为已读")
    @ApiImplicitParam(name = "messageId", value = "站内信ID", required = true, example = "2048", dataTypeClass = Long.class)
    public CommonResult<Boolean> redInternalMessage(@RequestParam("messageId") Long messageId) {
        Long userId = WebFrameworkUtils.getLoginUserId();
        return success(internalMessageService.redInternalMessage(userId, messageId));
    }
}
