package cn.iocoder.yudao.module.ecw.controller.admin.ladingTemplate;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.module.ecw.controller.admin.ladingTemplate.ueditor.ActionEnter;
import cn.iocoder.yudao.module.ecw.controller.admin.ladingTemplate.vo.LadingTemplateBackVO;
import cn.iocoder.yudao.module.ecw.controller.admin.ladingTemplate.vo.LadingTemplateCreateReqVO;
import cn.iocoder.yudao.module.ecw.controller.admin.ladingTemplate.vo.LadingTemplateUpdateReqVO;
import cn.iocoder.yudao.module.ecw.convert.ladingTemplate.LadingTemplateConvert;
import cn.iocoder.yudao.module.ecw.dal.dataobject.ladingTemplate.LadingTemplateDO;
import cn.iocoder.yudao.module.ecw.service.ladingTemplate.LadingTemplateService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.jetbrains.annotations.NotNull;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.util.ClassUtils;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.*;
import java.util.Collection;
import java.util.List;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

@Validated
@RestController
@Api(tags = "管理后台 - 提单模板")
@RequestMapping("/ecw/lading-template")
public class LadingTemplateController {

    @Resource
    private LadingTemplateService ladingTemplateService;

    @PostMapping("/create")
    @ApiOperation("创建提单模板")
    //@PreAuthorize("@ss.hasPermission('ecw:lading-template:create')")
    public CommonResult<Long> createLadingTemplate(@Valid @RequestBody LadingTemplateCreateReqVO createReqVO) {
        return success(ladingTemplateService.createLadingTemplate(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新提单模板")
    //@PreAuthorize("@ss.hasPermission('ecw:lading-template:update')")
    public CommonResult<Boolean> updateLadingTemplate(@Valid @RequestBody LadingTemplateUpdateReqVO updateReqVO) {
        ladingTemplateService.updateLadingTemplate(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除提单模板")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    //@PreAuthorize("@ss.hasPermission('ecw:lading-template:delete')")
    public CommonResult<Boolean> deleteLadingTemplate(@RequestParam("id") Long id) {
        ladingTemplateService.deleteLadingTemplate(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得提单模板")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    //@PreAuthorize("@ss.hasPermission('ecw:lading-template:query')")
    public CommonResult<LadingTemplateBackVO> getLadingTemplate(@RequestParam("id") Long id) {
        LadingTemplateDO ladingTemplate = ladingTemplateService.getLadingTemplate(id);
        return success(LadingTemplateConvert.INSTANCE.convert(ladingTemplate));
    }

    @GetMapping("/getByLineId")
    @ApiOperation("获得提单模板")
    @ApiImplicitParam(name = "lineId", value = "路线ID", required = true, example = "1024", dataTypeClass = Long.class)
    //@PreAuthorize("@ss.hasPermission('ecw:lading-template:query')")
    public CommonResult<LadingTemplateBackVO> getLadingTemplateByLineId(@RequestParam("lineId") Long lineId) {
        LadingTemplateDO ladingTemplate = ladingTemplateService.getLadingTemplateByLineId(lineId);
        return success(LadingTemplateConvert.INSTANCE.convert(ladingTemplate));
    }

    @GetMapping("/list")
    @ApiOperation("获得提单模板列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    //@PreAuthorize("@ss.hasPermission('ecw:lading-template:query')")
    public CommonResult<List<LadingTemplateBackVO>> getLadingTemplateList(@RequestParam("ids") Collection<Long> ids) {
        List<LadingTemplateDO> list = ladingTemplateService.getLadingTemplateList(ids);
        return success(LadingTemplateConvert.INSTANCE.convertList(list));
    }

//    @GetMapping("/page")
//    @ApiOperation("获得提单模板分页")
//    //@PreAuthorize("@ss.hasPermission('ecw:lading-template:query')")
//    public CommonResult<PageResult<LadingTemplateBackVO>> getLadingTemplatePage(@Valid LadingTemplateQueryVO query, PageVO page) {
//        PageResult<LadingTemplateDO> pageResult = ladingTemplateService.getLadingTemplatePage(query, page);
//        return success(LadingTemplateConvert.INSTANCE.convertPage(pageResult));
//    }

//    @GetMapping("/export-excel")
//    @ApiOperation("导出提单模板 Excel")
//    //@PreAuthorize("@ss.hasPermission('ecw:lading-template:export')")
//    @OperateLog(type = EXPORT)
//    public void exportLadingTemplateExcel(@Valid LadingTemplateQueryVO query,
//              HttpServletResponse response) throws IOException {
//        List<LadingTemplateDO> list = ladingTemplateService.getLadingTemplateList(query);
//        // 导出 Excel
//        List<LadingTemplateBackVO> datas = LadingTemplateConvert.INSTANCE.convertList(list);
//        ExcelUtils.write(response, "提单模板.xls", "数据", LadingTemplateBackVO.class, datas);
//    }
}
