package cn.iocoder.yudao.module.ecw.controller.admin.orderCode;

import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;

import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

import cn.iocoder.yudao.framework.excel.util.ExcelUtils;

import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;

import cn.iocoder.yudao.module.ecw.controller.admin.orderCode.vo.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.orderCode.OrderCodeDO;
import cn.iocoder.yudao.module.ecw.convert.orderCode.OrderCodeConvert;
import cn.iocoder.yudao.module.ecw.service.orderCode.OrderCodeService;

@Api(tags = "管理后台 - 单号配置")
@RestController
@RequestMapping("/ecw/order-code")
@Validated
public class OrderCodeController {

    @Resource
    private OrderCodeService orderCodeService;

    @PostMapping("/create")
    @ApiOperation("创建单号配置")
    public CommonResult<Long> createOrderCode(@Valid @RequestBody OrderCodeCreateReqVO createReqVO) {
        return success(orderCodeService.createOrderCode(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新单号配置")
    public CommonResult<Boolean> updateOrderCode(@Valid @RequestBody OrderCodeUpdateReqVO updateReqVO) {
        orderCodeService.updateOrderCode(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除单号配置")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<Boolean> deleteOrderCode(@RequestParam("id") Long id) {
        orderCodeService.deleteOrderCode(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得单号配置")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<OrderCodeRespVO> getOrderCode(@RequestParam("id") Long id) {
        OrderCodeDO orderCode = orderCodeService.getOrderCode(id);
        return success(OrderCodeConvert.INSTANCE.convert(orderCode));
    }

    @GetMapping("/list")
    @ApiOperation("获得单号配置列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    public CommonResult<List<OrderCodeRespVO>> getOrderCodeList(@RequestParam("ids") Collection<Long> ids) {
        List<OrderCodeDO> list = orderCodeService.getOrderCodeList(ids);
        return success(OrderCodeConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得单号配置分页")
    public CommonResult<PageResult<OrderCodeRespVO>> getOrderCodePage(@Valid OrderCodePageReqVO pageVO) {
        PageResult<OrderCodeDO> pageResult = orderCodeService.getOrderCodePage(pageVO);
        return success(OrderCodeConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出单号配置 Excel")
    @OperateLog(type = EXPORT)
    public void exportOrderCodeExcel(@Valid OrderCodeExportReqVO exportReqVO,
              HttpServletResponse response) throws IOException {
        List<OrderCodeDO> list = orderCodeService.getOrderCodeList(exportReqVO);
        // 导出 Excel
        List<OrderCodeExcelVO> datas = OrderCodeConvert.INSTANCE.convertList02(list);
        ExcelUtils.write(response, "单号配置.xls", "数据", OrderCodeExcelVO.class, datas);
    }

}
