package cn.iocoder.yudao.module.ecw.controller.admin.paramValid;

import cn.hutool.core.util.StrUtil;
import cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.module.ecw.enums.ErrorCodeConstants;
import cn.iocoder.yudao.module.ecw.service.paramValid.ParamValidatorService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.apache.commons.lang3.StringUtils;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import static cn.iocoder.yudao.module.ecw.enums.ErrorCodeConstants.MOBILE_CODE_NOT_NULL;
import static cn.iocoder.yudao.module.ecw.enums.ErrorCodeConstants.MOBILE_NOT_NULL;


@Api(tags = "管理后台 - 参数格式校验")
@RestController
@RequestMapping("/param/validator")
@Validated
@AllArgsConstructor
public class ParamValidatorController {
    private final ParamValidatorService paramValidatorService;

    @RequestMapping("/mobile")
    @ApiOperation("校验手机号")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mobile", value = "手机号", example = "13033332222",  required = true, dataType = "String"),
            @ApiImplicitParam(name = "code", value = "国家区号", example = "86", required = true, dataType = "String")
    })
    public CommonResult<Boolean> validatorMobile(String mobile, String code) {
        if (StringUtils.isBlank(code)){
            return CommonResult.error(MOBILE_CODE_NOT_NULL);
        }
        if (StringUtils.isBlank(mobile)){
            return CommonResult.error(MOBILE_NOT_NULL);
        }
        try {
            paramValidatorService.validatorMobile(code + StrUtil.COLON + mobile);
        } catch (Exception e) {
            throw ServiceExceptionUtil.exception(ErrorCodeConstants.MOBILE_FORMAT_ERROR);
        }
        return CommonResult.success(true);
    }
}
