package cn.iocoder.yudao.module.ecw.controller.admin.pickupLoc;

import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;

import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

import cn.iocoder.yudao.framework.excel.util.ExcelUtils;

import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;

import cn.iocoder.yudao.module.ecw.controller.admin.pickupLoc.vo.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.pickupLoc.PickupLocDO;
import cn.iocoder.yudao.module.ecw.convert.pickupLoc.PickupLocConvert;
import cn.iocoder.yudao.module.ecw.service.pickupLoc.PickupLocService;

@Api(tags = "管理后台 - 自提点")
@RestController
@RequestMapping("/ecw/pickup-loc")
@Validated
public class PickupLocController {

    @Resource
    private PickupLocService pickupLocService;

    @PostMapping("/create")
    @ApiOperation("创建自提点")
    @PreAuthorize("@ss.hasPermission('ecw:pickup-loc:create')")
    public CommonResult<Long> createPickupLoc(@Valid @RequestBody PickupLocCreateReqVO createReqVO) {
        return success(pickupLocService.createPickupLoc(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新自提点")
    @PreAuthorize("@ss.hasPermission('ecw:pickup-loc:update')")
    public CommonResult<Boolean> updatePickupLoc(@Valid @RequestBody PickupLocUpdateReqVO updateReqVO) {
        pickupLocService.updatePickupLoc(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除自提点")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('ecw:pickup-loc:delete')")
    public CommonResult<Boolean> deletePickupLoc(@RequestParam("id") Long id) {
        pickupLocService.deletePickupLoc(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得自提点")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('ecw:pickup-loc:query')")
    public CommonResult<PickupLocRespVO> getPickupLoc(@RequestParam("id") Long id) {
        PickupLocDO pickupLoc = pickupLocService.getPickupLoc(id);
        return success(PickupLocConvert.INSTANCE.convert(pickupLoc));
    }

    @GetMapping("/list")
    @ApiOperation("获得自提点列表")
    @PreAuthorize("@ss.hasPermission('ecw:pickup-loc:query')")
    public CommonResult<List<PickupLocRespVO>> getPickupLocList(PickupLocExportReqVO req) {
        List<PickupLocDO> list = pickupLocService.getPickupLocList(req);
        return success(PickupLocConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得自提点分页")
    @PreAuthorize("@ss.hasPermission('ecw:pickup-loc:query')")
    public CommonResult<PageResult<PickupLocRespVO>> getPickupLocPage(@Valid PickupLocPageReqVO pageVO) {
        PageResult<PickupLocDO> pageResult = pickupLocService.getPickupLocPage(pageVO);
        return success(PickupLocConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出自提点 Excel")
    @PreAuthorize("@ss.hasPermission('ecw:pickup-loc:export')")
    @OperateLog(type = EXPORT)
    public void exportPickupLocExcel(@Valid PickupLocExportReqVO exportReqVO,
              HttpServletResponse response) throws IOException {
        List<PickupLocDO> list = pickupLocService.getPickupLocList(exportReqVO);
        // 导出 Excel
        List<PickupLocExcelVO> datas = PickupLocConvert.INSTANCE.convertList02(list);
        ExcelUtils.write(response, "自提点.xls", "数据", PickupLocExcelVO.class, datas);
    }

}
