package cn.iocoder.yudao.module.ecw.controller.admin.setting;

import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;

import javax.validation.*;
import java.util.*;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

import cn.iocoder.yudao.module.ecw.controller.admin.setting.vo.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.setting.SettingDO;
import cn.iocoder.yudao.module.ecw.convert.setting.SettingConvert;
import cn.iocoder.yudao.module.ecw.service.setting.SettingService;

@Api(tags = "管理后台 - 全局配置")
@RestController
@RequestMapping("/ecw/setting")
@Validated
public class SettingController {

    @Resource
    private SettingService settingService;

    @PostMapping("/create")
    @ApiOperation("创建全局配置")
    @PreAuthorize("@ss.hasPermission('ecw:setting:create')")
    public CommonResult<String> createSetting(@Valid @RequestBody SettingCreateReqVO createReqVO) {
        settingService.createSetting(createReqVO);
        return success("添加成功");
    }


    @PostMapping("/list")
    @ApiOperation("获得全局配置列表")
    @ApiImplicitParam(name = "settingBaseVO", value = "SettingBaseVO", required = true,  dataTypeClass = SettingBaseVO.class)
    @PreAuthorize("@ss.hasPermission('ecw:setting:query')")
    public CommonResult<List<SettingBaseVO>> getSettingList(@RequestBody SettingBaseVO settingBaseVO) {
        List<SettingDO> list = settingService.getSettingList(settingBaseVO);
        return success(SettingConvert.INSTANCE.convertList(list));
    }


}
