package cn.iocoder.yudao.module.ecw.controller.admin.supplier;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import cn.iocoder.yudao.module.ecw.controller.admin.supplier.vo.*;
import cn.iocoder.yudao.module.ecw.convert.supplier.SupplierBankConvert;
import cn.iocoder.yudao.module.ecw.convert.supplier.SupplierContactsConvert;
import cn.iocoder.yudao.module.ecw.convert.supplier.SupplierConvert;
import cn.iocoder.yudao.module.ecw.dal.dataobject.supplier.SupplierBankDO;
import cn.iocoder.yudao.module.ecw.dal.dataobject.supplier.SupplierContactsDO;
import cn.iocoder.yudao.module.ecw.dal.dataobject.supplier.SupplierDO;
import cn.iocoder.yudao.module.ecw.service.supplier.SupplierBankService;
import cn.iocoder.yudao.module.ecw.service.supplier.SupplierContactsService;
import cn.iocoder.yudao.module.ecw.service.supplier.SupplierService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.util.Collection;
import java.util.List;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.EXPORT;
import static cn.iocoder.yudao.module.ecw.enums.ErrorCodeConstants.SUPPLIER_NOT_EXISTS;

@Api(tags = "管理后台 - 提单托运人")
@RestController
@RequestMapping("/ecw/lading-shipper")
@Validated
public class LadingShipperController {

    @Resource
    private SupplierService supplierService;

    @PostMapping("/create")
    @ApiOperation("创建提单托运人")
//    @PreAuthorize("@ss.hasPermission('ecw:lading-shipper:create')")
    public CommonResult<Long> createLadingShipper(@Valid @RequestBody LadingShipperCreateReqVO createReqVO) {
        return success(supplierService.createLadingShipper(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新提单托运人")
//    @PreAuthorize("@ss.hasPermission('ecw:lading-shipper:update')")
    public CommonResult<Boolean> updateLadingShipper(@Valid @RequestBody LadingShipperUpdateReqVO updateReqVO) {
        supplierService.updateLadingShipper(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除提单托运人")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
//    @PreAuthorize("@ss.hasPermission('ecw:lading-shipper:delete')")
    public CommonResult<Boolean> deleteLadingShipper(@RequestParam("id") Long id) {
        supplierService.deleteLadingShipper(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得提单托运人")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
//    @PreAuthorize("@ss.hasPermission('ecw:lading-shipper:query')")
    public CommonResult<LadingShipperRespVO> getSupplier(@RequestParam("id") Long id) {
        SupplierDO supplier = supplierService.getSupplier(id);
        LadingShipperRespVO respVO = SupplierConvert.INSTANCE.convertLadingShipper(supplier);
        return success(respVO);
    }

    @GetMapping("/page")
    @ApiOperation("获得提单托运人分页")
//    @PreAuthorize("@ss.hasPermission('ecw:lading-shipper:query')")
    public CommonResult<PageResult<SupplierRespVO>> getLadingShipperPage(@Valid LadingShipperPageReqVO pageVO) {
        PageResult<SupplierDO> pageResult = supplierService.getLadingShipperPage(pageVO);
        return success(SupplierConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出提单托运人 Excel")
//    @PreAuthorize("@ss.hasPermission('ecw:lading-shipper:export')")
    @OperateLog(type = EXPORT)
    public void exportSupplierExcel(@Valid LadingShipperExportReqVO exportReqVO,
              HttpServletResponse response) throws IOException {
        List<SupplierDO> list = supplierService.getLadingShipperList(exportReqVO);
        // 导出 Excel
        List<LadingShipperExcelVO> datas = SupplierConvert.INSTANCE.convertList03(list);
        ExcelUtils.write(response, "提单托运人.xls", "数据", LadingShipperExcelVO.class, datas);
    }

}
