package cn.iocoder.yudao.module.ecw.controller.admin.supplier;

import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;

import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

import cn.iocoder.yudao.framework.excel.util.ExcelUtils;

import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;

import cn.iocoder.yudao.module.ecw.controller.admin.supplier.vo.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.supplier.SupplierDO;
import cn.iocoder.yudao.module.ecw.convert.supplier.SupplierConvert;
import cn.iocoder.yudao.module.ecw.service.supplier.SupplierService;

@Api(tags = "管理后台 - 供应商")
@RestController
@RequestMapping("/ecw/supplier")
@Validated
public class SupplierController {

    @Resource
    private SupplierService supplierService;

    @PostMapping("/create")
    @ApiOperation("创建供应商")
    @PreAuthorize("@ss.hasPermission('ecw:supplier:create')")
    public CommonResult<Long> createSupplier(@Valid @RequestBody SupplierCreateReqVO createReqVO) {
        return success(supplierService.createSupplier(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新供应商")
    @PreAuthorize("@ss.hasPermission('ecw:supplier:update')")
    public CommonResult<Boolean> updateSupplier(@Valid @RequestBody SupplierUpdateReqVO updateReqVO) {
        supplierService.updateSupplier(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除供应商")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('ecw:supplier:delete')")
    public CommonResult<Boolean> deleteSupplier(@RequestParam("id") Long id) {
        supplierService.deleteSupplier(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得供应商")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
//    @PreAuthorize("@ss.hasPermission('ecw:supplier:query')")
    public CommonResult<SupplierRespVO> getSupplier(@RequestParam("id") Long id) {
        return success(supplierService.getSupplierDetail(id));
    }

    @GetMapping("/list")
    @ApiOperation("获得供应商列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
//    @PreAuthorize("@ss.hasPermission('ecw:supplier:query')")
    public CommonResult<List<SupplierRespVO>> getSupplierList(@RequestParam("ids") Collection<Long> ids) {
        List<SupplierDO> list = supplierService.getSupplierList(ids);
        return success(SupplierConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得供应商分页")
//    @PreAuthorize("@ss.hasPermission('ecw:supplier:query')")
    public CommonResult<PageResult<SupplierRespVO>> getSupplierPage(@Valid SupplierPageReqVO pageVO) {
        PageResult<SupplierDO> pageResult = supplierService.getSupplierPage(pageVO);
        PageResult<SupplierRespVO> respResult = SupplierConvert.INSTANCE.convertPage(pageResult);
        supplierService.matchExtraInfo(respResult);
        return success(respResult);
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出供应商 Excel")
    @PreAuthorize("@ss.hasPermission('ecw:supplier:export')")
    @OperateLog(type = EXPORT)
    public void exportSupplierExcel(@Valid SupplierExportReqVO exportReqVO,
              HttpServletResponse response) throws IOException {
        List<SupplierDO> list = supplierService.getSupplierList(exportReqVO);
        // 导出 Excel
        List<SupplierExcelVO> datas = SupplierConvert.INSTANCE.convertList02(list);
        ExcelUtils.write(response, "供应商.xls", "数据", SupplierExcelVO.class, datas);
    }

}
