package cn.iocoder.yudao.module.ecw.controller.admin.supplier.vo;

import cn.iocoder.yudao.module.ecw.controller.admin.supplier.vo.supplierResource.SupplierResourceCreateReqVO;
import lombok.*;
import java.util.*;
import io.swagger.annotations.*;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.Valid;
import javax.validation.constraints.*;

import static cn.iocoder.yudao.framework.common.util.date.DateUtils.FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND;

/**
* 供应商 Base VO，提供给添加、修改、详细的子 VO 使用
* 如果子 VO 存在差异的字段，请不要添加到这里，影响 Swagger 文档生成
*/
@Data
public class SupplierBaseVO {

    @ApiModelProperty(value = "公司名称", required = true)
    @NotEmpty(message = "公司名称不能为空")
    private String companyZh;

    @ApiModelProperty(value = "英文名称")
    private String companyEn;

    @ApiModelProperty(value = "供应商代码")
    private String companyCode;

    @ApiModelProperty(value = "代理商名称")
    private String agentName;

    @ApiModelProperty(value = "公司电话")
    private String tell;

    @ApiModelProperty(value = "国家")
    private Long country;

    @ApiModelProperty(value = "省")
    private Long province;

    @ApiModelProperty(value = "市")
    private Long city;

    @ApiModelProperty(value = "详细地址")
    private String area;

    @ApiModelProperty(value = "省市区+详细地址")
    private String address;

    @ApiModelProperty(value = "备注")
    private String remark;

    @ApiModelProperty(value = "供应商类别", required = true)
//    @NotEmpty(message = "供应商类别不能为空")
    private String companyType;

    @ApiModelProperty(value = "合作类型", required = true)
    @NotNull(message = "合作类型不能为空")
    private Integer cooperationType;

    @ApiModelProperty(value = "营业执照")
    private String license;

    @ApiModelProperty(value = "合同")
    private String contract;

    @ApiModelProperty(value = "社会信用统一代码")
    private String licenseNumber;

    @ApiModelProperty(value = "合作开始时间")
    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    private Date cooperationDateStart;

    @ApiModelProperty(value = "合作结束时间")
    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    private Date cooperationDateEnd;

    @ApiModelProperty(value = "邮件地址")
    private String email;

    @ApiModelProperty(value = "是否展示 默认为展示")
    private Integer status;

    @ApiModelProperty(value = "0-國内供應商，1-國外供應商")
    @NotNull(message = "供应商类型areaType不能为空")
    private Integer areaType;

    @ApiModelProperty(value = "结算周期，字典settlement_period")
    private Integer settlementPeriod;

    @ApiModelProperty(value = "结算周期，字典price_advantage")
    private Integer priceAdvantage;

    @ApiModelProperty(value = "供应商公司竞争，0-关闭，1-开启")
    private Integer companyCompete;

    @ApiModelProperty(value = "竞争渠道，1-海运，2-空运")
    private Integer competeChannel;

    @ApiModelProperty(value = "供应商银行信息")
    @Valid
    private List<SupplierBankBaseVO> bankList;

    @ApiModelProperty(value = "供应商联系人信息")
    @Valid
    private List<SupplierContactsBaseVO> contactList;

    @ApiModelProperty(value = "供应商港口码头id列表，多个以逗号连接")
    private String dockIds;

}
