package cn.iocoder.yudao.module.ecw.controller.admin.unit;

import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;

import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

import cn.iocoder.yudao.framework.excel.util.ExcelUtils;

import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;

import cn.iocoder.yudao.module.ecw.controller.admin.unit.vo.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.unit.UnitDO;
import cn.iocoder.yudao.module.ecw.convert.unit.UnitConvert;
import cn.iocoder.yudao.module.ecw.service.unit.UnitService;

@Api(tags = "管理后台 - 计量单位")
@RestController
@RequestMapping("/ecw/unit")
@Validated
public class UnitController {

    @Resource
    private UnitService unitService;

    @PostMapping("/create")
    @ApiOperation("创建计量单位")
    @PreAuthorize("@ss.hasPermission('ecw:unit:create')")
    public CommonResult<Integer> createUnit(@Valid @RequestBody UnitCreateReqVO createReqVO) {
        return success(unitService.createUnit(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新计量单位")
    @PreAuthorize("@ss.hasPermission('ecw:unit:update')")
    public CommonResult<Boolean> updateUnit(@Valid @RequestBody UnitUpdateReqVO updateReqVO) {
        unitService.updateUnit(updateReqVO);
        return success(true);
    }


    @PutMapping("/updateStatus")
    @ApiOperation("更新计量单位")
    @PreAuthorize("@ss.hasPermission('ecw:unit:update')")
    public CommonResult<Boolean> updateUnitStatus(@Valid @RequestBody UnitUpdateStatusReqVO updateReqVO) {
        unitService.updateUnitStatus(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除计量单位")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Integer.class)
    @PreAuthorize("@ss.hasPermission('ecw:unit:delete')")
    public CommonResult<Boolean> deleteUnit(@RequestParam("id") Integer id) {
        unitService.deleteUnit(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得计量单位")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Integer.class)
//    @PreAuthorize("@ss.hasPermission('ecw:unit:query')")
    public CommonResult<UnitRespVO> getUnit(@RequestParam("id") Integer id) {
        UnitDO unit = unitService.getUnit(id);
        return success(UnitConvert.INSTANCE.convert(unit));
    }

    @GetMapping("/list")
    @ApiOperation("获得计量单位列表")
//    @PreAuthorize("@ss.hasPermission('ecw:unit:query')")
    public CommonResult<List<UnitRespVO>> getUnitList() {
        List<UnitDO> list = unitService.getUnitList();
        return success(UnitConvert.INSTANCE.convertList(list));
    }

//    @GetMapping("/list")
//    @ApiOperation("获得有效的计量单位列表")
//    @PreAuthorize("@ss.hasPermission('ecw:unit:query')")
//    public CommonResult<List<UnitRespVO>> getUnitList() {
//        List<UnitDO> list = unitService.getUnitList();
//        return success(UnitConvert.INSTANCE.convertList(list));
//    }

    @GetMapping("/page")
    @ApiOperation("获得计量单位分页")
//    @PreAuthorize("@ss.hasPermission('ecw:unit:query')")
    public CommonResult<PageResult<UnitRespVO>> getUnitPage(@Valid UnitPageReqVO pageVO) {
        PageResult<UnitDO> pageResult = unitService.getUnitPage(pageVO);
        return success(UnitConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出计量单位 Excel")
    @PreAuthorize("@ss.hasPermission('ecw:unit:export')")
    @OperateLog(type = EXPORT)
    public void exportUnitExcel(@Valid UnitExportReqVO exportReqVO,
              HttpServletResponse response) throws IOException {
        List<UnitDO> list = unitService.getUnitList(exportReqVO);
        // 导出 Excel
        List<UnitExcelVO> datas = UnitConvert.INSTANCE.convertList02(list);
        ExcelUtils.write(response, "计量单位.xls", "数据", UnitExcelVO.class, datas);
    }

}
