package cn.iocoder.yudao.module.ecw.controller.app.appClient;

import cn.iocoder.yudao.framework.idempotent.core.annotation.Idempotent;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.security.core.annotations.PreAuthenticated;
import cn.iocoder.yudao.framework.web.core.util.WebFrameworkUtils;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import io.swagger.annotations.*;

import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;
import cn.iocoder.yudao.module.ecw.vo.adminClient.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.adminClient.AdminClientDO;
import cn.iocoder.yudao.module.ecw.convert.adminClient.AdminClientConvert;
import cn.iocoder.yudao.module.ecw.service.adminClient.AdminClientService;

@Validated
@RestController
@Api(tags = "客户端 - 我的客户")
@RequestMapping("/ecw/admin-client")
public class AppClientController {

    @Resource
    private AdminClientService adminClientService;

    @PostMapping("/create")
    @ApiOperation("创建我的客户")
    @PreAuthenticated
    @Idempotent(timeout = 5)
    public CommonResult<Long> createAdminClient(@Valid @RequestBody AdminClientCreateReqVO createReqVO) {
        createReqVO.setUid(WebFrameworkUtils.getLoginUserId());
        return success(adminClientService.createAdminClient(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新我的客户")
    @PreAuthenticated
    @Idempotent(timeout = 5)
    public CommonResult<Boolean> updateAdminClient(@Valid @RequestBody AdminClientUpdateReqVO updateReqVO) {
        adminClientService.updateAdminClient(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除我的客户")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthenticated
    @Idempotent(timeout = 5)
    public CommonResult<Boolean> deleteAdminClient(@RequestParam("id") Long id) {
        adminClientService.deleteAdminClient(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得我的客户")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthenticated
    public CommonResult<AdminClientBackVO> getAdminClient(@RequestParam("id") Long id) {
        AdminClientDO adminClient = adminClientService.getAdminClient(id);
        return success(AdminClientConvert.INSTANCE.convert(adminClient));
    }

    @GetMapping("/list")
    @ApiOperation("获得我的客户列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    @PreAuthenticated
    public CommonResult<List<AdminClientBackVO>> getAdminClientList(@RequestParam("ids") Collection<Long> ids) {
        List<AdminClientDO> list = adminClientService.getAdminClientList(ids);
        return success(AdminClientConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得我的客户分页")
    @PreAuthenticated
    public CommonResult<PageResult<AdminClientBackVO>> getAdminClientPage(@Valid AdminClientQueryVO query, PageVO page) {
        query.setUid(WebFrameworkUtils.getLoginUserId());
        PageResult<AdminClientDO> pageResult = adminClientService.getAdminClientPage(query, page);
        return success(AdminClientConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出我的客户 Excel")
    @PreAuthenticated
    @OperateLog(type = EXPORT)
    public void exportAdminClientExcel(@Valid AdminClientQueryVO query,
              HttpServletResponse response) throws IOException {
        List<AdminClientDO> list = adminClientService.getAdminClientList(query);
        // 导出 Excel
        List<AdminClientBackVO> datas = AdminClientConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "我的客户.xls", "数据", AdminClientBackVO.class, datas);
    }
}
