package cn.iocoder.yudao.module.ecw.controller.app.appClientType;

import cn.iocoder.yudao.framework.idempotent.core.annotation.Idempotent;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.security.core.annotations.PreAuthenticated;
import cn.iocoder.yudao.framework.web.core.util.WebFrameworkUtils;
import cn.iocoder.yudao.module.ecw.convert.adminClientType.AdminClientTypeConvert;
import cn.iocoder.yudao.module.ecw.dal.dataobject.adminClientType.AdminClientTypeDO;
import cn.iocoder.yudao.module.ecw.service.adminClientType.AdminClientTypeService;
import cn.iocoder.yudao.module.ecw.vo.adminClientType.AdminClientTypeBackVO;
import cn.iocoder.yudao.module.ecw.vo.adminClientType.AdminClientTypeCreateReqVO;
import cn.iocoder.yudao.module.ecw.vo.adminClientType.AdminClientTypeQueryVO;
import cn.iocoder.yudao.module.ecw.vo.adminClientType.AdminClientTypeUpdateReqVO;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import io.swagger.annotations.*;

import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;
@Validated
@RestController
@Api(tags = "客户端 - 我的客户分组")
@RequestMapping("/ecw/admin-client-type")
public class AppClientTypeController {

    @Resource
    private AdminClientTypeService adminClientTypeService;

    @PostMapping("/create")
    @ApiOperation("创建我的客户分组")
    @PreAuthenticated
    @Idempotent(timeout = 5)
    public CommonResult<Integer> createAdminClientType(@Valid @RequestBody AdminClientTypeCreateReqVO createReqVO) {
        createReqVO.setUid(WebFrameworkUtils.getLoginUserId().intValue());
        return success(adminClientTypeService.createAdminClientType(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新我的客户分组")
    @PreAuthenticated
    @Idempotent(timeout = 5)
    public CommonResult<Boolean> updateAdminClientType(@Valid @RequestBody AdminClientTypeUpdateReqVO updateReqVO) {
        adminClientTypeService.updateAdminClientType(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除我的客户分组")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Integer.class)
    @PreAuthenticated
    @Idempotent(timeout = 5)
    public CommonResult<Boolean> deleteAdminClientType(@RequestParam("id") Integer id) {
        adminClientTypeService.deleteAdminClientType(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得我的客户分组")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Integer.class)
    @PreAuthenticated
    public CommonResult<AdminClientTypeBackVO> getAdminClientType(@RequestParam("id") Integer id) {
        AdminClientTypeDO adminClientType = adminClientTypeService.getAdminClientType(id);
        return success(AdminClientTypeConvert.INSTANCE.convert(adminClientType));
    }

    @GetMapping("/list")
    @ApiOperation("获得我的客户分组列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    @PreAuthenticated
    public CommonResult<List<AdminClientTypeBackVO>> getAdminClientTypeList(@RequestParam("ids") Collection<Integer> ids) {
        List<AdminClientTypeDO> list = adminClientTypeService.getAdminClientTypeList(ids);
        return success(AdminClientTypeConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得我的客户分组分页")
    @PreAuthenticated
    public CommonResult<PageResult<AdminClientTypeBackVO>> getAdminClientTypePage(@Valid AdminClientTypeQueryVO query, PageVO page) {
        query.setUid(WebFrameworkUtils.getLoginUserId().intValue());
        PageResult<AdminClientTypeDO> pageResult = adminClientTypeService.getAdminClientTypePage(query, page);
        return success(AdminClientTypeConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出我的客户分组 Excel")
    @PreAuthenticated
    @OperateLog(type = EXPORT)
    public void exportAdminClientTypeExcel(@Valid AdminClientTypeQueryVO query,
              HttpServletResponse response) throws IOException {
        query.setUid(WebFrameworkUtils.getLoginUserId().intValue());
        List<AdminClientTypeDO> list = adminClientTypeService.getAdminClientTypeList(query);
        // 导出 Excel
        List<AdminClientTypeBackVO> datas = AdminClientTypeConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "我的客户分组.xls", "数据", AdminClientTypeBackVO.class, datas);
    }
}
