package cn.iocoder.yudao.module.ecw.controller.app.appClienta;

import cn.iocoder.yudao.framework.idempotent.core.annotation.Idempotent;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.security.core.annotations.PreAuthenticated;
import cn.iocoder.yudao.framework.web.core.util.WebFrameworkUtils;
import cn.iocoder.yudao.module.ecw.convert.adminClienta.AdminClientaConvert;
import cn.iocoder.yudao.module.ecw.dal.dataobject.adminClienta.AdminClientaDO;
import cn.iocoder.yudao.module.ecw.service.adminClienta.AdminClientaService;
import cn.iocoder.yudao.module.ecw.vo.adminClienta.AdminClientaBackVO;
import cn.iocoder.yudao.module.ecw.vo.adminClienta.AdminClientaCreateReqVO;
import cn.iocoder.yudao.module.ecw.vo.adminClienta.AdminClientaQueryVO;
import cn.iocoder.yudao.module.ecw.vo.adminClienta.AdminClientaUpdateReqVO;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import io.swagger.annotations.*;

import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;

@Validated
@RestController
@Api(tags = "客户端 - 我的供应商")
@RequestMapping("/ecw/admin-clienta")
public class AppClientaController {

    @Resource
    private AdminClientaService adminClientaService;

    @PostMapping("/create")
    @ApiOperation("创建我的供应商")
    @PreAuthenticated
    @Idempotent(timeout = 5)
    public CommonResult<Long> createAdminClienta(@Valid @RequestBody AdminClientaCreateReqVO createReqVO) {
        Long uid = WebFrameworkUtils.getLoginUserId();
        createReqVO.setUid(uid);
        return success(adminClientaService.createAdminClienta(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新我的供应商")
    @PreAuthenticated
    @Idempotent(timeout = 5)
    public CommonResult<Boolean> updateAdminClienta(@Valid @RequestBody AdminClientaUpdateReqVO updateReqVO) {
        adminClientaService.updateAdminClienta(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除我的供应商")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthenticated
    @Idempotent(timeout = 5)
    public CommonResult<Boolean> deleteAdminClienta(@RequestParam("id") Long id) {
        adminClientaService.deleteAdminClienta(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得我的供应商")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthenticated
    public CommonResult<AdminClientaBackVO> getAdminClienta(@RequestParam("id") Long id) {
        AdminClientaDO adminClienta = adminClientaService.getAdminClienta(id);
        return success(AdminClientaConvert.INSTANCE.convert(adminClienta));
    }

    @GetMapping("/list")
    @ApiOperation("获得我的供应商列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    @PreAuthenticated
    public CommonResult<List<AdminClientaBackVO>> getAdminClientaList(@RequestParam("ids") Collection<Long> ids) {
        List<AdminClientaDO> list = adminClientaService.getAdminClientaList(ids);
        return success(AdminClientaConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得我的供应商分页")
    @PreAuthenticated
    public CommonResult<PageResult<AdminClientaBackVO>> getAdminClientaPage(@Valid AdminClientaQueryVO query, PageVO page) {
        Long uid = WebFrameworkUtils.getLoginUserId();
        query.setUid(uid);
        PageResult<AdminClientaDO> pageResult = adminClientaService.getAdminClientaPage(query, page);
        return success(AdminClientaConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出我的供应商 Excel")
    @PreAuthenticated
    @OperateLog(type = EXPORT)
    public void exportAdminClientaExcel(@Valid AdminClientaQueryVO query,
              HttpServletResponse response) throws IOException {
        query.setUid(WebFrameworkUtils.getLoginUserId());
        List<AdminClientaDO> list = adminClientaService.getAdminClientaList(query);
        // 导出 Excel
        List<AdminClientaBackVO> datas = AdminClientaConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "我的供应商.xls", "数据", AdminClientaBackVO.class, datas);
    }
}
