package cn.iocoder.yudao.module.ecw.controller.app.appClientaType;

import cn.iocoder.yudao.framework.idempotent.core.annotation.Idempotent;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.security.core.annotations.PreAuthenticated;
import cn.iocoder.yudao.framework.web.core.util.WebFrameworkUtils;
import cn.iocoder.yudao.module.ecw.dal.dataobject.adminClientaType.AdminClientaTypeDO;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import io.swagger.annotations.*;

import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;
import cn.iocoder.yudao.module.ecw.vo.adminClientaType.*;
import cn.iocoder.yudao.module.ecw.convert.adminClientaType.AdminClientaTypeConvert;
import cn.iocoder.yudao.module.ecw.service.adminClientaType.AdminClientaTypeService;

@Validated
@RestController
@Api(tags = "客户端 - 我的供应商分组")
@RequestMapping("/ecw/admin-clienta-type")
public class AppClientaTypeController {

    @Resource
    private AdminClientaTypeService adminClientaTypeService;

    @PostMapping("/create")
    @ApiOperation("创建我的供应商分组")
    @PreAuthenticated
    @Idempotent(timeout = 5)
    public CommonResult<Long> createAdminClientaType(@Valid @RequestBody AdminClientaTypeCreateReqVO createReqVO) {
        Long uid = WebFrameworkUtils.getLoginUserId();
        createReqVO.setUid(uid);
        return success(adminClientaTypeService.createAdminClientaType(createReqVO));
    }

    @PutMapping("/update")
    @ApiOperation("更新我的供应商分组")
    @PreAuthenticated
    @Idempotent(timeout = 5)
    public CommonResult<Boolean> updateAdminClientaType(@Valid @RequestBody AdminClientaTypeUpdateReqVO updateReqVO) {
        adminClientaTypeService.updateAdminClientaType(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除我的供应商分组")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthenticated
    @Idempotent(timeout = 5)
    public CommonResult<Boolean> deleteAdminClientaType(@RequestParam("id") Long id) {
        adminClientaTypeService.deleteAdminClientaType(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得我的供应商分组")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthenticated
    public CommonResult<AdminClientaTypeBackVO> getAdminClientaType(@RequestParam("id") Long id) {
        AdminClientaTypeDO adminClientaType = adminClientaTypeService.getAdminClientaType(id);
        return success(AdminClientaTypeConvert.INSTANCE.convert(adminClientaType));
    }

    @GetMapping("/list")
    @ApiOperation("获得我的供应商分组列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    @PreAuthenticated
    public CommonResult<List<AdminClientaTypeBackVO>> getAdminClientaTypeList(@RequestParam("ids") Collection<Long> ids) {
        List<AdminClientaTypeDO> list = adminClientaTypeService.getAdminClientaTypeList(ids);
        return success(AdminClientaTypeConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得我的供应商分组分页")
    @PreAuthenticated
    public CommonResult<PageResult<AdminClientaTypeBackVO>> getAdminClientaTypePage(@Valid AdminClientaTypeQueryVO query, PageVO page) {
        Long uid = WebFrameworkUtils.getLoginUserId();
        query.setUid(uid);
        PageResult<AdminClientaTypeDO> pageResult = adminClientaTypeService.getAdminClientaTypePage(query, page);
        return success(AdminClientaTypeConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出我的供应商分组 Excel")
    @PreAuthenticated
    @OperateLog(type = EXPORT)
    public void exportAdminClientaTypeExcel(@Valid AdminClientaTypeQueryVO query,
              HttpServletResponse response) throws IOException {
        Long uid = WebFrameworkUtils.getLoginUserId();
        query.setUid(uid);
        List<AdminClientaTypeDO> list = adminClientaTypeService.getAdminClientaTypeList(query);
        // 导出 Excel
        List<AdminClientaTypeBackVO> datas = AdminClientaTypeConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "我的供应商分组.xls", "数据", AdminClientaTypeBackVO.class, datas);
    }
}
