package cn.iocoder.yudao.module.ecw.controller.app.country;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import cn.iocoder.yudao.module.ecw.convert.country.CountryConvert;
import cn.iocoder.yudao.module.ecw.dal.dataobject.country.CountryDO;
import cn.iocoder.yudao.module.ecw.service.country.CountryService;
import cn.iocoder.yudao.module.ecw.vo.country.CountryBackVO;
import cn.iocoder.yudao.module.ecw.vo.country.CountryCreateReqVO;
import cn.iocoder.yudao.module.ecw.vo.country.CountryQueryVO;
import cn.iocoder.yudao.module.ecw.vo.country.CountryUpdateReqVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.util.Collection;
import java.util.List;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.EXPORT;

@Validated
@RestController
@Api(tags = "客户端 - 国家区号")
@RequestMapping("/ecw/country")
public class AppCountryController {

    @Resource
    private CountryService countryService;


    @GetMapping("/get")
    @ApiOperation("获得国家区号")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<CountryBackVO> getCountry(@RequestParam("id") Long id) {
        CountryDO country = countryService.getCountry(id);
        return success(CountryConvert.INSTANCE.convert(country));
    }

    @GetMapping("/list")
    @ApiOperation("获得国家区号列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    public CommonResult<List<CountryBackVO>> getCountryList(@RequestParam("ids") Collection<Long> ids) {
        List<CountryDO> list = countryService.getCountryList(ids);
        return success(CountryConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/list-all")
    @ApiOperation("获得所有国家区号列表")
    public CommonResult<List<CountryBackVO>> getCountryListAll() {
        List<CountryDO> list = countryService.getCountryList(new CountryQueryVO());
        return success(CountryConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得国家区号分页")
    public CommonResult<PageResult<CountryBackVO>> getCountryPage(@Valid CountryQueryVO query, PageVO page) {
        PageResult<CountryDO> pageResult = countryService.getCountryPage(query, page);
        return success(CountryConvert.INSTANCE.convertPage(pageResult));
    }
}
