package cn.iocoder.yudao.module.ecw.controller.app.currencyEcash;

import cn.hutool.core.collection.CollectionUtil;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.dict.core.dto.DictDataRespDTO;
import cn.iocoder.yudao.framework.dict.core.util.DictFrameworkUtils;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import cn.iocoder.yudao.framework.security.core.annotations.PreAuthenticated;
import cn.iocoder.yudao.module.ecw.controller.admin.currencyEcash.vo.*;
import cn.iocoder.yudao.module.ecw.convert.currencyEcash.CurrencyEcashConvert;
import cn.iocoder.yudao.module.ecw.dal.dataobject.currencyEcash.CurrencyEcashDO;
import cn.iocoder.yudao.module.ecw.service.currencyEcash.CurrencyEcashService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.util.*;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.EXPORT;

@Api(tags = "客户端 - E-Cash汇率单位")
@RestController
@RequestMapping("/ecw/currency-ecash")
@Validated
public class AppCurrencyEcashController {

    @Resource
    private CurrencyEcashService currencyEcashService;

    @PostMapping("/create")
    @ApiOperation("创建E-Cash汇率单位")
    @PreAuthenticated
    public CommonResult<Integer> createCurrencyEcash(@Valid @RequestBody CurrencyEcashCreateReqVO createReqVO) throws Exception {
        return success(currencyEcashService.createCurrencyEcash(createReqVO));
    }

    @PutMapping("/updateBatch")
    @ApiOperation("批量更新E-Cash汇率单位")
    @PreAuthenticated
    public CommonResult<Boolean> batchUpdateCurrencyEcash(@Valid @RequestBody List<CurrencyEcashUpdateReqVO> updateReqVO) {
        currencyEcashService.batchUpdateCurrencyEcash(updateReqVO);
        return success(true);
    }

    @PutMapping("/update")
    @ApiOperation("更新E-Cash汇率单位")
    @PreAuthenticated
    public CommonResult<Boolean> updateCurrencyEcash(@Valid @RequestBody CurrencyEcashUpdateReqVO updateReqVO) {
        currencyEcashService.updateCurrencyEcash(updateReqVO);
        return success(true);
    }

    @PutMapping("/updateAll")
    @ApiOperation("更新E-Cash汇率单位ALL")
    @PreAuthenticated
    public CommonResult<Boolean> updateCurrencyEcashAll(@RequestBody CurrencyEcashDO currencyEcashDO) {
        currencyEcashService.updateCurrencyEcashAll(currencyEcashDO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除E-Cash汇率单位")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Integer.class)
    @PreAuthenticated
    public CommonResult<Boolean> deleteCurrencyEcash(@RequestParam("id") Integer id) {
        currencyEcashService.deleteCurrencyEcash(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得E-Cash汇率单位")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Integer.class)
    @PreAuthenticated
    public CommonResult<CurrencyEcashRespVO> getCurrencyEcash(@RequestParam("id") Integer id) {
        CurrencyEcashDO currencyEcash = currencyEcashService.getCurrencyEcash(id);
        return success(CurrencyEcashConvert.INSTANCE.convert(currencyEcash));
    }

   /* @GetMapping("/list")
    @ApiOperation("获得E-Cash汇率单位列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    @PreAuthenticated
    public CommonResult<List<CurrencyEcashRespVO>> getCurrencyEcashList(@RequestParam("ids") Collection<Integer> ids) {
        List<CurrencyEcashDO> list = currencyEcashService.getCurrencyEcashList(ids);
        return success(CurrencyEcashConvert.INSTANCE.convertList(list));
    }*/

    @GetMapping("/list")
    @ApiOperation("获得E-Cash汇率单位列表")
//    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    @PreAuthenticated
    public CommonResult<List<CurrencyEcashDO>> getCurrencyEcashList() {
        List<CurrencyEcashDO> list = currencyEcashService.getAllCurrency();
        return success(list);
    }

    @GetMapping("/page")
    @ApiOperation("获得E-Cash汇率单位分页")
//    @PreAuthenticated
    public CommonResult<PageResult<CurrencyEcashRespVO>> getCurrencyEcashPage(@Valid CurrencyEcashPageReqVO pageVO) {
        PageResult<CurrencyEcashDO> pageResult = currencyEcashService.getCurrencyEcashPage(pageVO);
        PageResult<CurrencyEcashRespVO> result = CurrencyEcashConvert.INSTANCE.convertPage(pageResult);
        List<CurrencyEcashRespVO> list = result.getList();
        Date currentTime = new Date();
        if(CollectionUtil.isNotEmpty(list)) {
            list.forEach(t -> t.setCurrentTime(currentTime));
        }
        return success(result);
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出E-Cash汇率单位 Excel")
    @PreAuthenticated
    @OperateLog(type = EXPORT)
    public void exportCurrencyEcashExcel(@Valid CurrencyEcashExportReqVO exportReqVO,
              HttpServletResponse response) throws IOException {
        List<CurrencyEcashDO> list = currencyEcashService.getCurrencyEcashList(exportReqVO);
        // 导出 Excel
        List<CurrencyEcashExcelVO> datas = CurrencyEcashConvert.INSTANCE.convertList02(list);
        ExcelUtils.write(response, "E-Cash汇率单位.xls", "数据", CurrencyEcashExcelVO.class, datas);
    }

}
