package cn.iocoder.yudao.module.ecw.controller.app.messageLeave;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import cn.iocoder.yudao.framework.security.core.annotations.PreAuthenticated;
import cn.iocoder.yudao.framework.web.core.util.WebFrameworkUtils;
import cn.iocoder.yudao.module.ecw.controller.admin.messageLeave.vo.*;
import cn.iocoder.yudao.module.ecw.convert.messageLeave.MessageLeaveConvert;
import cn.iocoder.yudao.module.ecw.dal.dataobject.messageLeave.MessageLeaveDO;
import cn.iocoder.yudao.module.ecw.service.messageLeave.MessageLeaveService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.util.Collection;
import java.util.List;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.EXPORT;

@Api(tags = "客户端 - 留言")
@RestController
@RequestMapping("/ecw/message-leave")
@Validated
public class AppMessageLeaveController {

    @Resource
    private MessageLeaveService messageLeaveService;

    @PostMapping("/create")
    @ApiOperation("创建留言")
    //@PreAuthorize("@ss.hasPermission('ecw:message-leave:create')")
    @PreAuthenticated
    public CommonResult<Long> createMessageLeave(@Valid @RequestBody MessageLeaveCreateReqVO createReqVO) {
        return success(messageLeaveService.createMessageLeave(createReqVO));
    }

    @PutMapping("/reply")
    @ApiOperation("回复留言")
    @PreAuthenticated
    public CommonResult<Boolean> reply(@Valid @RequestBody MessageLeaveReplyReqVO replyReqVO) {
        replyReqVO.setReplyUserId(WebFrameworkUtils.getLoginUserId());

        messageLeaveService.reply(replyReqVO);
        return success(true);
    }

    @PutMapping("/updateReply")
    @ApiOperation("更新留言回复")
    @PreAuthenticated
    public CommonResult<Boolean> updateReply(@Valid @RequestBody MessageLeaveReplyReqVO replyReqVO) {
        replyReqVO.setReplyUserId(WebFrameworkUtils.getLoginUserId());
        messageLeaveService.reply(replyReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @ApiOperation("删除留言")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthenticated
    public CommonResult<Boolean> deleteMessageLeave(@RequestParam("id") Long id) {
        messageLeaveService.deleteMessageLeave(id);
        return success(true);
    }

    @DeleteMapping("/deleteReply")
    @ApiOperation("删除留言的回复")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthenticated
    public CommonResult<Boolean> deleteReply(@RequestParam("id") Long id) {
        messageLeaveService.deleteReply(id);
        return success(true);
    }

    @GetMapping("/get")
    @ApiOperation("获得留言")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthenticated
    public CommonResult<MessageLeaveRespVO> getMessageLeave(@RequestParam("id") Long id) {
        MessageLeaveDO messageLeave = messageLeaveService.getMessageLeave(id);
        return success(MessageLeaveConvert.INSTANCE.convert(messageLeave));
    }

    @GetMapping("/list")
    @ApiOperation("获得留言列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    @PreAuthenticated
    public CommonResult<List<MessageLeaveRespVO>> getMessageLeaveList(@RequestParam("ids") Collection<Long> ids) {
        List<MessageLeaveDO> list = messageLeaveService.getMessageLeaveList(ids);
        return success(MessageLeaveConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得留言分页")
    @PreAuthenticated
    public CommonResult<PageResult<MessageLeaveRespVO>> getMessageLeavePage(@Valid MessageLeavePageReqVO pageVO) {
        pageVO.setCreator(WebFrameworkUtils.getLoginUserId());
        PageResult<MessageLeaveDO> pageResult = messageLeaveService.getMessageLeavePage(pageVO);
        return success(MessageLeaveConvert.INSTANCE.convertPage(pageResult));
    }

    @GetMapping("/export-excel")
    @ApiOperation("导出留言 Excel")
    @PreAuthenticated
    @OperateLog(type = EXPORT)
    public void exportMessageLeaveExcel(@Valid MessageLeaveExportReqVO exportReqVO,
              HttpServletResponse response) throws IOException {
        List<MessageLeaveDO> list = messageLeaveService.getMessageLeaveList(exportReqVO);
        // 导出 Excel
        List<MessageLeaveExcelVO> datas = MessageLeaveConvert.INSTANCE.convertList02(list);
        ExcelUtils.write(response, "留言.xls", "数据", MessageLeaveExcelVO.class, datas);
    }

}
