package cn.iocoder.yudao.module.ecw.controller.app.supplier;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import cn.iocoder.yudao.module.ecw.controller.admin.supplier.vo.*;
import cn.iocoder.yudao.module.ecw.convert.supplier.SupplierBankConvert;
import cn.iocoder.yudao.module.ecw.convert.supplier.SupplierContactsConvert;
import cn.iocoder.yudao.module.ecw.convert.supplier.SupplierConvert;
import cn.iocoder.yudao.module.ecw.dal.dataobject.supplier.SupplierBankDO;
import cn.iocoder.yudao.module.ecw.dal.dataobject.supplier.SupplierContactsDO;
import cn.iocoder.yudao.module.ecw.dal.dataobject.supplier.SupplierDO;
import cn.iocoder.yudao.module.ecw.service.supplier.SupplierBankService;
import cn.iocoder.yudao.module.ecw.service.supplier.SupplierContactsService;
import cn.iocoder.yudao.module.ecw.service.supplier.SupplierService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.util.Collection;
import java.util.List;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.EXPORT;
import static cn.iocoder.yudao.module.ecw.enums.ErrorCodeConstants.SUPPLIER_NOT_EXISTS;

@Api(tags = "app - 供应商")
@RestController
@RequestMapping("/ecw/supplier")
@Validated
public class AppSupplierController {

    @Resource
    private SupplierService supplierService;
    @Resource
    private SupplierBankService supplierBankService;
    @Resource
    private SupplierContactsService supplierContactsService;

    @GetMapping("/get")
    @ApiOperation("获得供应商")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<SupplierRespVO> getSupplier(@RequestParam("id") Long id) {
        SupplierDO supplier = supplierService.getSupplier(id);
        SupplierRespVO respVO = SupplierConvert.INSTANCE.convert(supplier);
        if(respVO == null) throw exception(SUPPLIER_NOT_EXISTS);

        List<SupplierBankDO> bankDOList = supplierBankService.getSupplierBankList(id);
        List<SupplierBankBaseVO> bankBaseVOList = SupplierBankConvert.INSTANCE.convertList(bankDOList);
        respVO.setBankList(bankBaseVOList);

        List<SupplierContactsDO> contactsDOList = supplierContactsService.getSupplierContactsList(id);
        List<SupplierContactsBaseVO> contactsRespVOList = SupplierContactsConvert.INSTANCE.convertList(contactsDOList);
        respVO.setContactList(contactsRespVOList);

        return success(respVO);
    }

    @GetMapping("/list")
    @ApiOperation("获得供应商列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    public CommonResult<List<SupplierRespVO>> getSupplierList(@RequestParam("ids") Collection<Long> ids) {
        List<SupplierDO> list = supplierService.getSupplierList(ids);
        return success(SupplierConvert.INSTANCE.convertList(list));
    }

    @GetMapping("/page")
    @ApiOperation("获得供应商分页")
    public CommonResult<PageResult<SupplierRespVO>> getSupplierPage(@Valid SupplierPageReqVO pageVO) {
        PageResult<SupplierDO> pageResult = supplierService.getSupplierPage(pageVO);
        return success(SupplierConvert.INSTANCE.convertPage(pageResult));
    }
}
