package cn.iocoder.yudao.module.ecw.dal.mysql.region;

import java.util.*;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.mybatis.core.query.LambdaQueryWrapperX;
import cn.iocoder.yudao.framework.mybatis.core.mapper.BaseMapperX;
import cn.iocoder.yudao.module.ecw.dal.dataobject.region.RegionDO;
import org.apache.ibatis.annotations.Mapper;
import cn.iocoder.yudao.module.ecw.controller.admin.region.vo.*;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.ResultType;
import org.apache.ibatis.annotations.Select;

/**
 * 区域设置 Mapper
 *
 * @author 江楠
 */
@Mapper
public interface RegionMapper extends BaseMapperX<RegionDO> {

    default PageResult<RegionDO> selectPage(RegionPageReqVO reqVO) {
        return selectPage(reqVO, new LambdaQueryWrapperX<RegionDO>()
                .eqIfPresent(RegionDO::getTitleZh, reqVO.getTitleZh())
                .eqIfPresent(RegionDO::getTitleEn, reqVO.getTitleEn())
                .likeIfPresent(RegionDO::getShortName, reqVO.getShortName())
                .eqIfPresent(RegionDO::getLanguage, reqVO.getLanguage())
                .eqIfPresent(RegionDO::getType, reqVO.getType())
                .eqIfPresent(RegionDO::getParentId, reqVO.getParentId())
                .eqIfPresent(RegionDO::getSort, reqVO.getSort())
                .eqIfPresent(RegionDO::getStatus, reqVO.getStatus())
                .betweenIfPresent(RegionDO::getCreateTime, reqVO.getBeginCreateTime(), reqVO.getEndCreateTime())
                .orderByDesc(RegionDO::getId));
    }

    default List<RegionDO> selectList(RegionExportReqVO reqVO) {
        return selectList(new LambdaQueryWrapperX<RegionDO>()
                .eqIfPresent(RegionDO::getTitleZh, reqVO.getTitleZh())
                .eqIfPresent(RegionDO::getTitleEn, reqVO.getTitleEn())
                .likeIfPresent(RegionDO::getShortName, reqVO.getShortName())
                .eqIfPresent(RegionDO::getLanguage, reqVO.getLanguage())
                .eqIfPresent(RegionDO::getType, reqVO.getType())
                .eqIfPresent(RegionDO::getParentId, reqVO.getParentId())
                .eqIfPresent(RegionDO::getSort, reqVO.getSort())
                .eqIfPresent(RegionDO::getStatus, reqVO.getStatus())
                .betweenIfPresent(RegionDO::getCreateTime, reqVO.getBeginCreateTime(), reqVO.getEndCreateTime())
                .orderByDesc(RegionDO::getId));
    }

    default List<RegionDO> selectList(RegionListReqVO reqVO) {
        return selectList(new LambdaQueryWrapperX<RegionDO>()
                .likeIfPresent(RegionDO::getTitleZh, reqVO.getTitleZh())
                .likeIfPresent(RegionDO::getTitleEn, reqVO.getTitleEn())
                .likeIfPresent(RegionDO::getLanguage, reqVO.getLanguage())
                .likeIfPresent(RegionDO::getType, reqVO.getType())
                .eqIfPresent(RegionDO::getStatus, reqVO.getStatus()));
    }

    List<RegionDO> getByParentId(Long id);

    /**
     * 获取所有城市列表
     *
     * @return RegionDO
     */
    List<RegionDO> getCityList();


    @ResultType(List.class)
    @Select(
            {
                    "<script>",
                    "select d.*",
                    " from ecw_region a",
                    "LEFT JOIN ecw_region b ON a.id = b.parent_id",
                    "LEFT JOIN ecw_region c ON b.id = c.parent_id",
                    "LEFT JOIN ecw_region d ON c.id = d.parent_id",
                    "where a.parent_id = 0",
                    " AND a.deleted = 0 ",
                    " AND b.deleted = 0 ",
                    " AND c.deleted = 0 ",
                    " AND d.deleted = 0 ",

//                    "<when test = 'pageVO.status != null'>",
                    "AND d.`status` = 0",
//                    "</when>",
                    "<when test = 'pageVO.type != null and pageVO.type != 0'>",
                    "AND (d.`type` = #{pageVO.type} or d.`type` = 3)",
                    "</when>",
                    "<when test = 'pageVO.destCountryId != null and pageVO.destCountryId != 0'>",
                    "AND ((d.type = 1 and d.id in(select w.shi from ecw_warehouse w where w.guojia = #{pageVO.destCountryId})) or ( d.type in(2,3)))",
                    "</when>",
                    " order by d.sort asc ",
                    "</script>"
            }
    )
    List<RegionDO> selectImportAndExportCity(@Param("pageVO") TradeRegionListReqVO listReqVO);

    List<RegionDO> getContinentCountry();

    List<RegionDO> getImportExportCountryList();


    List<RegionDO> getCityListByParentId(@Param("parentId") Long parentId);
}
