package cn.iocoder.yudao.module.ecw.dal.mysql.supplier;

import java.util.*;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.mybatis.core.query.LambdaQueryWrapperX;
import cn.iocoder.yudao.framework.mybatis.core.mapper.BaseMapperX;
import cn.iocoder.yudao.module.ecw.dal.dataobject.supplier.SupplierDO;
import org.apache.commons.lang3.StringUtils;
import org.apache.ibatis.annotations.Mapper;
import cn.iocoder.yudao.module.ecw.controller.admin.supplier.vo.*;

/**
 * 供应商 Mapper
 *
 * @author wlh
 */
@Mapper
public interface SupplierMapper extends BaseMapperX<SupplierDO> {

    default PageResult<SupplierDO> selectPage(SupplierPageReqVO reqVO) {
        return selectPage(reqVO, new LambdaQueryWrapperX<SupplierDO>()
                .eqIfPresent(SupplierDO::getCompanyEn, reqVO.getCompanyEn())
                .likeIfPresent(SupplierDO::getAgentName, reqVO.getAgentName())
                .eqIfPresent(SupplierDO::getTell, reqVO.getTell())
                .eqIfPresent(SupplierDO::getCountry, reqVO.getCountry())
                .eqIfPresent(SupplierDO::getProvince, reqVO.getProvince())
                .eqIfPresent(SupplierDO::getCity, reqVO.getCity())
                .eqIfPresent(SupplierDO::getArea, reqVO.getArea())
                .eqIfPresent(SupplierDO::getAddress, reqVO.getAddress())
                .eqIfPresent(SupplierDO::getRemark, reqVO.getRemark())
                .eqIfPresent(SupplierDO::getLicense, reqVO.getLicense())
                .eqIfPresent(SupplierDO::getContract, reqVO.getContract())
                .eqIfPresent(SupplierDO::getLicenseNumber, reqVO.getLicenseNumber())
                .eqIfPresent(SupplierDO::getStatus, reqVO.getStatus())

                .eq(SupplierDO::getType, 0)
                .eqIfPresent(SupplierDO::getAreaType, reqVO.getAreaType())

                //名称或者编号
                .likeIfPresent(SupplierDO::getCompanyZh, reqVO.getCompanyZh())
                .likeIfPresent(SupplierDO::getCompanyCode, reqVO.getCompanyZh())
                //合作商类型
//                .likeIfPresent(SupplierDO::getCompanyType, reqVO.getCompanyType())



                //合作类型
                .eqIfPresent(SupplierDO::getCooperationType, reqVO.getCooperationType())
                //时间
                .betweenIfPresent(SupplierDO::getCreateTime, reqVO.getBeginCreateTime(), reqVO.getEndCreateTime())

                .and(StringUtils.isNotEmpty(reqVO.getKeyword()),
                        i -> i.like(SupplierDO::getCompanyZh, reqVO.getKeyword())
                                .or()
                                .like(SupplierDO::getCompanyEn, reqVO.getKeyword())
                                .or()
                                .like(SupplierDO::getCompanyCode, reqVO.getKeyword())
//                                .or()
//                                .like(SupplierDO::getAgentName, reqVO.getKeyword())
//                                .or()
//                                .like(SupplierDO::getRemark, reqVO.getKeyword())
                )
                .apply(reqVO.getCompanyType() != null, "FIND_IN_SET('" + reqVO.getCompanyType() + "',company_type)")
                .orderByDesc(SupplierDO::getId));
    }

    default List<SupplierDO> selectList(SupplierExportReqVO reqVO) {
        return selectList(new LambdaQueryWrapperX<SupplierDO>()
                .eqIfPresent(SupplierDO::getCompanyZh, reqVO.getCompanyZh())
                .eqIfPresent(SupplierDO::getCompanyEn, reqVO.getCompanyEn())
                .eqIfPresent(SupplierDO::getCompanyCode, reqVO.getCompanyCode())
                .likeIfPresent(SupplierDO::getAgentName, reqVO.getAgentName())
                .eqIfPresent(SupplierDO::getTell, reqVO.getTell())
                .eqIfPresent(SupplierDO::getCountry, reqVO.getCountry())
                .eqIfPresent(SupplierDO::getProvince, reqVO.getProvince())
                .eqIfPresent(SupplierDO::getCity, reqVO.getCity())
                .eqIfPresent(SupplierDO::getArea, reqVO.getArea())
                .eqIfPresent(SupplierDO::getAddress, reqVO.getAddress())
                .eqIfPresent(SupplierDO::getRemark, reqVO.getRemark())
                .eqIfPresent(SupplierDO::getCompanyType, reqVO.getCompanyType())
                .eqIfPresent(SupplierDO::getCooperationType, reqVO.getCooperationType())
                .eqIfPresent(SupplierDO::getLicense, reqVO.getLicense())
                .eqIfPresent(SupplierDO::getContract, reqVO.getContract())
                .eqIfPresent(SupplierDO::getLicenseNumber, reqVO.getLicenseNumber())
                .eqIfPresent(SupplierDO::getStatus, reqVO.getStatus())
                .eq(SupplierDO::getType, 0)
                .eqIfPresent(SupplierDO::getAreaType, reqVO.getAreaType())
                .betweenIfPresent(SupplierDO::getCreateTime, reqVO.getBeginCreateTime(), reqVO.getEndCreateTime())
                .orderByDesc(SupplierDO::getId));
    }



    default PageResult<SupplierDO> selectLadingShipperPage(LadingShipperPageReqVO reqVO) {
        return selectPage(reqVO, new LambdaQueryWrapperX<SupplierDO>()
                .eqIfPresent(SupplierDO::getCompanyEn, reqVO.getCompanyEn())
                .eqIfPresent(SupplierDO::getTell, reqVO.getTell())
                .eqIfPresent(SupplierDO::getCountry, reqVO.getCountry())
                .eqIfPresent(SupplierDO::getProvince, reqVO.getProvince())
                .eqIfPresent(SupplierDO::getCity, reqVO.getCity())
                .eqIfPresent(SupplierDO::getArea, reqVO.getArea())
                .eqIfPresent(SupplierDO::getAddress, reqVO.getAddress())
                .eqIfPresent(SupplierDO::getRemark, reqVO.getRemark())
                .eqIfPresent(SupplierDO::getLicense, reqVO.getLicense())
                .eqIfPresent(SupplierDO::getContract, reqVO.getContract())
                .eqIfPresent(SupplierDO::getLicenseNumber, reqVO.getLicenseNumber())
                .eqIfPresent(SupplierDO::getStatus, reqVO.getStatus())
                .eq(SupplierDO::getType, 1)
                //名称或者编号
                .likeIfPresent(SupplierDO::getCompanyZh, reqVO.getCompanyZh())
                .likeIfPresent(SupplierDO::getCompanyCode, reqVO.getCompanyZh())
                //时间
                .betweenIfPresent(SupplierDO::getCreateTime, reqVO.getBeginCreateTime(), reqVO.getEndCreateTime())

                .and(StringUtils.isNotEmpty(reqVO.getKeyword()),
                        i -> i.like(SupplierDO::getCompanyZh, reqVO.getKeyword())
                                .or()
                                .like(SupplierDO::getCompanyEn, reqVO.getKeyword())
                                .or()
                                .like(SupplierDO::getCompanyCode, reqVO.getKeyword())
                )
                .orderByDesc(SupplierDO::getId));
    }

    default List<SupplierDO> selectList(LadingShipperExportReqVO reqVO) {
        return selectList(new LambdaQueryWrapperX<SupplierDO>()
                .eqIfPresent(SupplierDO::getCompanyZh, reqVO.getCompanyZh())
                .eqIfPresent(SupplierDO::getCompanyEn, reqVO.getCompanyEn())
                .eqIfPresent(SupplierDO::getTell, reqVO.getTell())
                .eqIfPresent(SupplierDO::getCountry, reqVO.getCountry())
                .eqIfPresent(SupplierDO::getProvince, reqVO.getProvince())
                .eqIfPresent(SupplierDO::getCity, reqVO.getCity())
                .eqIfPresent(SupplierDO::getArea, reqVO.getArea())
                .eqIfPresent(SupplierDO::getAddress, reqVO.getAddress())
                .eqIfPresent(SupplierDO::getRemark, reqVO.getRemark())
                .eqIfPresent(SupplierDO::getLicense, reqVO.getLicense())
                .eqIfPresent(SupplierDO::getContract, reqVO.getContract())
                .eqIfPresent(SupplierDO::getLicenseNumber, reqVO.getLicenseNumber())
                .eqIfPresent(SupplierDO::getStatus, reqVO.getStatus())
                .eq(SupplierDO::getType, 1)
                .betweenIfPresent(SupplierDO::getCreateTime, reqVO.getBeginCreateTime(), reqVO.getEndCreateTime())
                .orderByDesc(SupplierDO::getId));
    }

}
