package cn.iocoder.yudao.module.ecw.service.adminClient;

import java.util.*;
import javax.annotation.Resource;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.StrUtil;
import cn.iocoder.yudao.framework.apollo.core.event.AdminClientCreateEvent;
import cn.iocoder.yudao.framework.common.util.validation.PhoneUtil;
import cn.iocoder.yudao.framework.web.core.util.WebFrameworkUtils;
import cn.iocoder.yudao.module.ecw.service.paramValid.ParamValidatorService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationContext;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.mybatis.core.service.AbstractService;
import cn.iocoder.yudao.module.ecw.vo.adminClient.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.adminClient.AdminClientDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.module.ecw.convert.adminClient.AdminClientConvert;
import cn.iocoder.yudao.module.ecw.dal.mysql.adminClient.AdminClientMapper;
import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.ecw.enums.ErrorCodeConstants.*;

/**
 * 我的客户 Service 实现类
 *
 * @author 系统管理员
 */
@Service
@Validated
public class AdminClientServiceImpl extends AbstractService<AdminClientMapper, AdminClientDO> implements AdminClientService {

    @Resource
    private AdminClientMapper adminClientMapper;
    @Resource
    private ParamValidatorService paramValidatorService;

    @Autowired
    private ApplicationContext applicationContext;

    @Override
    public Long createAdminClient(AdminClientCreateReqVO createReqVO) {
        // 手机号校验
        try {
            String mobileCode = createReqVO.getDialCode() + StrUtil.COLON + createReqVO.getPhone();
            paramValidatorService.validatorMobile(mobileCode);
//            String phone = PhoneUtil.formatPhone(mobileCode);
//            if (StringUtils.isNotBlank(phone)) {
//                createReqVO.setPhone(phone);
//            }
        } catch (Exception e) {
            throw exception(CUSTOMER_CONTACTS_PHONE_FORMAT_ERROR);
        }
        // 插入
        AdminClientDO adminClient = AdminClientConvert.INSTANCE.convert(createReqVO);
        adminClientMapper.insert(adminClient);


        //发布通知(间接客户那里接收)
        // AdminClientCreateEvent event = BeanUtil.copyProperties(adminClient, AdminClientCreateEvent.class);
        // applicationContext.publishEvent(event);

        // 返回
        return adminClient.getId();
    }

    @Override
    public void updateAdminClient(AdminClientUpdateReqVO updateReqVO) {
        // 校验存在
        this.validateAdminClientExists(updateReqVO.getId());
        // 手机号校验
        try {
            String mobileCode = updateReqVO.getDialCode() + StrUtil.COLON + updateReqVO.getPhone();
            paramValidatorService.validatorMobile(mobileCode);
//            String phone = PhoneUtil.formatPhone(mobileCode);
//            if (StringUtils.isNotBlank(phone)) {
//                updateReqVO.setPhone(phone);
//            }
        } catch (Exception e) {
            throw exception(CUSTOMER_CONTACTS_PHONE_FORMAT_ERROR);
        }
        // 更新
        AdminClientDO updateObj = AdminClientConvert.INSTANCE.convert(updateReqVO);
        adminClientMapper.updateById(updateObj);
    }

    @Override
    public void deleteAdminClient(Long id) {
        // 校验存在
        this.validateAdminClientExists(id);
        // 删除
        adminClientMapper.deleteById(id);
    }

    private void validateAdminClientExists(Long id) {
        if (adminClientMapper.selectById(id) == null) {
            throw exception(ADMIN_CLIENT_NOT_EXISTS);
        }
    }

    @Override
    public AdminClientDO getAdminClient(Long id) {
        return adminClientMapper.selectById(id);
    }

    @Override
    public List<AdminClientDO> getAdminClientList(Collection<Long> ids) {
        return adminClientMapper.selectBatchIds(ids);
    }

    @Override
    public PageResult<AdminClientDO> getAdminClientPage(AdminClientQueryVO query, PageVO page) {
        return adminClientMapper.selectPage(page, query);
    }

    @Override
    public List<AdminClientDO> getAdminClientList(AdminClientQueryVO query) {
        return adminClientMapper.selectList(query);
    }
}
