package cn.iocoder.yudao.module.ecw.service.adminClientType;

import java.util.*;
import javax.annotation.Resource;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.mybatis.core.service.AbstractService;
import cn.iocoder.yudao.module.ecw.vo.adminClientType.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.adminClientType.AdminClientTypeDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.module.ecw.convert.adminClientType.AdminClientTypeConvert;
import cn.iocoder.yudao.module.ecw.dal.mysql.adminClientType.AdminClientTypeMapper;
import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.ecw.enums.ErrorCodeConstants.*;

/**
 * 我的客户分组 Service 实现类
 *
 * @author 系统管理员
 */
@Service
@Validated
public class AdminClientTypeServiceImpl extends AbstractService<AdminClientTypeMapper, AdminClientTypeDO> implements AdminClientTypeService {

    @Resource
    private AdminClientTypeMapper adminClientTypeMapper;

    @Override
    public Integer createAdminClientType(AdminClientTypeCreateReqVO createReqVO) {
        // 插入
        AdminClientTypeDO adminClientType = AdminClientTypeConvert.INSTANCE.convert(createReqVO);
        adminClientTypeMapper.insert(adminClientType);
        // 返回
        return adminClientType.getId();
    }

    @Override
    public void updateAdminClientType(AdminClientTypeUpdateReqVO updateReqVO) {
        // 校验存在
        this.validateAdminClientTypeExists(updateReqVO.getId());
        // 更新
        AdminClientTypeDO updateObj = AdminClientTypeConvert.INSTANCE.convert(updateReqVO);
        adminClientTypeMapper.updateById(updateObj);
    }

    @Override
    public void deleteAdminClientType(Integer id) {
        // 校验存在
        this.validateAdminClientTypeExists(id);
        // 删除
        adminClientTypeMapper.deleteById(id);
    }

    private void validateAdminClientTypeExists(Integer id) {
        if (adminClientTypeMapper.selectById(id) == null) {
            throw exception(ADMIN_CLIENT_TYPE_NOT_EXISTS);
        }
    }

    @Override
    public AdminClientTypeDO getAdminClientType(Integer id) {
        return adminClientTypeMapper.selectById(id);
    }

    @Override
    public List<AdminClientTypeDO> getAdminClientTypeList(Collection<Integer> ids) {
        return adminClientTypeMapper.selectBatchIds(ids);
    }

    @Override
    public PageResult<AdminClientTypeDO> getAdminClientTypePage(AdminClientTypeQueryVO query, PageVO page) {
        return adminClientTypeMapper.selectPage(page, query);
    }

    @Override
    public List<AdminClientTypeDO> getAdminClientTypeList(AdminClientTypeQueryVO query) {
        return adminClientTypeMapper.selectList(query);
    }
}
