package cn.iocoder.yudao.module.ecw.service.adminClienta;

import java.util.*;
import javax.annotation.Resource;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.mybatis.core.service.AbstractService;
import cn.iocoder.yudao.module.ecw.vo.adminClienta.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.adminClienta.AdminClientaDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.module.ecw.convert.adminClienta.AdminClientaConvert;
import cn.iocoder.yudao.module.ecw.dal.mysql.adminClienta.AdminClientaMapper;
import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.ecw.enums.ErrorCodeConstants.*;

/**
 * 我的供应商 Service 实现类
 *
 * @author 系统管理员
 */
@Service
@Validated
public class AdminClientaServiceImpl extends AbstractService<AdminClientaMapper, AdminClientaDO> implements AdminClientaService {

    @Resource
    private AdminClientaMapper adminClientaMapper;

    @Override
    public Long createAdminClienta(AdminClientaCreateReqVO createReqVO) {
        // 插入
        AdminClientaDO adminClienta = AdminClientaConvert.INSTANCE.convert(createReqVO);
        adminClientaMapper.insert(adminClienta);
        // 返回
        return adminClienta.getId();
    }

    @Override
    public void updateAdminClienta(AdminClientaUpdateReqVO updateReqVO) {
        // 校验存在
        this.validateAdminClientaExists(updateReqVO.getId());
        // 更新
        AdminClientaDO updateObj = AdminClientaConvert.INSTANCE.convert(updateReqVO);
        adminClientaMapper.updateById(updateObj);
    }

    @Override
    public void deleteAdminClienta(Long id) {
        // 校验存在
        this.validateAdminClientaExists(id);
        // 删除
        adminClientaMapper.deleteById(id);
    }

    private void validateAdminClientaExists(Long id) {
        if (adminClientaMapper.selectById(id) == null) {
            throw exception(ADMIN_CLIENTA_NOT_EXISTS);
        }
    }

    @Override
    public AdminClientaDO getAdminClienta(Long id) {
        return adminClientaMapper.selectById(id);
    }

    @Override
    public List<AdminClientaDO> getAdminClientaList(Collection<Long> ids) {
        return adminClientaMapper.selectBatchIds(ids);
    }

    @Override
    public PageResult<AdminClientaDO> getAdminClientaPage(AdminClientaQueryVO query, PageVO page) {
        return adminClientaMapper.selectPage(page, query);
    }

    @Override
    public List<AdminClientaDO> getAdminClientaList(AdminClientaQueryVO query) {
        return adminClientaMapper.selectList(query);
    }
}
