package cn.iocoder.yudao.module.ecw.service.adminClientaType;

import java.util.*;
import javax.annotation.Resource;

import cn.iocoder.yudao.module.ecw.dal.dataobject.adminClientaType.AdminClientaTypeDO;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.mybatis.core.service.AbstractService;
import cn.iocoder.yudao.module.ecw.vo.adminClientaType.*;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.module.ecw.convert.adminClientaType.AdminClientaTypeConvert;
import cn.iocoder.yudao.module.ecw.dal.mysql.adminClientaType.AdminClientaTypeMapper;
import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.ecw.enums.ErrorCodeConstants.*;

/**
 * 我的供应商分组 Service 实现类
 *
 * @author 系统管理员
 */
@Service
@Validated
public class AdminClientaTypeServiceImpl extends AbstractService<AdminClientaTypeMapper, AdminClientaTypeDO> implements AdminClientaTypeService {

    @Resource
    private AdminClientaTypeMapper adminClientaTypeMapper;

    @Override
    public Long createAdminClientaType(AdminClientaTypeCreateReqVO createReqVO) {
        // 插入
        AdminClientaTypeDO adminClientaType = AdminClientaTypeConvert.INSTANCE.convert(createReqVO);
        adminClientaTypeMapper.insert(adminClientaType);
        // 返回
        return adminClientaType.getId();
    }

    @Override
    public void updateAdminClientaType(AdminClientaTypeUpdateReqVO updateReqVO) {
        // 校验存在
        this.validateAdminClientaTypeExists(updateReqVO.getId());
        // 更新
        AdminClientaTypeDO updateObj = AdminClientaTypeConvert.INSTANCE.convert(updateReqVO);
        adminClientaTypeMapper.updateById(updateObj);
    }

    @Override
    public void deleteAdminClientaType(Long id) {
        // 校验存在
        this.validateAdminClientaTypeExists(id);
        // 删除
        adminClientaTypeMapper.deleteById(id);
    }

    private void validateAdminClientaTypeExists(Long id) {
        if (adminClientaTypeMapper.selectById(id) == null) {
            throw exception(ADMIN_CLIENTA_TYPE_NOT_EXISTS);
        }
    }

    @Override
    public AdminClientaTypeDO getAdminClientaType(Long id) {
        return adminClientaTypeMapper.selectById(id);
    }

    @Override
    public List<AdminClientaTypeDO> getAdminClientaTypeList(Collection<Long> ids) {
        return adminClientaTypeMapper.selectBatchIds(ids);
    }

    @Override
    public PageResult<AdminClientaTypeDO> getAdminClientaTypePage(AdminClientaTypeQueryVO query, PageVO page) {
        return adminClientaTypeMapper.selectPage(page, query);
    }

    @Override
    public List<AdminClientaTypeDO> getAdminClientaTypeList(AdminClientaTypeQueryVO query) {
        return adminClientaTypeMapper.selectList(query);
    }
}
