package cn.iocoder.yudao.module.ecw.service.busiPwd;

import org.springframework.stereotype.Service;
import javax.annotation.Resource;

import org.springframework.util.DigestUtils;
import org.springframework.validation.annotation.Validated;

import java.util.*;
import cn.iocoder.yudao.framework.mybatis.core.service.AbstractService;
import cn.iocoder.yudao.module.ecw.controller.admin.busiPwd.vo.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.busiPwd.BusiPwdDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;

import cn.iocoder.yudao.module.ecw.convert.busiPwd.BusiPwdConvert;
import cn.iocoder.yudao.module.ecw.dal.mysql.busiPwd.BusiPwdMapper;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.ecw.enums.ErrorCodeConstants.*;

/**
 * 业务密码 Service 实现类
 *
 * @author 系统管理员
 */
@Service
@Validated
public class BusiPwdServiceImpl extends AbstractService<BusiPwdMapper, BusiPwdDO> implements BusiPwdService {

    @Resource
    private BusiPwdMapper busiPwdMapper;

    @Override
    public Long createBusiPwd(BusiPwdCreateReqVO createReqVO) {
        // 插入
        BusiPwdDO busiPwd = BusiPwdConvert.INSTANCE.convert(createReqVO);
        busiPwd.setPwd(DigestUtils.md5DigestAsHex(busiPwd.getPwd().getBytes()));
        busiPwdMapper.insert(busiPwd);
        // 返回
        return busiPwd.getId();
    }

    @Override
    public void updateBusiPwd(BusiPwdUpdateReqVO updateReqVO) {
        // 校验存在
        this.validateBusiPwdExists(updateReqVO.getId());
        // 更新
        BusiPwdDO updateObj = BusiPwdConvert.INSTANCE.convert(updateReqVO);
        updateObj.setPwd(DigestUtils.md5DigestAsHex(updateObj.getPwd().getBytes()));

        busiPwdMapper.updateById(updateObj);
    }

    @Override
    public void deleteBusiPwd(Long id) {
        // 校验存在
        this.validateBusiPwdExists(id);
        // 删除
        busiPwdMapper.deleteById(id);
    }

    private void validateBusiPwdExists(Long id) {
        if (busiPwdMapper.selectById(id) == null) {
            throw exception(BUSI_PWD_NOT_EXISTS);
        }
    }

    @Override
    public BusiPwdDO getBusiPwd(Long id) {
        return busiPwdMapper.selectById(id);
    }

    @Override
    public List<BusiPwdDO> getBusiPwdList(Collection<Long> ids) {
        return busiPwdMapper.selectBatchIds(ids);
    }

    @Override
    public PageResult<BusiPwdDO> getBusiPwdPage(BusiPwdPageReqVO pageReqVO) {
        return busiPwdMapper.selectPage(pageReqVO);
    }

    @Override
    public List<BusiPwdDO> getBusiPwdList(BusiPwdExportReqVO exportReqVO) {
        return busiPwdMapper.selectList(exportReqVO);
    }

}
