package cn.iocoder.yudao.module.ecw.service.cabinet;

import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;

import java.util.*;
import cn.iocoder.yudao.module.ecw.controller.admin.cabinet.vo.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.cabinet.CabinetDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;

import cn.iocoder.yudao.module.ecw.convert.cabinet.CabinetConvert;
import cn.iocoder.yudao.module.ecw.dal.mysql.cabinet.CabinetMapper;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.ecw.enums.ErrorCodeConstants.*;

/**
 * 柜型配置 Service 实现类
 *
 * @author yanghao
 */
@Service
@Validated
public class CabinetServiceImpl implements CabinetService {

    @Resource
    private CabinetMapper cabinetMapper;

    @Override
    public Long createCabinet(CabinetCreateReqVO createReqVO) {
        // 插入
        CabinetDO cabinet = CabinetConvert.INSTANCE.convert(createReqVO);
        cabinetMapper.insert(cabinet);
        // 返回
        return cabinet.getId();
    }

    @Override
    public void updateCabinet(CabinetUpdateReqVO updateReqVO) {
        // 校验存在
        this.validateCabinetExists(updateReqVO.getId());
        // 更新
        CabinetDO updateObj = CabinetConvert.INSTANCE.convert(updateReqVO);
        cabinetMapper.updateById(updateObj);
    }

    @Override
    public void deleteCabinet(Long id) {
        // 校验存在
        this.validateCabinetExists(id);
        // 删除
        cabinetMapper.deleteById(id);
    }

    private void validateCabinetExists(Long id) {
        if (cabinetMapper.selectById(id) == null) {
            throw exception(CABINET_NOT_EXISTS);
        }
    }

    @Override
    public CabinetDO getCabinet(Long id) {
        return cabinetMapper.selectById(id);
    }

    @Override
    public List<CabinetDO> getCabinetList(Collection<Long> ids) {
        return cabinetMapper.selectBatchIds(ids);
    }

    @Override
    public PageResult<CabinetDO> getCabinetPage(CabinetPageReqVO pageReqVO) {
        return cabinetMapper.selectPage(pageReqVO);
    }

    @Override
    public List<CabinetDO> getCabinetList(CabinetExportReqVO exportReqVO) {
        return cabinetMapper.selectList(exportReqVO);
    }

}
