package cn.iocoder.yudao.module.ecw.service.country;

import java.util.*;
import javax.validation.*;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.mybatis.core.service.IService;
import cn.iocoder.yudao.module.ecw.vo.country.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.country.CountryDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;

/**
 * 国家区号 Service 接口
 *
 * @author yanghao
 */
public interface CountryService extends IService<CountryDO> {

    /**
     * 创建国家区号
     * @param createReqVO 创建信息
     * @return 编号
     */
    Long createCountry(@Valid CountryCreateReqVO createReqVO);

    /**
     * 更新国家区号
     * @param updateReqVO 更新信息
     */
    void updateCountry(@Valid CountryUpdateReqVO updateReqVO);

    /**
     * 删除国家区号
     * @param id 编号
     */
    void deleteCountry(Long id);

    /**
     * 获得国家区号
     * @param id 编号
     * @return 国家区号
     */
    CountryDO getCountry(Long id);
    CountryDO getCountry(String areaCode);

    /**
     * 获得国家区号列表
     * @param ids 编号
     * @return 国家区号列表
     */
    List<CountryDO> getCountryList(Collection<Long> ids);

    /**
     * 获得国家区号分页
     * @param page 分页查询
     * @param query 查询
     * @return 国家区号分页
     */
    PageResult<CountryDO> getCountryPage(CountryQueryVO query, PageVO page);

    /**
     * 获得国家区号列表, 用于 Excel 导出
     * @param query 查询
     * @return 国家区号列表
     */
    List<CountryDO> getCountryList(CountryQueryVO query);
}
