package cn.iocoder.yudao.module.ecw.service.country;

import java.util.*;
import javax.annotation.Resource;

import cn.hutool.core.collection.CollectionUtil;
import cn.iocoder.yudao.framework.mybatis.core.query.LambdaQueryWrapperX;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.mybatis.core.service.AbstractService;
import cn.iocoder.yudao.module.ecw.vo.country.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.country.CountryDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.module.ecw.convert.country.CountryConvert;
import cn.iocoder.yudao.module.ecw.dal.mysql.country.CountryMapper;
import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.ecw.enums.ErrorCodeConstants.*;

/**
 * 国家区号 Service 实现类
 *
 * @author yanghao
 */
@Service
@Validated
public class CountryServiceImpl extends AbstractService<CountryMapper, CountryDO> implements CountryService {

    @Resource
    private CountryMapper countryMapper;

    @Override
    public Long createCountry(CountryCreateReqVO createReqVO) {
        // 插入
        CountryDO country = CountryConvert.INSTANCE.convert(createReqVO);
        countryMapper.insert(country);
        // 返回
        return country.getId();
    }

    @Override
    public void updateCountry(CountryUpdateReqVO updateReqVO) {
        // 校验存在
        this.validateCountryExists(updateReqVO.getId());
        // 更新
        CountryDO updateObj = CountryConvert.INSTANCE.convert(updateReqVO);
        countryMapper.updateById(updateObj);
    }

    @Override
    public void deleteCountry(Long id) {
        // 校验存在
        this.validateCountryExists(id);
        // 删除
        countryMapper.deleteById(id);
    }

    private void validateCountryExists(Long id) {
        if (countryMapper.selectById(id) == null) {
            throw exception(COUNTRY_NOT_EXISTS);
        }
    }

    @Override
    public CountryDO getCountry(Long id) {
        return countryMapper.selectById(id);
    }

    @Override
    public CountryDO getCountry(String areaCode) {
        return countryMapper.selectOne(new LambdaQueryWrapperX<CountryDO>().eq(CountryDO::getTel, areaCode).last("limit 1"));
    }

    @Override
    public List<CountryDO> getCountryList(Collection<Long> ids) {
        List<CountryDO> countryDOList = countryMapper.selectBatchIds(ids);
        if (CollectionUtil.isNotEmpty(countryDOList)) {
            countryDOList.sort((o1, o2) -> o2.getSort().compareTo(o1.getSort()));
        }
        return countryDOList;
    }

    @Override
    public PageResult<CountryDO> getCountryPage(CountryQueryVO query, PageVO page) {
        return countryMapper.selectPage(page, query);
    }

    @Override
    public List<CountryDO> getCountryList(CountryQueryVO query) {
        return countryMapper.selectList(query);
    }
}
