package cn.iocoder.yudao.module.ecw.service.currency;

import java.util.*;
import javax.validation.*;
import cn.iocoder.yudao.module.ecw.controller.admin.currency.vo.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.currency.CurrencyDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;

/**
 * 货币单位 Service 接口
 *
 * @author brian
 */
public interface CurrencyService {

    /**
     * 创建货币单位
     *
     * @param createReqVO 创建信息
     * @return 编号
     */
    Integer createCurrency(@Valid CurrencyCreateReqVO createReqVO);

    /**
     * 更新货币单位
     *
     * @param updateReqVO 更新信息
     */
    void updateCurrency(@Valid CurrencyUpdateReqVO updateReqVO);

    /**
     * 更新货币单位
     *
     * @param updateReqVO 更新信息
     */
    void updateCurrencyStatus(@Valid CurrencyUpdateStatusReqVO updateReqVO);

    /**
     * 删除货币单位
     *
     * @param id 编号
     */
    void deleteCurrency(Integer id);

    /**
     * 获得货币单位
     *
     * @param id 编号
     * @return 货币单位
     */
    CurrencyDO getCurrency(Integer id);

    /**
     * 获得货币单位
     *
     * @param code 符号
     * @return 货币单位
     */
    CurrencyDO getCurrencyByCode(String code);

    /**
     * 获得货币单位列表
     *
     * @return 货币单位列表
     */
    List<CurrencyDO> getCurrencyList();

    /**
     * 获得货币单位分页
     *
     * @param pageReqVO 分页查询
     * @return 货币单位分页
     */
    PageResult<CurrencyDO> getCurrencyPage(CurrencyPageReqVO pageReqVO);

    /**
     * 获得货币单位列表, 用于 Excel 导出
     *
     * @param exportReqVO 查询条件
     * @return 货币单位列表
     */
    List<CurrencyDO> getCurrencyList(CurrencyExportReqVO exportReqVO);

    List<CurrencyDO> list();

}
