package cn.iocoder.yudao.module.ecw.service.currency;

import cn.iocoder.yudao.framework.common.util.spring.enums.CommonStatusEnum;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.mybatis.core.query.QueryWrapperX;
import cn.iocoder.yudao.module.ecw.controller.admin.currency.vo.*;
import cn.iocoder.yudao.module.ecw.convert.currency.CurrencyConvert;
import cn.iocoder.yudao.module.ecw.dal.dataobject.currency.CurrencyDO;
import cn.iocoder.yudao.module.ecw.dal.mysql.currency.CurrencyMapper;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import org.springframework.cache.annotation.CacheEvict;
import org.springframework.cache.annotation.Cacheable;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.ecw.enums.ErrorCodeConstants.CURRENCY_NOT_EXISTS;

/**
 * 货币单位 Service 实现类
 *
 * @author brian
 */
@Service
@Validated
public class CurrencyServiceImpl implements CurrencyService {

    @Resource
    private CurrencyMapper currencyMapper;

    @Override
    @CacheEvict(cacheNames = "jd:currency", key = "'all'")
    public Integer createCurrency(CurrencyCreateReqVO createReqVO) {
        createReqVO.setCreateTime(new Date());
        createReqVO.setStatus(CommonStatusEnum.ENABLE.getStatus());
        createReqVO.setDeleted(false);
        // 插入
        CurrencyDO currency = CurrencyConvert.INSTANCE.convert(createReqVO);
        currencyMapper.insert(currency);
        // 返回
        return currency.getId();
    }

    @Override
    @CacheEvict(cacheNames = "jd:currency", key = "'all'")
    public void updateCurrency(CurrencyUpdateReqVO updateReqVO) {
        // 校验存在
        this.validateCurrencyExists(updateReqVO.getId());
        // 更新
        CurrencyDO updateObj = CurrencyConvert.INSTANCE.convert(updateReqVO);
        updateObj.setUpdateTime(new Date());
        currencyMapper.updateById(updateObj);
    }

    @Override
    @CacheEvict(cacheNames = "jd:currency", key = "'all'")
    public void updateCurrencyStatus(CurrencyUpdateStatusReqVO updateReqVO) {
        // 校验存在
        this.validateCurrencyExists(updateReqVO.getId());
        // 更新
        CurrencyDO updateObj = CurrencyConvert.INSTANCE.convert(updateReqVO);
        currencyMapper.updateById(updateObj);
    }

    @Override
    public void deleteCurrency(Integer id) {
        // 校验存在
        this.validateCurrencyExists(id);
        // 删除
        currencyMapper.deleteById(id);
    }

    private void validateCurrencyExists(Integer id) {
        if (currencyMapper.selectById(id) == null) {
            throw exception(CURRENCY_NOT_EXISTS);
        }
    }

    @Override
    public CurrencyDO getCurrency(Integer id) {
        return currencyMapper.selectById(id);
    }

    @Override
    public CurrencyDO getCurrencyByCode(String code) {
        LambdaQueryWrapper<CurrencyDO> lambdaQueryWrapper = new LambdaQueryWrapper();
        lambdaQueryWrapper.eq(CurrencyDO::getFuhao, code);
        return currencyMapper.selectOne(lambdaQueryWrapper);
    }

    @Override
    public List<CurrencyDO> getCurrencyList() {
        return currencyMapper.selectList(new QueryWrapperX<CurrencyDO>()
                .orderByAsc("aorder")
        );
    }

    @Override
    public PageResult<CurrencyDO> getCurrencyPage(CurrencyPageReqVO pageReqVO) {
        return currencyMapper.selectPage(pageReqVO);
    }

    @Override
    public List<CurrencyDO> getCurrencyList(CurrencyExportReqVO exportReqVO) {
        return currencyMapper.selectList(exportReqVO);
    }

    @Override
    @Cacheable(cacheNames = "jd:currency", key = "'all'")
    public List<CurrencyDO> list() {
        return currencyMapper.selectList(new LambdaQueryWrapper<CurrencyDO>()
                .eq(CurrencyDO::getDeleted, 0));
    }
}
