package cn.iocoder.yudao.module.ecw.service.currencyEcash;

import cn.iocoder.yudao.framework.mybatis.core.dataobject.BaseDO;
import cn.iocoder.yudao.framework.mybatis.core.query.LambdaQueryWrapperX;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

import org.springframework.validation.annotation.Validated;

import java.util.*;

import cn.iocoder.yudao.module.ecw.controller.admin.currencyEcash.vo.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.currencyEcash.CurrencyEcashDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;

import cn.iocoder.yudao.module.ecw.convert.currencyEcash.CurrencyEcashConvert;
import cn.iocoder.yudao.module.ecw.dal.mysql.currencyEcash.CurrencyEcashMapper;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.ecw.enums.ErrorCodeConstants.*;

/**
 * E-Cash汇率单位 Service 实现类
 *
 * @author 久点源码
 */
@Service
@Validated
public class CurrencyEcashServiceImpl implements CurrencyEcashService {

    @Resource
    private CurrencyEcashMapper currencyEcashMapper;

    @Override
    public Integer createCurrencyEcash(CurrencyEcashCreateReqVO createReqVO) throws Exception {
        // 插入
        Date now = new Date();
        CurrencyEcashDO currencyEcash = CurrencyEcashConvert.INSTANCE.convert(createReqVO);
        LambdaQueryWrapperX<CurrencyEcashDO> wrapper = new LambdaQueryWrapperX<CurrencyEcashDO>().eq(CurrencyEcashDO::getFromCurrency, currencyEcash.getFromCurrency()).eq(CurrencyEcashDO::getToCurrency, currencyEcash.getToCurrency());
        wrapper.and(i -> i.le(CurrencyEcashDO::getNrlyStartTime, now).ge(CurrencyEcashDO::getNrlyEndTime, now))
        .or(i -> i.le(CurrencyEcashDO::getBjStartTime, now).ge(CurrencyEcashDO::getBjEndTime, now));
        List<CurrencyEcashDO> currencyEcashDOS = currencyEcashMapper.selectList(wrapper);
        if (currencyEcashDOS!=null && currencyEcashDOS.size()>0) {
            throw new Exception("当前存在生效中的汇率！");
        }
        currencyEcashMapper.insert(currencyEcash);
        // 返回
        return currencyEcash.getId();
    }

    @Override
    public void updateCurrencyEcash(CurrencyEcashUpdateReqVO updateReqVO) {
        // 校验存在
        this.validateCurrencyEcashExists(updateReqVO.getId());
        // 更新
        CurrencyEcashDO updateObj = CurrencyEcashConvert.INSTANCE.convert(updateReqVO);
        currencyEcashMapper.updateById(updateObj);
    }

    @Override
    public void deleteCurrencyEcash(Integer id) {
        // 校验存在
        this.validateCurrencyEcashExists(id);
        // 删除
        currencyEcashMapper.deleteById(id);
    }

    private void validateCurrencyEcashExists(Integer id) {
        if (currencyEcashMapper.selectById(id) == null) {
            throw exception(CURRENCY_ECASH_NOT_EXISTS);
        }
    }

    @Override
    public CurrencyEcashDO getCurrencyEcash(Integer id) {
        return currencyEcashMapper.selectById(id);
    }

    @Override
    public List<CurrencyEcashDO> getCurrencyEcashList(Collection<Integer> ids) {
        return currencyEcashMapper.selectBatchIds(ids);
    }

    @Override
    public PageResult<CurrencyEcashDO> getCurrencyEcashPage(CurrencyEcashPageReqVO pageReqVO) {
        return currencyEcashMapper.selectPage(pageReqVO);
    }

    @Override
    public List<CurrencyEcashDO> getCurrencyEcashList(CurrencyEcashExportReqVO exportReqVO) {
        return currencyEcashMapper.selectList(exportReqVO);
    }

    @Override
    public void batchUpdateCurrencyEcash(List<CurrencyEcashUpdateReqVO> updateReqVO) {
        if(updateReqVO!=null && updateReqVO.size()>0){
            for (CurrencyEcashUpdateReqVO currencyEcashUpdateReqVO : updateReqVO){
                // 校验存在
                this.validateCurrencyEcashExists(currencyEcashUpdateReqVO.getId());
                // 更新
                CurrencyEcashDO updateObj = CurrencyEcashConvert.INSTANCE.convert(currencyEcashUpdateReqVO);
                currencyEcashMapper.updateById(updateObj);
            }
        }
    }

    @Override
    public List<CurrencyEcashDO> getAllCurrency() {
        return currencyEcashMapper.selectList();
    }

    @Override
    public void updateCurrencyEcashAll(CurrencyEcashDO updateReqVO) {
        currencyEcashMapper.update(updateReqVO,new UpdateWrapper<>());
    }

}
