package cn.iocoder.yudao.module.ecw.service.dock;

import java.util.*;
import javax.validation.*;
import cn.iocoder.yudao.module.ecw.controller.admin.dock.vo.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.dock.DockDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;

/**
 * 码头信息 Service 接口
 *
 * @author wlh
 */
public interface DockService {

    /**
     * 创建码头信息
     *
     * @param createReqVO 创建信息
     * @return 编号
     */
    Long createDock(@Valid DockCreateReqVO createReqVO);

    /**
     * 更新码头信息
     *
     * @param updateReqVO 更新信息
     */
    void updateDock(@Valid DockUpdateReqVO updateReqVO);

    /**
     * 删除码头信息
     *
     * @param id 编号
     */
    void deleteDock(Long id);

    /**
     * 获得码头信息
     *
     * @param id 编号
     * @return 码头信息
     */
    DockDO getDock(Long id);

    /**
     * 获得码头信息列表
     *
     * @param ids 编号
     * @return 码头信息列表
     */
    List<DockDO> getDockList(Collection<Long> ids);

    /**
     * 获得码头信息分页
     *
     * @param pageReqVO 分页查询
     * @return 码头信息分页
     */
    PageResult<DockDO> getDockPage(DockPageReqVO pageReqVO);

    /**
     * 获得码头信息列表, 用于 Excel 导出
     *
     * @param exportReqVO 查询条件
     * @return 码头信息列表
     */
    List<DockDO> getDockList(DockExportReqVO exportReqVO);

}
