package cn.iocoder.yudao.module.ecw.service.dock;

import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;

import java.util.*;
import cn.iocoder.yudao.module.ecw.controller.admin.dock.vo.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.dock.DockDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;

import cn.iocoder.yudao.module.ecw.convert.dock.DockConvert;
import cn.iocoder.yudao.module.ecw.dal.mysql.dock.DockMapper;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.ecw.enums.ErrorCodeConstants.*;

/**
 * 码头信息 Service 实现类
 *
 * @author wlh
 */
@Service
@Validated
public class DockServiceImpl implements DockService {

    @Resource
    private DockMapper dockMapper;

    @Override
    public Long createDock(DockCreateReqVO createReqVO) {
        // 插入
        DockDO dock = DockConvert.INSTANCE.convert(createReqVO);
        dockMapper.insert(dock);
        // 返回
        return dock.getId();
    }

    @Override
    public void updateDock(DockUpdateReqVO updateReqVO) {
        // 校验存在
        this.validateDockExists(updateReqVO.getId());
        // 更新
        DockDO updateObj = DockConvert.INSTANCE.convert(updateReqVO);
        dockMapper.updateById(updateObj);
    }

    @Override
    public void deleteDock(Long id) {
        // 校验存在
        this.validateDockExists(id);
        // 删除
        dockMapper.deleteById(id);
    }

    private void validateDockExists(Long id) {
        if (dockMapper.selectById(id) == null) {
            throw exception(DOCK_NOT_EXISTS);
        }
    }

    @Override
    public DockDO getDock(Long id) {
        return dockMapper.selectById(id);
    }

    @Override
    public List<DockDO> getDockList(Collection<Long> ids) {
        return dockMapper.selectBatchIds(ids);
    }

    @Override
    public PageResult<DockDO> getDockPage(DockPageReqVO pageReqVO) {
        return dockMapper.selectPage(pageReqVO);
    }

    @Override
    public List<DockDO> getDockList(DockExportReqVO exportReqVO) {
        return dockMapper.selectList(exportReqVO);
    }

}
