package cn.iocoder.yudao.module.ecw.service.enterprise;

import java.util.*;
import javax.validation.*;
import cn.iocoder.yudao.module.ecw.controller.admin.enterprise.vo.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.enterprise.EnterpriseDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.mybatis.core.service.IService;

/**
 * 企业设置 Service 接口
 *
 * @author 系统管理员
 */
public interface EnterpriseService extends IService<EnterpriseDO> {

    /**
     * 创建企业设置
     *
     * @param createReqVO 创建信息
     * @return 编号
     */
    Long createEnterprise(@Valid EnterpriseCreateReqVO createReqVO);

    /**
     * 更新企业设置
     *
     * @param updateReqVO 更新信息
     */
    void updateEnterprise(@Valid EnterpriseUpdateReqVO updateReqVO);

    /**
     * 删除企业设置
     *
     * @param id 编号
     */
    void deleteEnterprise(Long id);

    /**
     * 获得企业设置
     *
     * @param id 编号
     * @return 企业设置
     */
    EnterpriseDO getEnterprise(Long id);

    /**
     * 获得企业设置列表
     *
     * @param ids 编号
     * @return 企业设置列表
     */
    List<EnterpriseDO> getEnterpriseList(Collection<Long> ids);

    /**
     * 获得企业设置分页
     *
     * @param pageReqVO 分页查询
     * @return 企业设置分页
     */
    PageResult<EnterpriseDO> getEnterprisePage(EnterprisePageReqVO pageReqVO);

    /**
     * 获得企业设置列表, 用于 Excel 导出
     *
     * @param exportReqVO 查询条件
     * @return 企业设置列表
     */
    List<EnterpriseDO> getEnterpriseList(EnterpriseExportReqVO exportReqVO);

    EnterpriseDO getInfo();
}
