package cn.iocoder.yudao.module.ecw.service.enterprise;

import cn.iocoder.yudao.framework.mybatis.core.query.LambdaQueryWrapperX;
import cn.iocoder.yudao.framework.security.core.util.SecurityFrameworkUtils;
import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;

import java.util.*;
import cn.iocoder.yudao.framework.mybatis.core.service.AbstractService;
import cn.iocoder.yudao.module.ecw.controller.admin.enterprise.vo.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.enterprise.EnterpriseDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;

import cn.iocoder.yudao.module.ecw.convert.enterprise.EnterpriseConvert;
import cn.iocoder.yudao.module.ecw.dal.mysql.enterprise.EnterpriseMapper;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.ecw.enums.ErrorCodeConstants.*;

/**
 * 企业设置 Service 实现类
 *
 * @author 系统管理员
 */
@Service
@Validated
public class EnterpriseServiceImpl extends AbstractService<EnterpriseMapper, EnterpriseDO> implements EnterpriseService {

    @Resource
    private EnterpriseMapper enterpriseMapper;

    @Override
    public Long createEnterprise(EnterpriseCreateReqVO createReqVO) {
        Long userId = SecurityFrameworkUtils.getLoginUserId();
        // 插入
        EnterpriseDO enterprise = EnterpriseConvert.INSTANCE.convert(createReqVO);
        Date now = new Date();
        enterprise.setCreator(String.valueOf(userId));
        enterprise.setUpdater(String.valueOf(userId));
        enterprise.setCreateTime(now);
        enterprise.setUpdateTime(now);

        enterpriseMapper.insert(enterprise);
        // 返回
        return enterprise.getId();
    }

    @Override
    public void updateEnterprise(EnterpriseUpdateReqVO updateReqVO) {
        Long userId = SecurityFrameworkUtils.getLoginUserId();
        // 校验存在
        this.validateEnterpriseExists(updateReqVO.getId());
        // 更新
        EnterpriseDO updateObj = EnterpriseConvert.INSTANCE.convert(updateReqVO);
        Date now = new Date();
        updateObj.setUpdater(String.valueOf(userId));
        updateObj.setUpdateTime(now);
        enterpriseMapper.updateById(updateObj);
    }

    @Override
    public void deleteEnterprise(Long id) {
        // 校验存在
        this.validateEnterpriseExists(id);
        // 删除
        enterpriseMapper.deleteById(id);
    }

    private void validateEnterpriseExists(Long id) {
        if (enterpriseMapper.selectById(id) == null) {
            throw exception(ENTERPRISE_NOT_EXISTS);
        }
    }

    @Override
    public EnterpriseDO getEnterprise(Long id) {
        return enterpriseMapper.selectById(id);
    }

    @Override
    public List<EnterpriseDO> getEnterpriseList(Collection<Long> ids) {
        return enterpriseMapper.selectBatchIds(ids);
    }

    @Override
    public PageResult<EnterpriseDO> getEnterprisePage(EnterprisePageReqVO pageReqVO) {
        return enterpriseMapper.selectPage(pageReqVO);
    }

    @Override
    public List<EnterpriseDO> getEnterpriseList(EnterpriseExportReqVO exportReqVO) {
        return enterpriseMapper.selectList(exportReqVO);
    }

    @Override
    public EnterpriseDO getInfo() {
        return enterpriseMapper.selectOne(new LambdaQueryWrapperX<EnterpriseDO>().orderByDesc(EnterpriseDO::getId).last("limit 1"));
    }
}
