package cn.iocoder.yudao.module.ecw.service.exchangeRate;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.mybatis.core.service.AbstractService;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.security.core.util.SecurityFrameworkUtils;
import cn.iocoder.yudao.module.ecw.convert.exchangeRate.ExchangeRateConvert;
import cn.iocoder.yudao.module.ecw.dal.dataobject.exchangeRate.ExchangeRateDO;
import cn.iocoder.yudao.module.ecw.dal.mysql.exchangeRate.ExchangeRateMapper;
import cn.iocoder.yudao.module.ecw.service.exchangeRateLog.ExchangeRateLogService;
import cn.iocoder.yudao.module.ecw.vo.exchangeRate.ExchangeRateCreateReqVO;
import cn.iocoder.yudao.module.ecw.vo.exchangeRate.ExchangeRateQueryVO;
import cn.iocoder.yudao.module.ecw.vo.exchangeRate.ExchangeRateUpdateReqVO;
import cn.iocoder.yudao.module.ecw.vo.exchangeRateLog.ExchangeRateLogCreateReqVO;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.validation.annotation.Validated;

import javax.annotation.Resource;
import java.util.Collection;
import java.util.Date;
import java.util.List;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.ecw.enums.ErrorCodeConstants.EXCHANGE_RATE_EXISTS;
import static cn.iocoder.yudao.module.ecw.enums.ErrorCodeConstants.EXCHANGE_RATE_NOT_EXISTS;

/**
 * 汇率管理 Service 实现类
 *
 * @author 系统管理员
 */
@Service
@Validated
public class ExchangeRateServiceImpl extends AbstractService<ExchangeRateMapper, ExchangeRateDO> implements ExchangeRateService {

    @Resource
    private ExchangeRateMapper exchangeRateMapper;
    @Resource
    private ExchangeRateLogService exchangeRateLogService;

    @Override
    public Long createExchangeRate(ExchangeRateCreateReqVO createReqVO) {
        //判断汇率是否已经存在
        LambdaQueryWrapper<ExchangeRateDO> lambdaQueryWrapper = new LambdaQueryWrapper<>();
        lambdaQueryWrapper.eq(ExchangeRateDO::getSourceCurrencyId, createReqVO.getSourceCurrencyId());
        lambdaQueryWrapper.eq(ExchangeRateDO::getTargetCurrencyId, createReqVO.getTargetCurrencyId());
        if (this.count(lambdaQueryWrapper) > 0) {
            throw exception(EXCHANGE_RATE_EXISTS);
        }
        // 插入
        ExchangeRateDO exchangeRate = ExchangeRateConvert.INSTANCE.convert(createReqVO);
        exchangeRateMapper.insert(exchangeRate);
        // 返回
        return exchangeRate.getId();
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void updateExchangeRate(ExchangeRateUpdateReqVO updateReqVO) {
        ExchangeRateDO exchangeRateDO = exchangeRateMapper.selectById(updateReqVO.getId());
        if (exchangeRateDO == null) {
            throw exception(EXCHANGE_RATE_NOT_EXISTS);
        }
        LambdaQueryWrapper<ExchangeRateDO> lambdaQueryWrapper = new LambdaQueryWrapper<>();
        lambdaQueryWrapper.eq(ExchangeRateDO::getSourceCurrencyId, updateReqVO.getSourceCurrencyId());
        lambdaQueryWrapper.eq(ExchangeRateDO::getTargetCurrencyId, updateReqVO.getTargetCurrencyId());
        lambdaQueryWrapper.ne(ExchangeRateDO::getId, updateReqVO.getId());

        if (this.count(lambdaQueryWrapper) > 0) {
            throw exception(EXCHANGE_RATE_EXISTS);
        }


        // 更新
        ExchangeRateDO updateObj = ExchangeRateConvert.INSTANCE.convert(updateReqVO);
        exchangeRateMapper.updateById(updateObj);


        ExchangeRateLogCreateReqVO logCreateReqVO = new ExchangeRateLogCreateReqVO();
        logCreateReqVO.setRateId(updateObj.getId());
        logCreateReqVO.setChangeName(SecurityFrameworkUtils.getLoginUserNickName());
        logCreateReqVO.setChangeTime(new Date());
        logCreateReqVO.setBeforeChangeSourceValue(exchangeRateDO.getSourceCurrencyCode());
        logCreateReqVO.setAfterChangeSourceValue(updateReqVO.getSourceCurrencyCode());

        logCreateReqVO.setBeforeChangeTargetValue(exchangeRateDO.getTargetCurrencyCode());
        logCreateReqVO.setAfterChangeTargetValue(updateReqVO.getTargetCurrencyCode());

        logCreateReqVO.setBeforeChangeValue(exchangeRateDO.getCurrencyRate().toString());
        logCreateReqVO.setAfterChangeValue(updateReqVO.getCurrencyRate().toString());
        exchangeRateLogService.createExchangeRateLog(logCreateReqVO);
    }

    @Override
    public void deleteExchangeRate(Long id) {
        // 校验存在
        this.validateExchangeRateExists(id);
        // 删除
        exchangeRateMapper.deleteById(id);
    }

    private void validateExchangeRateExists(Long id) {
        if (exchangeRateMapper.selectById(id) == null) {
            throw exception(EXCHANGE_RATE_NOT_EXISTS);
        }
    }

    @Override
    public ExchangeRateDO getExchangeRate(Long id) {
        return exchangeRateMapper.selectById(id);
    }

    @Override
    public List<ExchangeRateDO> getExchangeRateList(Collection<Long> ids) {
        return exchangeRateMapper.selectBatchIds(ids);
    }

    @Override
    public PageResult<ExchangeRateDO> getExchangeRatePage(ExchangeRateQueryVO query, PageVO page) {
        return exchangeRateMapper.selectPage(page, query);
    }

    @Override
    public List<ExchangeRateDO> getExchangeRateList(ExchangeRateQueryVO query) {
        return exchangeRateMapper.selectList(query);
    }
}

