package cn.iocoder.yudao.module.ecw.service.exchangeRateLog;

import java.util.*;
import javax.annotation.Resource;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.mybatis.core.service.AbstractService;
import cn.iocoder.yudao.module.ecw.vo.exchangeRateLog.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.exchangeRateLog.ExchangeRateLogDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.module.ecw.convert.exchangeRateLog.ExchangeRateLogConvert;
import cn.iocoder.yudao.module.ecw.dal.mysql.exchangeRateLog.ExchangeRateLogMapper;
import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.ecw.enums.ErrorCodeConstants.*;

/**
 * 汇率变更记录 Service 实现类
 *
 * @author 系统管理员
 */
@Service
@Validated
public class ExchangeRateLogServiceImpl extends AbstractService<ExchangeRateLogMapper, ExchangeRateLogDO> implements ExchangeRateLogService {

    @Resource
    private ExchangeRateLogMapper exchangeRateLogMapper;

    @Override
    public Long createExchangeRateLog(ExchangeRateLogCreateReqVO createReqVO) {
        // 插入
        ExchangeRateLogDO exchangeRateLog = ExchangeRateLogConvert.INSTANCE.convert(createReqVO);
        exchangeRateLogMapper.insert(exchangeRateLog);
        // 返回
        return exchangeRateLog.getId();
    }

    @Override
    public void updateExchangeRateLog(ExchangeRateLogUpdateReqVO updateReqVO) {
        // 校验存在
        this.validateExchangeRateLogExists(updateReqVO.getId());
        // 更新
        ExchangeRateLogDO updateObj = ExchangeRateLogConvert.INSTANCE.convert(updateReqVO);
        exchangeRateLogMapper.updateById(updateObj);
    }

    @Override
    public void deleteExchangeRateLog(Long id) {
        // 校验存在
        this.validateExchangeRateLogExists(id);
        // 删除
        exchangeRateLogMapper.deleteById(id);
    }

    private void validateExchangeRateLogExists(Long id) {
        if (exchangeRateLogMapper.selectById(id) == null) {
            throw exception(EXCHANGE_RATE_LOG_NOT_EXISTS);
        }
    }

    @Override
    public ExchangeRateLogDO getExchangeRateLog(Long id) {
        return exchangeRateLogMapper.selectById(id);
    }

    @Override
    public List<ExchangeRateLogDO> getExchangeRateLogList(Collection<Long> ids) {
        return exchangeRateLogMapper.selectBatchIds(ids);
    }

    @Override
    public PageResult<ExchangeRateLogDO> getExchangeRateLogPage(ExchangeRateLogQueryVO query, PageVO page) {
        return exchangeRateLogMapper.selectPage(page, query);
    }

    @Override
    public List<ExchangeRateLogDO> getExchangeRateLogList(ExchangeRateLogQueryVO query) {
        return exchangeRateLogMapper.selectList(query);
    }
}
