package cn.iocoder.yudao.module.ecw.service.express;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;

import java.util.*;
import cn.iocoder.yudao.module.ecw.controller.admin.express.vo.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.express.ExpressDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;

import cn.iocoder.yudao.module.ecw.convert.express.ExpressConvert;
import cn.iocoder.yudao.module.ecw.dal.mysql.express.ExpressMapper;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.ecw.enums.ErrorCodeConstants.*;

/**
 * 配送管理 Service 实现类
 *
 * @author yanghao
 */
@Service
@Validated
public class ExpressServiceImpl implements ExpressService {

    @Resource
    private ExpressMapper expressMapper;

    @Override
    public Long createExpress(ExpressCreateReqVO createReqVO) {
        // 插入
        ExpressDO express = ExpressConvert.INSTANCE.convert(createReqVO);
        expressMapper.insert(express);
        // 返回
        return express.getId();
    }

    @Override
    public void updateExpress(ExpressUpdateReqVO updateReqVO) {
        // 校验存在
        this.validateExpressExists(updateReqVO.getId());
        // 更新
        ExpressDO updateObj = ExpressConvert.INSTANCE.convert(updateReqVO);
        expressMapper.updateById(updateObj);
    }

    @Override
    public void deleteExpress(Long id) {
        // 校验存在
        this.validateExpressExists(id);
        // 删除
        expressMapper.deleteById(id);
    }

    private void validateExpressExists(Long id) {
        if (expressMapper.selectById(id) == null) {
            throw exception(EXPRESS_NOT_EXISTS);
        }
    }

    @Override
    public ExpressDO getExpress(Long id) {
        return expressMapper.selectById(id);
    }

    @Override
    public List<ExpressDO> getExpressList(Collection<Long> ids) {
        return expressMapper.selectBatchIds(ids);
    }

    @Override
    public PageResult<ExpressDO> getExpressPage(ExpressPageReqVO pageReqVO) {
        return expressMapper.selectPage(pageReqVO);
    }

    @Override
    public List<ExpressDO> getExpressList(ExpressExportReqVO exportReqVO) {
        return expressMapper.selectList(exportReqVO);
    }

    @Override
    public List<ExpressDO> list() {
        LambdaQueryWrapper<ExpressDO> wrapper = Wrappers.lambdaQuery();
        wrapper.eq(ExpressDO::getDeleted, 0);
        return expressMapper.selectList(wrapper);
    }

}
