package cn.iocoder.yudao.module.ecw.service.internalMessage;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.mybatis.core.query.QueryWrapperX;
import cn.iocoder.yudao.framework.mybatis.core.service.AbstractService;
import cn.iocoder.yudao.framework.mybatis.core.util.MyBatisUtils;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.module.ecw.convert.internalMessage.InternalMessageConvert;
import cn.iocoder.yudao.module.ecw.dal.dataobject.internalMessage.InternalMessageDO;
import cn.iocoder.yudao.module.ecw.dal.dataobject.internalMessageTo.InternalMessageToDO;
import cn.iocoder.yudao.module.ecw.dal.mysql.internalMessage.InternalMessageMapper;
import cn.iocoder.yudao.module.ecw.dal.mysql.internalMessageTo.InternalMessageToMapper;
import cn.iocoder.yudao.module.ecw.vo.internalMessage.InternalMessageBackVO;
import cn.iocoder.yudao.module.ecw.vo.internalMessage.InternalMessageCreateReqVO;
import cn.iocoder.yudao.module.ecw.vo.internalMessage.InternalMessageQueryVO;
import cn.iocoder.yudao.module.ecw.vo.internalMessage.InternalMessageUpdateReqVO;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.validation.annotation.Validated;

import javax.annotation.Resource;
import java.util.Collection;
import java.util.List;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.ecw.enums.ErrorCodeConstants.INTERNAL_MESSAGE_NOT_EXISTS;

/**
 * 站内信 Service 实现类
 *
 * @author 系统管理员
 */
@Service
@Validated
public class InternalMessageServiceImpl extends AbstractService<InternalMessageMapper, InternalMessageDO> implements InternalMessageService {

    @Resource
    private InternalMessageMapper internalMessageMapper;

    @Resource
    private InternalMessageToMapper internalMessageToMapper;

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Long createInternalMessage(InternalMessageCreateReqVO createReqVO) {
        // 插入
        InternalMessageDO internalMessage = InternalMessageConvert.INSTANCE.convert(createReqVO);
        internalMessageMapper.insert(internalMessage);

        /**
         * 插入所有接收信息
         */
        if (null != createReqVO.getToIdList() && createReqVO.getToIdList().size() > 0) {
            Long internalMessageId = internalMessage.getId();
            for (Long toId : createReqVO.getToIdList()) {
                if (null != toId) {
                    InternalMessageToDO internalMessageToDO = new InternalMessageToDO();
                    internalMessageToDO.setMessageId(internalMessageId);
                    internalMessageToDO.setToId(toId);
                    internalMessageToMapper.insert(internalMessageToDO);
                }
            }
        }

        // 返回
        return internalMessage.getId();
    }

    @Override
    public void updateInternalMessage(InternalMessageUpdateReqVO updateReqVO) {
        // 校验存在
        this.validateInternalMessageExists(updateReqVO.getId());
        // 更新
        InternalMessageDO updateObj = InternalMessageConvert.INSTANCE.convert(updateReqVO);
        internalMessageMapper.updateById(updateObj);
    }

    @Override
    public void deleteInternalMessage(Long id) {
        // 校验存在
        this.validateInternalMessageExists(id);
        // 删除
        internalMessageMapper.deleteById(id);
    }

    private void validateInternalMessageExists(Long id) {
        if (internalMessageMapper.selectById(id) == null) {
            throw exception(INTERNAL_MESSAGE_NOT_EXISTS);
        }
    }

    @Override
    public InternalMessageDO getInternalMessage(Long id) {
        return internalMessageMapper.selectById(id);
    }

    @Override
    public List<InternalMessageDO> getInternalMessageList(Collection<Long> ids) {
        return internalMessageMapper.selectBatchIds(ids);
    }

    @Override
    public PageResult<InternalMessageDO> getInternalMessagePage(InternalMessageQueryVO query, PageVO page) {
        return internalMessageMapper.selectPage(page, query);
    }

    @Override
    public List<InternalMessageDO> getInternalMessageList(InternalMessageQueryVO query) {
        return internalMessageMapper.selectList(query);
    }

    @Override
    public Long getNotReadInternalMessageTotal(Long userId) {
        return internalMessageMapper.getNotReadInternalMessageTotal(userId);
    }

    @Override
    public PageResult<InternalMessageBackVO> getMyInternalMessagePage(InternalMessageQueryVO query, PageVO page) {
        page.setField("b.id");
        IPage<InternalMessageBackVO> mpPage = MyBatisUtils.buildPage(page);
        QueryWrapperX queryWrapper = new QueryWrapperX();
        queryWrapper.eqIfPresent("a.to_id", query.getUserId());
        queryWrapper.betweenIfPresent("b.send_time", query.getBeginSendTime(), query.getEndSendTime());
        queryWrapper.likeIfPresent("b.title", query.getTitle());
        queryWrapper.eqIfPresent("b.type", query.getType());
        queryWrapper.eqIfPresent("a.status", query.getStatus());
        queryWrapper.betweenIfPresent("b.create_time", query.getBeginCreateTime(), query.getEndCreateTime());
        internalMessageMapper.selectMyInternalMessagePage(mpPage, queryWrapper);

        // 转换返回
        return PageResult.of(mpPage);
    }

    @Override
    public Boolean redInternalMessage(Long userId, Long messageId) {
        LambdaQueryWrapper<InternalMessageToDO> lambdaQueryWrapper = new LambdaQueryWrapper<>();
        lambdaQueryWrapper.eq(InternalMessageToDO::getMessageId, messageId);
        lambdaQueryWrapper.eq(InternalMessageToDO::getToId, userId);
        InternalMessageToDO updateDate = new InternalMessageToDO();
        updateDate.setStatus(1);
        int result = internalMessageToMapper.update(updateDate, lambdaQueryWrapper);
        if (result != 0) {
            return true;
        }
        return false;
    }


    @Override
    public Integer countUserUnreadMessage(Long userId) {
        long count = internalMessageToMapper.selectCount(new LambdaQueryWrapper<InternalMessageToDO>()
                .eq(InternalMessageToDO::getToId, userId)
                .eq(InternalMessageToDO::getStatus, 0)
                .eq(InternalMessageToDO::getDeleted, Boolean.FALSE));
        return Math.toIntExact(count);
    }
}
