package cn.iocoder.yudao.module.ecw.service.internalMessage;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.mybatis.core.service.IService;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.module.ecw.dal.dataobject.internalMessage.InternalMessageDO;
import cn.iocoder.yudao.module.ecw.dal.dataobject.internalMessage.WebInternalMessageDO;
import cn.iocoder.yudao.module.ecw.vo.internalMessage.InternalMessageBackVO;
import cn.iocoder.yudao.module.ecw.vo.internalMessage.InternalMessageCreateReqVO;
import cn.iocoder.yudao.module.ecw.vo.internalMessage.InternalMessageQueryVO;
import cn.iocoder.yudao.module.ecw.vo.internalMessage.InternalMessageUpdateReqVO;

import javax.validation.Valid;
import java.util.Collection;
import java.util.List;

/**
 * 站内信 Service 接口
 *
 * @author 系统管理员
 */
public interface WebInternalMessageService extends IService<WebInternalMessageDO> {

    /**
     * 创建站内信
     *
     * @param createReqVO 创建信息
     * @return 编号
     */
    Long createInternalMessage(@Valid InternalMessageCreateReqVO createReqVO);

    /**
     * 更新站内信
     *
     * @param updateReqVO 更新信息
     */
    void updateInternalMessage(@Valid InternalMessageUpdateReqVO updateReqVO);

    /**
     * 删除站内信
     *
     * @param id 编号
     */
    void deleteInternalMessage(Long id);

    /**
     * 获得站内信
     *
     * @param id 编号
     * @return 站内信
     */
    WebInternalMessageDO getInternalMessage(Long id);

    /**
     * 获得站内信列表
     *
     * @param ids 编号
     * @return 站内信列表
     */
    List<WebInternalMessageDO> getInternalMessageList(Collection<Long> ids);

    /**
     * 获得站内信分页
     *
     * @param page  分页查询
     * @param query 查询
     * @return 站内信分页
     */
    PageResult<WebInternalMessageDO> getInternalMessagePage(InternalMessageQueryVO query, PageVO page);

    /**
     * 获得站内信列表, 用于 Excel 导出
     *
     * @param query 查询
     * @return 站内信列表
     */
    List<WebInternalMessageDO> getInternalMessageList(InternalMessageQueryVO query);

    /**
     * 根据用户ID查询所有未读站内信总数
     *
     * @param userId 用户ID
     * @return 总数
     */
    Long getNotReadInternalMessageTotal(Long userId);

    /**
     * 根据条件得到我的站内信列表
     *
     * @param page  分页查询
     * @param query 查询
     * @return 站内信分页
     */
    PageResult<InternalMessageBackVO> getMyInternalMessagePage(InternalMessageQueryVO query, PageVO page);

    /**
     * 设置用户的某一条消息为已读
     *
     * @param userId
     * @param messageId
     * @return
     */
    Boolean redInternalMessage(Long userId, Long messageId);


    /**
     * 统计未读消息数
     *
     * @param userId 用户ID
     * @return 未读消息数
     */
    Integer countUserUnreadMessage(Long userId);
}
