package cn.iocoder.yudao.module.ecw.service.internalMessage;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.mybatis.core.service.AbstractService;
import cn.iocoder.yudao.framework.mybatis.core.util.MyBatisUtils;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.module.ecw.convert.internalMessage.WebInternalMessageConvert;
import cn.iocoder.yudao.module.ecw.dal.dataobject.internalMessage.WebInternalMessageDO;
import cn.iocoder.yudao.module.ecw.dal.dataobject.internalMessageTo.WebInternalMessageToDO;
import cn.iocoder.yudao.module.ecw.dal.mysql.internalMessage.WebInternalMessageMapper;
import cn.iocoder.yudao.module.ecw.dal.mysql.internalMessageTo.WebInternalMessageToMapper;
import cn.iocoder.yudao.module.ecw.vo.internalMessage.InternalMessageBackVO;
import cn.iocoder.yudao.module.ecw.vo.internalMessage.InternalMessageCreateReqVO;
import cn.iocoder.yudao.module.ecw.vo.internalMessage.InternalMessageQueryVO;
import cn.iocoder.yudao.module.ecw.vo.internalMessage.InternalMessageUpdateReqVO;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.validation.annotation.Validated;

import javax.annotation.Resource;
import java.util.Collection;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.ecw.enums.ErrorCodeConstants.INTERNAL_MESSAGE_NOT_EXISTS;

/**
 * 站内信 Service 实现类
 *
 * @author 系统管理员
 */
@Service
@Validated
public class WebInternalMessageServiceImpl extends AbstractService<WebInternalMessageMapper, WebInternalMessageDO> implements WebInternalMessageService {

    @Resource
    private WebInternalMessageMapper webInternalMessageMapper;

    @Resource
    private WebInternalMessageToMapper webInternalMessageToMapper;

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Long createInternalMessage(InternalMessageCreateReqVO createReqVO) {
        // 插入
        WebInternalMessageDO internalMessage = WebInternalMessageConvert.INSTANCE.convert(createReqVO);
        webInternalMessageMapper.insert(internalMessage);

        /**
         * 插入所有接收信息
         */
        if (null != createReqVO.getToIdList() && createReqVO.getToIdList().size() > 0) {
            Long internalMessageId = internalMessage.getId();
            Set<Long> setToIdList = new HashSet<>(createReqVO.getToIdList());
            for (Long toId : setToIdList) {
                if (null != toId) {
                    WebInternalMessageToDO internalMessageToDO = new WebInternalMessageToDO();
                    internalMessageToDO.setMessageId(internalMessageId);
                    internalMessageToDO.setToId(toId);
                    webInternalMessageToMapper.insert(internalMessageToDO);
                }
            }
        }

        // 返回
        return internalMessage.getId();
    }

    @Override
    public void updateInternalMessage(InternalMessageUpdateReqVO updateReqVO) {
        // 校验存在
        this.validateInternalMessageExists(updateReqVO.getId());
        // 更新
        WebInternalMessageDO updateObj = WebInternalMessageConvert.INSTANCE.convert(updateReqVO);
        webInternalMessageMapper.updateById(updateObj);
    }

    @Override
    public void deleteInternalMessage(Long id) {
        // 校验存在
        this.validateInternalMessageExists(id);
        // 删除
        webInternalMessageMapper.deleteById(id);
    }

    private void validateInternalMessageExists(Long id) {
        if (webInternalMessageMapper.selectById(id) == null) {
            throw exception(INTERNAL_MESSAGE_NOT_EXISTS);
        }
    }

    @Override
    public WebInternalMessageDO getInternalMessage(Long id) {
        return webInternalMessageMapper.selectById(id);
    }

    @Override
    public List<WebInternalMessageDO> getInternalMessageList(Collection<Long> ids) {
        return webInternalMessageMapper.selectBatchIds(ids);
    }

    @Override
    public PageResult<WebInternalMessageDO> getInternalMessagePage(InternalMessageQueryVO query, PageVO page) {
        return webInternalMessageMapper.selectPage(page, query);
    }

    @Override
    public List<WebInternalMessageDO> getInternalMessageList(InternalMessageQueryVO query) {
        return webInternalMessageMapper.selectList(query);
    }

    @Override
    public Long getNotReadInternalMessageTotal(Long userId) {
        return webInternalMessageMapper.getNotReadInternalMessageTotal(userId);
    }

    @Override
    public PageResult<InternalMessageBackVO> getMyInternalMessagePage(InternalMessageQueryVO query, PageVO page) {
        IPage<InternalMessageBackVO> mpPage = MyBatisUtils.buildPage(page);
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("a.to_id", query.getUserId());
        if (null != query.getType()) {
            queryWrapper.eq("b.type", query.getType());
        }
        if (null != query.getStatus()) {
            queryWrapper.eq("a.status", query.getStatus());
        }
        queryWrapper.eq(" b.deleted", 0);
        queryWrapper.orderByDesc("b.id");
        webInternalMessageMapper.selectMyInternalMessagePage(mpPage, queryWrapper);

        // 转换返回
        return PageResult.of(mpPage);
    }

    @Override
    public Boolean redInternalMessage(Long userId, Long messageId) {
        LambdaQueryWrapper<WebInternalMessageToDO> lambdaQueryWrapper = new LambdaQueryWrapper<>();
        lambdaQueryWrapper.eq(WebInternalMessageToDO::getMessageId, messageId);
        lambdaQueryWrapper.eq(WebInternalMessageToDO::getToId, userId);
        WebInternalMessageToDO updateDate = new WebInternalMessageToDO();
        updateDate.setStatus(1);
        int result = webInternalMessageToMapper.update(updateDate, lambdaQueryWrapper);
        if (result != 0) {
            return true;
        }
        return false;
    }

    @Override
    public Integer countUserUnreadMessage(Long userId) {
        long count = webInternalMessageToMapper.selectCount(new LambdaQueryWrapper<WebInternalMessageToDO>()
                .eq(WebInternalMessageToDO::getToId, userId)
                .eq(WebInternalMessageToDO::getStatus, 0)
                .eq(WebInternalMessageToDO::getDeleted, Boolean.FALSE));
        return Math.toIntExact(count);
    }
}
