package cn.iocoder.yudao.module.ecw.service.internalMessageTo;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.mybatis.core.service.AbstractService;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.module.ecw.convert.internalMessageTo.InternalMessageToConvert;
import cn.iocoder.yudao.module.ecw.dal.dataobject.internalMessageTo.InternalMessageToDO;
import cn.iocoder.yudao.module.ecw.dal.mysql.internalMessageTo.InternalMessageToMapper;
import cn.iocoder.yudao.module.ecw.vo.internalMessageTo.InternalMessageToCreateReqVO;
import cn.iocoder.yudao.module.ecw.vo.internalMessageTo.InternalMessageToQueryVO;
import cn.iocoder.yudao.module.ecw.vo.internalMessageTo.InternalMessageToUpdateReqVO;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;

import javax.annotation.Resource;
import java.util.Collection;
import java.util.List;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.ecw.enums.ErrorCodeConstants.INTERNAL_MESSAGE_TO_NOT_EXISTS;

/**
 * 站内信读取信息 Service 实现类
 *
 * @author 系统管理员
 */
@Service
@Validated
public class WebInternalMessageToServiceImpl extends AbstractService<InternalMessageToMapper, InternalMessageToDO> implements InternalMessageToService {

    @Resource
    private InternalMessageToMapper internalMessageToMapper;

    @Override
    public Long createInternalMessageTo(InternalMessageToCreateReqVO createReqVO) {
        // 插入
        InternalMessageToDO internalMessageTo = InternalMessageToConvert.INSTANCE.convert(createReqVO);
        internalMessageToMapper.insert(internalMessageTo);
        // 返回
        return internalMessageTo.getId();
    }

    @Override
    public void updateInternalMessageTo(InternalMessageToUpdateReqVO updateReqVO) {
        // 校验存在
        this.validateInternalMessageToExists(updateReqVO.getId());
        // 更新
        InternalMessageToDO updateObj = InternalMessageToConvert.INSTANCE.convert(updateReqVO);
        internalMessageToMapper.updateById(updateObj);
    }

    @Override
    public void deleteInternalMessageTo(Long id) {
        // 校验存在
        this.validateInternalMessageToExists(id);
        // 删除
        internalMessageToMapper.deleteById(id);
    }

    private void validateInternalMessageToExists(Long id) {
        if (internalMessageToMapper.selectById(id) == null) {
            throw exception(INTERNAL_MESSAGE_TO_NOT_EXISTS);
        }
    }

    @Override
    public InternalMessageToDO getInternalMessageTo(Long id) {
        return internalMessageToMapper.selectById(id);
    }

    @Override
    public List<InternalMessageToDO> getInternalMessageToList(Collection<Long> ids) {
        return internalMessageToMapper.selectBatchIds(ids);
    }

    @Override
    public PageResult<InternalMessageToDO> getInternalMessageToPage(InternalMessageToQueryVO query, PageVO page) {
        return internalMessageToMapper.selectPage(page, query);
    }

    @Override
    public List<InternalMessageToDO> getInternalMessageToList(InternalMessageToQueryVO query) {
        return internalMessageToMapper.selectList(query);
    }
}
