package cn.iocoder.yudao.module.ecw.service.ladingTemplate;

import cn.iocoder.yudao.framework.security.core.util.SecurityFrameworkUtils;
import cn.iocoder.yudao.module.ecw.controller.admin.ladingTemplate.vo.LadingTemplateCreateReqVO;
import cn.iocoder.yudao.module.ecw.controller.admin.ladingTemplate.vo.LadingTemplateUpdateReqVO;
import cn.iocoder.yudao.module.ecw.convert.ladingTemplate.LadingTemplateConvert;
import cn.iocoder.yudao.module.ecw.dal.dataobject.ladingTemplate.LadingTemplateDO;
import cn.iocoder.yudao.module.ecw.dal.mysql.ladingTemplate.LadingTemplateMapper;
import com.alibaba.fastjson.JSON;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.util.HtmlUtils;

import javax.annotation.Resource;
import java.util.*;
import java.util.stream.Collectors;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.ecw.enums.ErrorCodeConstants.LADING_TEMPLATE_NOT_EXISTS;

/**
 * 提单模板 Service 实现类
 *
 * @author 系统管理员
 */
@Service
@Validated
public class LadingTemplateServiceImpl implements LadingTemplateService {

    @Resource
    private LadingTemplateMapper ladingTemplateMapper;

    @Override
    public Long createLadingTemplate(LadingTemplateCreateReqVO createReqVO) {
        Long id = 0L;
        if(StringUtils.isNotBlank(createReqVO.getLineId())){
            if(createReqVO.getLineId().contains(",")){
                String[] lineIds = createReqVO.getLineId().split(",");
                Set<String> collect = Arrays.stream(lineIds).collect(Collectors.toSet());
                for (String line : collect) {
                    LadingTemplateDO ladingTemplateDO = ladingTemplateMapper.selectOne(LadingTemplateDO::getLineId, line);
                    if(ladingTemplateDO!=null){
                        if (JSON.parseArray(createReqVO.getAccount()).size() > 0) {
                            ladingTemplateDO.setAccount(createReqVO.getAccount());
                        }
                        if (StringUtils.isNotBlank(createReqVO.getContentZh())) {
                            ladingTemplateDO.setContentZh(createReqVO.getContentZh());
                        }
                        if (StringUtils.isNotBlank(createReqVO.getPrefixCounter())) {
                            ladingTemplateDO.setPrefixCounter(createReqVO.getPrefixCounter());
                        }
                        if (StringUtils.isNotBlank(createReqVO.getTitleZh())) {
                            ladingTemplateDO.setTitleZh(createReqVO.getTitleZh());
                        }
                        ladingTemplateDO.setUpdateTime(new Date());
                        ladingTemplateDO.setUpdater(String.valueOf(SecurityFrameworkUtils.getLoginUserId()));
                        ladingTemplateMapper.updateById(ladingTemplateDO);
                    }else {
                        LadingTemplateDO ladingTemplate = new LadingTemplateDO();
                        ladingTemplate.setAccount(createReqVO.getAccount());
                        ladingTemplate.setContentZh(createReqVO.getContentZh());
                        ladingTemplate.setLineId(line);
                        ladingTemplate.setPrefixCounter(createReqVO.getPrefixCounter());
                        ladingTemplate.setStatus(createReqVO.getStatus());
                        ladingTemplate.setTitleZh(createReqVO.getTitleZh());
                        ladingTemplateMapper.insert(ladingTemplate);
                    }
                }
            }else {
                LadingTemplateDO ladingTemplateDO = ladingTemplateMapper.selectOne(LadingTemplateDO::getLineId, createReqVO.getLineId());
                LadingTemplateDO ladingTemplate = LadingTemplateConvert.INSTANCE.convert(createReqVO);
                if (ladingTemplateDO==null) {
                    // 插入
                    ladingTemplateMapper.insert(ladingTemplate);
                    // 返回
                }else {
                    ladingTemplate.setId(ladingTemplateDO.getId());
                    ladingTemplate.setUpdateTime(new Date());
                    ladingTemplate.setUpdater(String.valueOf(SecurityFrameworkUtils.getLoginUserId()));
                    ladingTemplateMapper.updateById(ladingTemplate);
                }
                id = ladingTemplate.getId();
            }
        }
        return id;
    }

    @Override
    public void updateLadingTemplate(LadingTemplateUpdateReqVO updateReqVO) {
        // 校验存在
        this.validateLadingTemplateExists(updateReqVO.getId());
        // 更新
        LadingTemplateDO updateObj = LadingTemplateConvert.INSTANCE.convert(updateReqVO);
        ladingTemplateMapper.updateById(updateObj);
    }

    @Override
    public void deleteLadingTemplate(Long id) {
        // 校验存在
        this.validateLadingTemplateExists(id);
        // 删除
        ladingTemplateMapper.deleteById(id);
    }

    private void validateLadingTemplateExists(Long id) {
        if (ladingTemplateMapper.selectById(id) == null) {
            throw exception(LADING_TEMPLATE_NOT_EXISTS);
        }
    }

    @Override
    public LadingTemplateDO getLadingTemplate(Long id) {
        LadingTemplateDO ladingTemplateDO = ladingTemplateMapper.selectById(id);
        if (ladingTemplateDO != null) {
            if(StringUtils.isNotBlank(ladingTemplateDO.getContentZh())){
                ladingTemplateDO.setContentZh(HtmlUtils.htmlUnescape(ladingTemplateDO.getContentZh()));
            }
            if (StringUtils.isNotBlank(ladingTemplateDO.getTitleZh())){
                ladingTemplateDO.setTitleZh(HtmlUtils.htmlUnescape(ladingTemplateDO.getTitleZh()));
            }
        }
        return ladingTemplateDO;
    }

    @Override
    public List<LadingTemplateDO> getLadingTemplateList(Collection<Long> ids) {
        return ladingTemplateMapper.selectBatchIds(ids);
    }

    @Override
    public LadingTemplateDO getLadingTemplateByLineId(Long lineId) {
        LadingTemplateDO ladingTemplateDO = ladingTemplateMapper.selectOne(LadingTemplateDO::getLineId, lineId);
        if (ladingTemplateDO != null) {
            if(StringUtils.isNotBlank(ladingTemplateDO.getContentZh())){
                ladingTemplateDO.setContentZh(HtmlUtils.htmlUnescape(ladingTemplateDO.getContentZh()));
            }
            if (StringUtils.isNotBlank(ladingTemplateDO.getTitleZh())){
                ladingTemplateDO.setTitleZh(HtmlUtils.htmlUnescape(ladingTemplateDO.getTitleZh()));
            }
        }
        return ladingTemplateDO;
    }

//    @Override
//    public PageResult<LadingTemplateDO> getLadingTemplatePage(LadingTemplateQueryVO query, PageVO page) {
//        return ladingTemplateMapper.selectPage(page, query);
//    }

//    @Override
//    public List<LadingTemplateDO> getLadingTemplateList(LadingTemplateQueryVO query) {
//        return ladingTemplateMapper.selectList(query);
//    }
}
