package cn.iocoder.yudao.module.ecw.service.messageLeave;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.mybatis.core.service.AbstractService;
import cn.iocoder.yudao.module.ecw.controller.admin.messageLeave.vo.*;
import cn.iocoder.yudao.module.ecw.convert.messageLeave.MessageLeaveConvert;
import cn.iocoder.yudao.module.ecw.dal.dataobject.messageLeave.MessageLeaveDO;
import cn.iocoder.yudao.module.ecw.dal.mysql.messageLeave.MessageLeaveMapper;
import cn.iocoder.yudao.module.ecw.enums.MessageLeaveStatusEnum;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;

import javax.annotation.Resource;
import java.util.Collection;
import java.util.Date;
import java.util.List;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.ecw.enums.ErrorCodeConstants.MESSAGE_LEAVE_NOT_EXISTS;

/**
 * 留言 Service 实现类
 *
 * @author yanghao
 */
@Service
@Validated
public class MessageLeaveServiceImpl extends AbstractService<MessageLeaveMapper, MessageLeaveDO> implements MessageLeaveService {

    @Resource
    private MessageLeaveMapper messageLeaveMapper;

    @Override
    public Long createMessageLeave(MessageLeaveCreateReqVO createReqVO) {
        // 插入
        MessageLeaveDO messageLeave = MessageLeaveConvert.INSTANCE.convert(createReqVO);
        messageLeave.setCreateTime(new Date());
        messageLeaveMapper.insert(messageLeave);
        // 返回
        return messageLeave.getId();
    }

    @Override
    public void updateMessageLeave(MessageLeaveUpdateReqVO updateReqVO) {
        // 校验存在
        this.validateMessageLeaveExists(updateReqVO.getId());
        // 更新
        MessageLeaveDO updateObj = MessageLeaveConvert.INSTANCE.convert(updateReqVO);
        messageLeaveMapper.updateById(updateObj);
    }

    @Override
    public void deleteReply(Long id) {
        MessageLeaveDO messageLeaveDO = messageLeaveMapper.selectById(id);
        if (messageLeaveDO == null) {
            throw exception(MESSAGE_LEAVE_NOT_EXISTS);
        }

        messageLeaveDO.setReplyTime(null);
        messageLeaveDO.setReplyContent(null);
        messageLeaveDO.setStatus(MessageLeaveStatusEnum.NO_REPLY.getValue());
        messageLeaveDO.setReplyUserId(null);

        messageLeaveMapper.updateById(messageLeaveDO);
    }

    @Override
    public void reply(MessageLeaveReplyReqVO replyReqVO) {

        // 校验存在
        this.validateMessageLeaveExists(replyReqVO.getId());
        // 更新
        MessageLeaveDO updateObj = MessageLeaveConvert.INSTANCE.convert(replyReqVO);

        //设置已回复状态
        updateObj.setStatus(MessageLeaveStatusEnum.REPLIED.getValue());
        updateObj.setReplyTime(new Date());

        messageLeaveMapper.updateById(updateObj);
    }

    @Override
    public void deleteMessageLeave(Long id) {
        // 校验存在
        this.validateMessageLeaveExists(id);
        // 删除
        messageLeaveMapper.deleteById(id);
    }

    private void validateMessageLeaveExists(Long id) {
        if (messageLeaveMapper.selectById(id) == null) {
            throw exception(MESSAGE_LEAVE_NOT_EXISTS);
        }
    }

    @Override
    public MessageLeaveDO getMessageLeave(Long id) {
        return messageLeaveMapper.selectById(id);
    }

    @Override
    public List<MessageLeaveDO> getMessageLeaveList(Collection<Long> ids) {
        return messageLeaveMapper.selectBatchIds(ids);
    }

    @Override
    public PageResult<MessageLeaveDO> getMessageLeavePage(MessageLeavePageReqVO pageReqVO) {
        return messageLeaveMapper.selectPage(pageReqVO);
    }

    @Override
    public List<MessageLeaveDO> getMessageLeaveList(MessageLeaveExportReqVO exportReqVO) {
        return messageLeaveMapper.selectList(exportReqVO);
    }

}
