package cn.iocoder.yudao.module.ecw.service.node;

import cn.iocoder.yudao.framework.mybatis.core.util.MyBatisUtils;
import cn.iocoder.yudao.module.ecw.api.node.dto.NodeTreeRegionDTO;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;

import java.util.*;
import cn.iocoder.yudao.module.ecw.controller.admin.node.vo.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.node.NodeDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;

import cn.iocoder.yudao.module.ecw.convert.node.NodeConvert;
import cn.iocoder.yudao.module.ecw.dal.mysql.node.NodeMapper;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.ecw.enums.ErrorCodeConstants.*;

/**
 * 服务网点 Service 实现类
 *
 * @author wlh
 */
@Service
@Validated
public class NodeServiceImpl implements NodeService {

    @Resource
    private NodeMapper nodeMapper;

    @Override
    public Long createNode(NodeCreateReqVO createReqVO) {
        // 插入
        NodeDO node = NodeConvert.INSTANCE.convert(createReqVO);
        nodeMapper.insert(node);
        // 返回
        return node.getId();
    }

    @Override
    public void updateNode(NodeUpdateReqVO updateReqVO) {
        // 校验存在
        this.validateNodeExists(updateReqVO.getId());
        // 更新
        NodeDO updateObj = NodeConvert.INSTANCE.convert(updateReqVO);
        nodeMapper.updateById(updateObj);
    }

    @Override
    public void deleteNode(Long id) {
        // 校验存在
        this.validateNodeExists(id);
        // 删除
        nodeMapper.deleteById(id);
    }

    private void validateNodeExists(Long id) {
        if (nodeMapper.selectById(id) == null) {
            throw exception(NODE_NOT_EXISTS);
        }
    }

    @Override
    public NodeDO getNode(Long id) {
        return nodeMapper.selectById(id);
    }

    @Override
    public List<NodeDO> getNodeList(Collection<Long> ids) {
        return nodeMapper.selectBatchIds(ids);
    }

    @Override
    public List<NodeDO> getNodeList() {
        return nodeMapper.selectList();
    }

    @Override
    public PageResult<NodeDO> getNodePage(NodePageReqVO pageReqVO) {
        return nodeMapper.selectPage(pageReqVO);
    }

    @Override
    public List<NodeDO> getNodeList(NodeExportReqVO exportReqVO) {
        return nodeMapper.selectList(exportReqVO);
    }

    @Override
    public List<NodeTreeRegionSimpleVO> getNodeTreeRegion() {
        List<NodeTreeRegionDTO> nodeList = nodeMapper.getNodeTreeRegionList();
        Map<Long, NodeTreeRegionSimpleVO> countryMap = new LinkedHashMap<>();
        Map<Long, Map<Long, NodeTreeRegionSimpleVO.NodeCity>> cityMap = new LinkedHashMap<>();

        for (NodeTreeRegionDTO dto : nodeList) {
            Long countryId = dto.getCountryId();
            String countryZh = dto.getCountryZh();
            String countryEn = dto.getCountryEn();

            Long cityId = dto.getCityId();
            String cityZh = dto.getCityZh();
            String cityEn = dto.getCityEn();

            Long nodeId = dto.getNodeId();
            String nodeZh = dto.getNodeZh();
            String nodeEn = dto.getNodeEn();

            // 处理国家
            NodeTreeRegionSimpleVO countryVO = countryMap.computeIfAbsent(countryId, id -> {
                NodeTreeRegionSimpleVO vo = new NodeTreeRegionSimpleVO();
                vo.setId(id);
                vo.setLabelZh(countryZh.trim());
                vo.setLabelEn(countryEn);
                vo.setChildren(new ArrayList<>());
                return vo;
            });

            // 处理城市
            Map<Long, NodeTreeRegionSimpleVO.NodeCity> cities = cityMap.computeIfAbsent(countryId, k -> new LinkedHashMap<>());
            NodeTreeRegionSimpleVO.NodeCity cityVO = cities.computeIfAbsent(cityId, id -> {
                NodeTreeRegionSimpleVO.NodeCity city = new NodeTreeRegionSimpleVO.NodeCity();
                city.setId(id);
                city.setLabelZh(cityZh.trim());
                city.setLabelEn(cityEn);
                city.setChildren(new ArrayList<>());
                return city;
            });

            // 处理网点
            NodeTreeRegionSimpleVO.Node node = new NodeTreeRegionSimpleVO.Node();
            node.setId(nodeId);
            node.setLabelZh(nodeZh);
            node.setLabelEn(nodeEn);
            cityVO.getChildren().add(node);

            if (!countryVO.getChildren().contains(cityVO)) {
                countryVO.getChildren().add(cityVO);
            }
        }
        return new ArrayList<>(countryMap.values());
    }

    @Override
    public PageResult<NodeDO> getNodePageList(NodePageReqVO pageReqVO) {
        IPage<NodeDO> mpPage = MyBatisUtils.buildPage(pageReqVO);
        mpPage = nodeMapper.queryPageList(mpPage, pageReqVO.getCityName(), pageReqVO.getKeywords());
        PageResult<NodeDO> pageResult = new PageResult<NodeDO>();

        pageResult.setList( mpPage.getRecords() );
        pageResult.setTotal( mpPage.getTotal() );
        pageResult.setRows( mpPage.getSize() );
        pageResult.setPage( mpPage.getCurrent() );
        pageResult.setPages( mpPage.getPages() );
        return pageResult;
    }
}
