package cn.iocoder.yudao.module.ecw.service.orderCode;

import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;

import java.util.*;
import cn.iocoder.yudao.module.ecw.controller.admin.orderCode.vo.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.orderCode.OrderCodeDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;

import cn.iocoder.yudao.module.ecw.convert.orderCode.OrderCodeConvert;
import cn.iocoder.yudao.module.ecw.dal.mysql.orderCode.OrderCodeMapper;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.ecw.enums.ErrorCodeConstants.*;

/**
 * 单号配置 Service 实现类
 *
 * @author yanghao
 */
@Service
@Validated
public class OrderCodeServiceImpl implements OrderCodeService {

    @Resource
    private OrderCodeMapper orderCodeMapper;

    @Override
    public Long createOrderCode(OrderCodeCreateReqVO createReqVO) {
        // 插入
        OrderCodeDO orderCode = OrderCodeConvert.INSTANCE.convert(createReqVO);
        orderCodeMapper.insert(orderCode);
        // 返回
        return orderCode.getId();
    }

    @Override
    public void updateOrderCode(OrderCodeUpdateReqVO updateReqVO) {
        // 校验存在
        this.validateOrderCodeExists(updateReqVO.getId());
        // 更新
        OrderCodeDO updateObj = OrderCodeConvert.INSTANCE.convert(updateReqVO);
        orderCodeMapper.updateById(updateObj);
    }

    @Override
    public void deleteOrderCode(Long id) {
        // 校验存在
        this.validateOrderCodeExists(id);
        // 删除
        orderCodeMapper.deleteById(id);
    }

    private void validateOrderCodeExists(Long id) {
        if (orderCodeMapper.selectById(id) == null) {
            throw exception(ORDER_CODE_NOT_EXISTS);
        }
    }

    @Override
    public OrderCodeDO getOrderCode(Long id) {
        return orderCodeMapper.selectById(id);
    }

    @Override
    public List<OrderCodeDO> getOrderCodeList(Collection<Long> ids) {
        return orderCodeMapper.selectBatchIds(ids);
    }

    @Override
    public PageResult<OrderCodeDO> getOrderCodePage(OrderCodePageReqVO pageReqVO) {
        return orderCodeMapper.selectPage(pageReqVO);
    }

    @Override
    public List<OrderCodeDO> getOrderCodeList(OrderCodeExportReqVO exportReqVO) {
        return orderCodeMapper.selectList(exportReqVO);
    }

}
