package cn.iocoder.yudao.module.ecw.service.pickupLoc;

import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;

import java.util.*;
import cn.iocoder.yudao.module.ecw.controller.admin.pickupLoc.vo.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.pickupLoc.PickupLocDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;

import cn.iocoder.yudao.module.ecw.convert.pickupLoc.PickupLocConvert;
import cn.iocoder.yudao.module.ecw.dal.mysql.pickupLoc.PickupLocMapper;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.ecw.enums.ErrorCodeConstants.*;

/**
 * 自提点 Service 实现类
 *
 * @author wlh
 */
@Service
@Validated
public class PickupLocServiceImpl implements PickupLocService {

    @Resource
    private PickupLocMapper pickupLocMapper;

    @Override
    public Long createPickupLoc(PickupLocCreateReqVO createReqVO) {
        // 插入
        PickupLocDO pickupLoc = PickupLocConvert.INSTANCE.convert(createReqVO);
        pickupLocMapper.insert(pickupLoc);
        // 返回
        return pickupLoc.getId();
    }

    @Override
    public void updatePickupLoc(PickupLocUpdateReqVO updateReqVO) {
        // 校验存在
        this.validatePickupLocExists(updateReqVO.getId());
        // 更新
        PickupLocDO updateObj = PickupLocConvert.INSTANCE.convert(updateReqVO);
        pickupLocMapper.updateById(updateObj);
    }

    @Override
    public void deletePickupLoc(Long id) {
        // 校验存在
        this.validatePickupLocExists(id);
        // 删除
        pickupLocMapper.deleteById(id);
    }

    private void validatePickupLocExists(Long id) {
        if (pickupLocMapper.selectById(id) == null) {
            throw exception(PICKUP_LOC_NOT_EXISTS);
        }
    }

    @Override
    public PickupLocDO getPickupLoc(Long id) {
        return pickupLocMapper.selectById(id);
    }

    @Override
    public List<PickupLocDO> getPickupLocList(Collection<Long> ids) {
        return pickupLocMapper.selectBatchIds(ids);
    }

    @Override
    public PageResult<PickupLocDO> getPickupLocPage(PickupLocPageReqVO pageReqVO) {
        return pickupLocMapper.selectPage(pageReqVO);
    }

    @Override
    public List<PickupLocDO> getPickupLocList(PickupLocExportReqVO exportReqVO) {
        return pickupLocMapper.selectList(exportReqVO);
    }

}
