package cn.iocoder.yudao.module.ecw.service.region;

import java.util.*;
import javax.validation.*;
import cn.iocoder.yudao.module.ecw.controller.admin.region.vo.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.region.RegionDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;

/**
 * 区域设置 Service 接口
 *
 * @author 江楠
 */
public interface RegionService {

    /**
     * 创建区域设置
     *
     * @param createReqVO 创建信息
     * @return 编号
     */
    Long createRegion(@Valid RegionCreateReqVO createReqVO);

    /**
     * 更新区域设置
     *
     * @param updateReqVO 更新信息
     */
    void updateRegion(@Valid RegionUpdateReqVO updateReqVO);
    void updateRegionStatus(@Valid RegionUpdateStatusReqVO updateReqVO);

    /**
     * 删除区域设置
     *
     * @param id 编号
     */
    void deleteRegion(Long id);

    /**
     * 获得区域设置
     *
     * @param id 编号
     * @return 区域设置
     */
    RegionDO getRegion(Long id);

    /**
     * 获得区域设置列表
     *
     * @param ids 编号
     * @return 区域设置列表
     */
    List<RegionDO> getRegionList(Collection<Long> ids);


    /**
     * 筛选部门列表
     *
     * @param reqVO 筛选条件请求 VO
     * @return 部门列表
     */
    List<RegionDO> getSimpleDepts(RegionListReqVO reqVO);
    /**
     * 获得区域设置分页
     *
     * @param pageReqVO 分页查询
     * @return 区域设置分页
     */
    PageResult<RegionDO> getRegionPage(RegionPageReqVO pageReqVO);

    /**
     * 获得区域设置列表, 用于 Excel 导出
     *
     * @param exportReqVO 查询条件
     * @return 区域设置列表
     */
    List<RegionDO> getRegionList(RegionExportReqVO exportReqVO);

    List<RegionDO> getRegionListByTree(RegionListReqVO exportReqVO);

    List<RegionDO> getByParent(Long id);

    /**
     * 获取所有城市列表
     */
    List<RegionDO> getCityList();
    List<RegionDO> getImportExportCityList(TradeRegionListReqVO listReqVO);

    List<RegionDO> getContinentCountry();

    List<RegionDO> getImportExportCountryList();

    List<RegionDO> getCityListByParentId(Long parentId);
}
