package cn.iocoder.yudao.module.ecw.service.region;

import cn.hutool.core.util.StrUtil;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;

import java.util.*;
import cn.iocoder.yudao.module.ecw.controller.admin.region.vo.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.region.RegionDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;

import cn.iocoder.yudao.module.ecw.convert.region.RegionConvert;
import cn.iocoder.yudao.module.ecw.dal.mysql.region.RegionMapper;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.ecw.enums.ErrorCodeConstants.*;

/**
 * 区域设置 Service 实现类
 *
 * @author 江楠
 */
@Service
@Validated
public class RegionServiceImpl implements RegionService {

    @Resource
    private RegionMapper regionMapper;

    @Override
    public Long createRegion(RegionCreateReqVO createReqVO) {
        if (Objects.equals(createReqVO.getType(), "1") || Objects.equals(createReqVO.getType(), "3")){
            if (StringUtils.isBlank(createReqVO.getLabelCode())){
                throw exception(REGION_LABEL_CODE_NOT_NULL);
            }
            String[] codes = createReqVO.getLabelCode().split(StrUtil.DASHED);
            if (codes.length < 2){
                throw exception(REGION_LABEL_CODE_COUNTRY_AND_CITY_AND_AIR_COUNTRY);
            }
        }
        // 插入
        RegionDO region = RegionConvert.INSTANCE.convert(createReqVO);
        regionMapper.insert(region);
        // 返回
        return region.getId();
    }

    @Override
    public void updateRegion(RegionUpdateReqVO updateReqVO) {
        if (Objects.equals(updateReqVO.getType(), "1") || Objects.equals(updateReqVO.getType(), "3")){
            if (StringUtils.isBlank(updateReqVO.getLabelCode())){
                throw exception(REGION_LABEL_CODE_NOT_NULL);
            }
            String[] codes = updateReqVO.getLabelCode().split(StrUtil.DASHED);
            if (codes.length < 2){
                throw exception(REGION_LABEL_CODE_COUNTRY_AND_CITY_AND_AIR_COUNTRY);
            }
        }
        // 校验存在
        this.validateRegionExists(updateReqVO.getId());
        // 更新
        RegionDO updateObj = RegionConvert.INSTANCE.convert(updateReqVO);
        regionMapper.updateById(updateObj);
    }

    @Override
    public void updateRegionStatus(RegionUpdateStatusReqVO updateReqVO) {
        // 校验存在
        this.validateRegionExists(updateReqVO.getId());
        // 更新
        RegionDO updateObj = RegionConvert.INSTANCE.convert(updateReqVO);
        regionMapper.updateById(updateObj);

    }

    @Override
    public void deleteRegion(Long id) {
        // 校验存在
        this.validateRegionExists(id);
        // 删除
        regionMapper.deleteById(id);
    }

    private void validateRegionExists(Long id) {
        if (regionMapper.selectById(id) == null) {
            throw exception(REGION_NOT_EXISTS);
        }
    }

    @Override
    public RegionDO getRegion(Long id) {
        return regionMapper.selectById(id);
    }

    @Override
    public List<RegionDO> getRegionList(Collection<Long> ids) {
        return regionMapper.selectBatchIds(ids);
    }

    @Override
    public List<RegionDO> getSimpleDepts(RegionListReqVO reqVO) {
        return regionMapper.selectList(reqVO);
    }

    @Override
    public PageResult<RegionDO> getRegionPage(RegionPageReqVO pageReqVO) {
        return regionMapper.selectPage(pageReqVO);
    }

    @Override
    public List<RegionDO> getRegionList(RegionExportReqVO exportReqVO) {
        return regionMapper.selectList(exportReqVO);
    }

    @Override
    public List<RegionDO> getRegionListByTree(RegionListReqVO exportReqVO) {
        return regionMapper.selectList(exportReqVO);
    }


    @Override
    public List<RegionDO> getByParent(Long id) {
        return regionMapper.getByParentId(id);
    }

    @Override
    public List<RegionDO> getCityList() {
        return regionMapper.getCityList();
    }

    @Override
    public List<RegionDO> getImportExportCityList(TradeRegionListReqVO listReqVO) {
        return regionMapper.selectImportAndExportCity(listReqVO);
    }

    @Override
    public List<RegionDO> getContinentCountry() {
        return regionMapper.getContinentCountry();
    }

    @Override
    public List<RegionDO> getImportExportCountryList() {
        return regionMapper.getImportExportCountryList();
    }

    @Override
    public List<RegionDO> getCityListByParentId(Long parentId) {
        return regionMapper.getCityListByParentId(parentId);
    }
}
