package cn.iocoder.yudao.module.ecw.service.setting;

import cn.hutool.core.collection.CollectionUtil;
import cn.iocoder.yudao.framework.mybatis.core.query.LambdaQueryWrapperX;
import com.baomidou.mybatisplus.core.conditions.Wrapper;
import org.springframework.stereotype.Service;

import org.springframework.transaction.annotation.Transactional;
import org.springframework.validation.annotation.Validated;

import java.util.*;
import java.util.stream.Collectors;

import cn.iocoder.yudao.module.ecw.controller.admin.setting.vo.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.setting.SettingDO;

import cn.iocoder.yudao.module.ecw.convert.setting.SettingConvert;
import cn.iocoder.yudao.module.ecw.dal.mysql.setting.SettingMapper;

import javax.annotation.Resource;


/**
 * 全局配置 Service 实现类
 *
 * @author wlh
 */
@Service
@Validated
public class SettingServiceImpl implements SettingService {
    @Resource
    private SettingMapper settingMapper;

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void createSetting(SettingCreateReqVO createReqVO) {
        List<SettingBaseVO> settingList = createReqVO.getSettingList();
        if(CollectionUtil.isEmpty(settingList)) return;
        settingList = settingList.stream()
                .filter(t -> t.getKeyValue() != null)
                .collect(Collectors.toList());

        List<SettingDO> settingDOList = SettingConvert.INSTANCE.convertList2(settingList);
        settingDOList.forEach(t -> {
            Wrapper<SettingDO> query = new LambdaQueryWrapperX<SettingDO>()
                    .eq(SettingDO::getKeyName, t.getKeyName())
                    .eq(SettingDO::getKeyType, t.getKeyType());
            SettingDO settingDO = settingMapper.selectOne(query);
            if(settingDO == null) {
                settingMapper.insert(t);
            } else {
                settingMapper.update(t, query);
            }
        });
    }

    @Override
    public List<SettingDO> getSettingList(SettingBaseVO settingBaseVO) {
        return settingMapper.selectList(settingBaseVO);
    }

}
