package cn.iocoder.yudao.module.ecw.service.supplier;

import java.util.*;
import javax.validation.*;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.mybatis.core.service.IService;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.module.ecw.controller.admin.supplier.vo.supplierResource.SupplierResourceCreateReqVO;
import cn.iocoder.yudao.module.ecw.controller.admin.supplier.vo.supplierResource.SupplierResourceQueryVO;
import cn.iocoder.yudao.module.ecw.controller.admin.supplier.vo.supplierResource.SupplierResourceUpdateReqVO;
import cn.iocoder.yudao.module.ecw.dal.dataobject.supplier.SupplierResourceDO;

/**
 * 国内供应商优质资源条件 Service 接口
 *
 * @author wlh
 */
public interface SupplierResourceService extends IService<SupplierResourceDO> {

    /**
     * 创建国内供应商优质资源条件
     * @param createReqVO 创建信息
     * @return 编号
     */
    Long createSupplierResource(@Valid SupplierResourceCreateReqVO createReqVO);

    /**
     * 更新国内供应商优质资源条件
     * @param updateReqVO 更新信息
     */
    void updateSupplierResource(@Valid SupplierResourceUpdateReqVO updateReqVO);

    /**
     * 删除国内供应商优质资源条件
     * @param id 编号
     */
    void deleteSupplierResource(Long id);

    /**
     * 获得国内供应商优质资源条件
     * @param id 编号
     * @return 国内供应商优质资源条件
     */
    SupplierResourceDO getSupplierResource(Long id);

    /**
     * 获得国内供应商优质资源条件列表
     * @param ids 编号
     * @return 国内供应商优质资源条件列表
     */
    List<SupplierResourceDO> getSupplierResourceList(Collection<Long> ids);

    /**
     * 获得国内供应商优质资源条件分页
     * @param page 分页查询
     * @param query 查询
     * @return 国内供应商优质资源条件分页
     */
    PageResult<SupplierResourceDO> getSupplierResourcePage(SupplierResourceQueryVO query, PageVO page);

    /**
     * 获得国内供应商优质资源条件列表, 用于 Excel 导出
     * @param query 查询
     * @return 国内供应商优质资源条件列表
     */
    List<SupplierResourceDO> getSupplierResourceList(SupplierResourceQueryVO query);
}
