package cn.iocoder.yudao.module.ecw.service.unit;

import cn.iocoder.yudao.framework.common.util.spring.enums.CommonStatusEnum;
import cn.iocoder.yudao.framework.mybatis.core.query.LambdaQueryWrapperX;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;

import java.util.*;
import cn.iocoder.yudao.module.ecw.controller.admin.unit.vo.*;
import cn.iocoder.yudao.module.ecw.dal.dataobject.unit.UnitDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;

import cn.iocoder.yudao.module.ecw.convert.unit.UnitConvert;
import cn.iocoder.yudao.module.ecw.dal.mysql.unit.UnitMapper;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.ecw.enums.ErrorCodeConstants.*;

/**
 * 计量单位 Service 实现类
 *
 * @author 久点源码
 */
@Service
@Validated
public class UnitServiceImpl implements UnitService {

    @Resource
    private UnitMapper unitMapper;

    @Override
    public Integer createUnit(UnitCreateReqVO createReqVO) {
        // 插入
        UnitDO unit = UnitConvert.INSTANCE.convert(createReqVO);
        unitMapper.insert(unit);
        // 返回
        return unit.getId();
    }

    @Override
    public void updateUnit(UnitUpdateReqVO updateReqVO) {
        // 校验存在
        this.validateUnitExists(updateReqVO.getId());
        // 更新
        UnitDO updateObj = UnitConvert.INSTANCE.convert(updateReqVO);
        unitMapper.updateById(updateObj);
    }

    @Override
    public void updateUnitStatus(UnitUpdateStatusReqVO updateReqVO) {
        // 校验存在
        this.validateUnitExists(updateReqVO.getId());
        // 更新
        UnitDO updateObj = UnitConvert.INSTANCE.convert(updateReqVO);
        unitMapper.updateById(updateObj);
    }

    @Override
    public void deleteUnit(Integer id) {
        // 校验存在
        this.validateUnitExists(id);
        // 删除
        unitMapper.deleteById(id);
    }

    private void validateUnitExists(Integer id) {
        if (unitMapper.selectById(id) == null) {
            throw exception(UNIT_NOT_EXISTS);
        }
    }

    @Override
    public UnitDO getUnit(Integer id) {
        return unitMapper.selectById(id);
    }

    @Override
    public List<UnitDO> getUnitList() {
        return unitMapper.selectList(new LambdaQueryWrapperX<UnitDO>()
                        .eqIfPresent(UnitDO::getStatus, CommonStatusEnum.ENABLE.getStatus())
                                    .orderByAsc(UnitDO::getAorder)
        );
    }

    @Override
    public PageResult<UnitDO> getUnitPage(UnitPageReqVO pageReqVO) {
        return unitMapper.selectPage(pageReqVO);
    }

    @Override
    public List<UnitDO> getUnitList(UnitExportReqVO exportReqVO) {
        return unitMapper.selectList(exportReqVO);
    }

    @Override
    public List<UnitDO> list() {
        return unitMapper.selectList(new LambdaQueryWrapper<UnitDO>().eq(UnitDO::getStatus, 0).eq(UnitDO::getDeleted, 0).orderByAsc(UnitDO::getAorder));
    }
}
