CREATE TABLE IF NOT EXISTS "ecw_dock" (
    "id" int NOT NULL GENERATED BY DEFAULT AS IDENTITY,
    "title_zh" varchar(25) NOT NULL,
    "title_en" varchar(30) NOT NULL,
    "sort" int NOT NULL,
    "source" varchar(10) NOT NULL,
    "country_id" bigint,
    "country_zh" varchar(255),
    "country_en" varchar(255),
    "province_id" bigint,
    "province_zh" varchar(255),
    "province_en" varchar(255),
    "city_id" bigint,
    "city_zh" varchar(255),
    "city_en" varchar(255),
    "number" varchar(255),
    "type" varchar(255),
    "status" tinyint(1),
    "creator" varchar(64) DEFAULT '',
    "create_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
    "updater" varchar(64) DEFAULT '',
    "update_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    "deleted" bit NOT NULL DEFAULT FALSE,
    PRIMARY KEY ("id")
) COMMENT '码头信息表';

-- 将该建表 SQL 语句，添加到 yudao-module-ecw-impl 模块的 test/resources/sql/create_tables.sql 文件里
CREATE TABLE IF NOT EXISTS "ecw_currency" (
                                              "id" int NOT NULL GENERATED BY DEFAULT AS IDENTITY,
                                              "title_zh" varchar(100),
    "title_en" varchar(100),
    "fuhao" varchar(255),
    "show" tinyint,
    "huilv" float(11,9),
    "aorder" int,
    "create_at" datetime,
    "update_at" datetime,
    PRIMARY KEY ("id")
    ) COMMENT '货币单位管理';



-- 计量单位
-- 将该建表 SQL 语句，添加到 yudao-module-ecw-impl 模块的 test/resources/sql/create_tables.sql 文件里
CREATE TABLE IF NOT EXISTS "ecw_unit" (
                                          "id" int NOT NULL GENERATED BY DEFAULT AS IDENTITY,
                                          "title_zh" varchar(100),
    "title_en" varchar(100),
    "fuhao" varchar(255),
    "status" tinyint(1),
    "aorder" int,
    "create_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
    "update_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    "creator" varchar(255) DEFAULT '',
    "updater" varchar(255) DEFAULT '',
    "deleted" bit NOT NULL DEFAULT FALSE,
    PRIMARY KEY ("id")
    ) COMMENT '计量单位表';

-- 将该建表 SQL 语句，添加到 yudao-module-ecw-impl 模块的 test/resources/sql/create_tables.sql 文件里
CREATE TABLE IF NOT EXISTS "ecw_bank_account" (
                                                  "id" bigint NOT NULL GENERATED BY DEFAULT AS IDENTITY,
                                                  "ba_account_name" varchar(100) NOT NULL,
    "ba_bank_name" varchar(100) NOT NULL,
    "ba_account_num" varchar(100) NOT NULL,
    "ba_swift_code" varchar(30) NOT NULL,
    "ba_bank_add" varchar(30) NOT NULL,
    "ba_type" tinyint NOT NULL,
    "source" varchar(30) NOT NULL,
    "status" tinyint NOT NULL,
    "creator" varchar(64) DEFAULT '',
    "create_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
    "updater" varchar(64) DEFAULT '',
    "update_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    "deleted" bit NOT NULL DEFAULT FALSE,
    PRIMARY KEY ("id")
    ) COMMENT '银行账户表';

CREATE TABLE IF NOT EXISTS "ecw_node" (
    "id" int NOT NULL GENERATED BY DEFAULT AS IDENTITY,
    "number" varchar(100),
    "zhou" bigint,
    "guojia" bigint,
    "sheng" bigint,
    "shi" bigint,
    "title_zh" varchar(255),
    "title_en" varchar(255),
    "img" varchar(255),
    "titles_zh" varchar(255),
    "titles_en" varchar(500),
    "keywords_zh" varchar(500),
    "keywords_en" varchar(500),
    "description_zh" varchar(1000),
    "description_en" varchar(1000),
    "content_zh" text,
    "content_en" text,
    "address_zh" varchar(1000),
    "address_en" varchar(1000),
    "trade_type" char(10),
    "freight" varchar(500),
    "worktime" varchar(255),
    "admin_id" int,
    "aorder" int,
    "status" tinyint(1),
    "creator" varchar(64) DEFAULT '',
    "create_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
    "updater" varchar(64) DEFAULT '',
    "update_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    "deleted" bit NOT NULL DEFAULT FALSE,
    PRIMARY KEY ("id")
) COMMENT '服务网点';


CREATE TABLE IF NOT EXISTS "ecw_express" (
                                             "id" bigint NOT NULL GENERATED BY DEFAULT AS IDENTITY,
                                             "company_name" varchar(63) NOT NULL,
                                             "account_name" varchar(63),
                                             "query_key" varchar(64),
                                             "query_url" varchar(127),
                                             "creator" varchar(63) DEFAULT '',
                                             "create_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
                                             "updater" varchar(63) DEFAULT '',
                                             "update_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
                                             "deleted" bit NOT NULL DEFAULT FALSE,
                                             PRIMARY KEY ("id")
) COMMENT '配送管理';



CREATE TABLE IF NOT EXISTS "ecw_pickup_loc" (
    "id" bigint NOT NULL GENERATED BY DEFAULT AS IDENTITY,
    "country_id" bigint NOT NULL,
    "title_zh" varchar(255) NOT NULL,
    "title_en" varchar(255),
    "work_time" varchar(255),
    "contact" varchar(255),
    "address" varchar(255),
    "detail_zh" varchar(255),
    "detail_en" varchar(255),
    "sort" int NOT NULL,
    "status" tinyint(1),
    "creator" varchar(64) DEFAULT '',
    "create_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
    "updater" varchar(64) DEFAULT '',
    "update_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    "deleted" bit NOT NULL DEFAULT FALSE,
    PRIMARY KEY ("id")
) COMMENT '自提点';


CREATE TABLE IF NOT EXISTS "ecw_zhong_pao" (
                                               "id" bigint NOT NULL GENERATED BY DEFAULT AS IDENTITY,
                                               "pao_linjie" varchar(127),
                                               "pao_gs" varchar(127),
                                               "pao_ys_ids" varchar(255),
                                               "pao_is_open" tinyint(1) NOT NULL,
                                               "zhong_linjie" varchar(127),
                                               "zhong_gs" varchar(127),
                                               "zhong_ys_ids" varchar(255),
                                               "zhong_is_open" tinyint(1) NOT NULL,
                                               "creator" varchar(63) DEFAULT '',
                                               "create_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
                                               "updater" varchar(63) DEFAULT '',
                                               "update_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
                                               "deleted" bit NOT NULL DEFAULT FALSE,
                                               PRIMARY KEY ("id")
) COMMENT '重泡货配置';

-- 将该建表 SQL 语句，添加到 yudao-module-ecw-impl 模块的 test/resources/sql/create_tables.sql 文件里
CREATE TABLE IF NOT EXISTS "ecw_order_code" (
                                                "id" bigint NOT NULL GENERATED BY DEFAULT AS IDENTITY,
                                                "title" varchar(127) NOT NULL,
                                                "start_code" bigint NOT NULL,
                                                "end_code" bigint,
                                                "creator" varchar(63) DEFAULT '',
                                                "create_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
                                                "updater" varchar(63) DEFAULT '',
                                                "update_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
                                                "deleted" bit NOT NULL DEFAULT FALSE,
                                                PRIMARY KEY ("id")
) COMMENT '单号配置';



-- 将该建表 SQL 语句，添加到 yudao-module-ecw-impl 模块的 test/resources/sql/create_tables.sql 文件里
CREATE TABLE IF NOT EXISTS "ecw_cabinet" (
                                             "id" bigint NOT NULL GENERATED BY DEFAULT AS IDENTITY,
                                             "name" varchar(127) NOT NULL,
                                             "volume" decimal(10,2),
                                             "weight" decimal(10,2),
                                             "status" tinyint NOT NULL,
                                             "sort" int NOT NULL,
                                             "creator" varchar(63) DEFAULT '',
                                             "create_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
                                             "updater" varchar(63) DEFAULT '',
                                             "update_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
                                             "deleted" bit NOT NULL DEFAULT FALSE,
                                             PRIMARY KEY ("id")
) COMMENT '柜型配置';

--ecash汇率表
CREATE TABLE IF NOT EXISTS "ecw_currency_ecash" (
                                                    "id" int NOT NULL GENERATED BY DEFAULT AS IDENTITY,
                                                    "title_zh" varchar(100),
    "title_en" varchar(100),
    "fuhao" varchar(255),
    "status" tinyint(1),
    "huilv" float(13,4),
    "aorder" int,
    "create_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
    "update_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    "creator" varchar(255) DEFAULT '',
    "updater" varchar(255) DEFAULT '',
    "deleted" bit NOT NULL DEFAULT FALSE,
    PRIMARY KEY ("id")
    ) COMMENT 'E-Cash汇率单位表';


CREATE TABLE IF NOT EXISTS "ecw_customer" (
                                              "id" bigint NOT NULL GENERATED BY DEFAULT AS IDENTITY,
                                              "number" varchar(50),
                                              "name" varchar(100) NOT NULL,
                                              "level" tinyint,
                                              "country" bigint,
                                              "type" varchar(10),
                                              "agent_id" bigint,
                                              "company" varchar(100),
                                              "address" varchar(255),
                                              "product_type" bigint,
                                              "product_id" bigint,
                                              "pickup_point" bigint,
                                              "member_id" bigint,
                                              "birthday" int,
                                              "balance" tinyint,
                                              "source" tinyint,
                                              "picture" varchar(255),
                                              "customer_service" bigint,
                                              "promoter" bigint,
                                              "status" tinyint,
                                              "founder" bigint,
                                              "department" varchar(100),
                                              "invoice_title" varchar(100),
                                              "license_number" varchar(100),
                                              "bank" varchar(100),
                                              "bank_number" varchar(100),
                                              "project" varchar(100),
                                              "billing_address" varchar(100),
                                              "billing_tell" varchar(50),
                                              "tax_rate" decimal(10,2),
                                              "perfect_time" datetime,
                                              "remarks" varchar(255),
                                              "admin_id" bigint,
                                              "approver" bigint,
                                              "notifier" bigint,
                                              "other_approval_id" bigint,
                                              "arrival_confirm" tinyint,
                                              "weight_unit" decimal(10,2) NOT NULL,
                                              "weight_edit_who" varchar(20) NOT NULL,
                                              "weight_edit_time" datetime,
                                              "is_auto" tinyint NOT NULL,
                                              "creator" varchar(63) DEFAULT '',
                                              "create_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
                                              "updater" varchar(63) DEFAULT '',
                                              "update_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
                                              "deleted" bit NOT NULL DEFAULT FALSE,
                                              PRIMARY KEY ("id")
) COMMENT '客户表';



-- 将该建表 SQL 语句，添加到 yudao-module-ecw-impl 模块的 test/resources/sql/create_tables.sql 文件里
CREATE TABLE IF NOT EXISTS "ecw_customer_contacts" (
                                                       "id" bigint NOT NULL GENERATED BY DEFAULT AS IDENTITY,
                                                       "customer_id" bigint,
                                                       "department" varchar(100),
                                                       "position" varchar(100),
                                                       "name" varchar(100),
                                                       "phone" varchar(50),
                                                       "social" int,
                                                       "social_number" varchar(50),
                                                       "email" varchar(50),
                                                       "default" tinyint,
                                                       "userid" bigint,
                                                       "username" varchar(100),
                                                       "area_code" varchar(15) NOT NULL,
                                                       "phone_new" varchar(63) NOT NULL,
                                                       "is_auto" tinyint NOT NULL,
                                                       "creator" varchar(63) DEFAULT '',
                                                       "create_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
                                                       "updater" varchar(63) DEFAULT '',
                                                       "update_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
                                                       "deleted" bit NOT NULL DEFAULT FALSE,
                                                       PRIMARY KEY ("id")
) COMMENT '客户联系人表';


-- 将该建表 SQL 语句，添加到 yudao-module-ecw-impl 模块的 test/resources/sql/create_tables.sql 文件里
CREATE TABLE IF NOT EXISTS "ecw_customer_complaint" (
                                                        "id" bigint NOT NULL GENERATED BY DEFAULT AS IDENTITY,
                                                        "customer_id" bigint NOT NULL,
                                                        "type" tinyint,
                                                        "order_id" varchar(1000),
                                                        "ladingbill_id" varchar(1000),
                                                        "content" varchar(255),
                                                        "status" tinyint,
                                                        "admin_id" bigint,
                                                        "code" varchar(255),
                                                        "creator" varchar(63) DEFAULT '',
                                                        "create_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
                                                        "updater" varchar(63) DEFAULT '',
                                                        "update_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
                                                        "deleted" bit NOT NULL DEFAULT FALSE,
                                                        PRIMARY KEY ("id")
) COMMENT '客户投诉表';

-- 将该建表 SQL 语句，添加到 yudao-module-ecw-impl 模块的 test/resources/sql/create_tables.sql 文件里
CREATE TABLE IF NOT EXISTS "ecw_customer_complaint_follow" (
                                                               "id" bigint NOT NULL GENERATED BY DEFAULT AS IDENTITY,
                                                               "complaint_id" bigint NOT NULL,
                                                               "follow_type" tinyint,
                                                               "follow_time" datetime,
                                                               "contact_name" varchar(63),
                                                               "follow_method" tinyint,
                                                               "follow_user_id" bigint,
                                                               "feedback" varchar(1000),
                                                               "result" varchar(1000),
                                                               "admin_id" bigint,
                                                               "creator" varchar(63) DEFAULT '',
                                                               "create_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
                                                               "updater" varchar(63) DEFAULT '',
                                                               "update_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
                                                               "deleted" bit NOT NULL DEFAULT FALSE,
                                                               PRIMARY KEY ("id")
) COMMENT '客户投诉跟进表';


-- 将该建表 SQL 语句，添加到 yudao-module-ecw-impl 模块的 test/resources/sql/create_tables.sql 文件里
CREATE TABLE IF NOT EXISTS "ecw_busi_pwd" (
                                              "id" bigint NOT NULL GENERATED BY DEFAULT AS IDENTITY,
                                              "busi_type" varchar(5),
    "pwd" varchar(64),
    "creator" varchar(32) DEFAULT '',
    "create_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
    "updater" varchar(32) DEFAULT '',
    "update_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    "deleted" bit NOT NULL DEFAULT FALSE,
    PRIMARY KEY ("id")
    ) COMMENT '业务密码表，存储一些业务中使用的密码';

-- 将该建表 SQL 语句，添加到 yudao-module-ecw-impl 模块的 test/resources/sql/create_tables.sql 文件里
CREATE TABLE IF NOT EXISTS "ecw_product_brank" (
                                                   "id" bigint NOT NULL GENERATED BY DEFAULT AS IDENTITY,
                                                   "title_zh" varchar(255),
    "title_en" varchar(255),
    "aorder" int,
    "filing" char(20),
    "creator" varchar(32) DEFAULT '',
    "create_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
    "updater" varchar(32) DEFAULT '',
    "update_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    "deleted" bit NOT NULL DEFAULT FALSE,
    PRIMARY KEY ("id")
    ) COMMENT '品牌表';


CREATE TABLE IF NOT EXISTS "ecw_product_brand_empower" (
                                                           "id" bigint NOT NULL GENERATED BY DEFAULT AS IDENTITY,
                                                           "product_brand_id" bigint NOT NULL,
                                                           "customer_id" bigint NOT NULL,
                                                           "customer_contacts_id" bigint NOT NULL,
                                                           "start_time" datetime,
                                                           "end_time" datetime,
                                                           "file_url" varchar(255) NOT NULL,
    "fee_scale" tinyint NOT NULL,
    "status" tinyint NOT NULL,
    "create_user_id" bigint NOT NULL,
    "create_username" varchar(255) NOT NULL,
    "creator" varchar(32) DEFAULT '',
    "create_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
    "updater" varchar(32) DEFAULT '',
    "update_time" datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    "deleted" bit NOT NULL DEFAULT FALSE,
    PRIMARY KEY ("id")
    ) COMMENT '商品品牌授权表';
